# poodle_async_full
Auto-generated OpenAPI spec for Moodle's Webservice API.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 5.0.3 (Build: 20251006)
- Package version: 5.0.3
- Generator version: 7.15.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/bchmnn/poodle.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/bchmnn/poodle.git`)

Then import the package:
```python
import poodle_async_full
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import poodle_async_full
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import poodle_async_full
from poodle_async_full.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = poodle_async_full.Configuration(
    host = "https://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: wstoken
configuration.api_key['wstoken'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['wstoken'] = 'Bearer'


# Enter a context with an instance of the API client
async with poodle_async_full.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = poodle_async_full.DefaultApi(api_client)
    contextid = 56 # int | The context ID
    prompttext = 'prompttext_example' # str | The prompt text for the AI service

    try:
        # Explain text for the Course Assistance Placement
        api_response = await api_instance.aiplacement_courseassist_explain_text(contextid, prompttext)
        print("The response of DefaultApi->aiplacement_courseassist_explain_text:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->aiplacement_courseassist_explain_text: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**aiplacement_courseassist_explain_text**](docs/DefaultApi.md#aiplacement_courseassist_explain_text) | **POST** /webservice/rest/server.php#aiplacement_courseassist_explain_text | Explain text for the Course Assistance Placement
*DefaultApi* | [**aiplacement_courseassist_summarise_text**](docs/DefaultApi.md#aiplacement_courseassist_summarise_text) | **POST** /webservice/rest/server.php#aiplacement_courseassist_summarise_text | Summarise text for the Course Assistance Placement
*DefaultApi* | [**aiplacement_editor_generate_image**](docs/DefaultApi.md#aiplacement_editor_generate_image) | **POST** /webservice/rest/server.php#aiplacement_editor_generate_image | Generate image for the HTML Text editor AI Placement
*DefaultApi* | [**aiplacement_editor_generate_text**](docs/DefaultApi.md#aiplacement_editor_generate_text) | **POST** /webservice/rest/server.php#aiplacement_editor_generate_text | Generate text for the HTML Text editor AI Placement
*DefaultApi* | [**auth_email_get_signup_settings**](docs/DefaultApi.md#auth_email_get_signup_settings) | **GET** /lib/ajax/service-nologin.php#auth_email_get_signup_settings | Get the signup required settings and profile fields.
*DefaultApi* | [**auth_email_signup_user**](docs/DefaultApi.md#auth_email_signup_user) | **GET** /lib/ajax/service-nologin.php#auth_email_signup_user | Adds a new user (pendingto be confirmed) in the site.
*DefaultApi* | [**block_accessreview_get_module_data**](docs/DefaultApi.md#block_accessreview_get_module_data) | **POST** /webservice/rest/server.php#block_accessreview_get_module_data | Gets error data for course modules.
*DefaultApi* | [**block_accessreview_get_section_data**](docs/DefaultApi.md#block_accessreview_get_section_data) | **POST** /webservice/rest/server.php#block_accessreview_get_section_data | Gets error data for course sections.
*DefaultApi* | [**block_recentlyaccesseditems_get_recent_items**](docs/DefaultApi.md#block_recentlyaccesseditems_get_recent_items) | **POST** /webservice/rest/server.php#block_recentlyaccesseditems_get_recent_items | List of items a user has accessed most recently.
*DefaultApi* | [**block_starredcourses_get_starred_courses**](docs/DefaultApi.md#block_starredcourses_get_starred_courses) | **POST** /webservice/rest/server.php#block_starredcourses_get_starred_courses | Get users starred courses.
*DefaultApi* | [**core_admin_set_block_protection**](docs/DefaultApi.md#core_admin_set_block_protection) | **POST** /webservice/rest/server.php#core_admin_set_block_protection | Set the protection state for a block plugin
*DefaultApi* | [**core_admin_set_plugin_order**](docs/DefaultApi.md#core_admin_set_plugin_order) | **POST** /webservice/rest/server.php#core_admin_set_plugin_order | Set the order of a plugin
*DefaultApi* | [**core_admin_set_plugin_state**](docs/DefaultApi.md#core_admin_set_plugin_state) | **POST** /webservice/rest/server.php#core_admin_set_plugin_state | Set the state of a plugin
*DefaultApi* | [**core_ai_delete_provider_instance**](docs/DefaultApi.md#core_ai_delete_provider_instance) | **POST** /webservice/rest/server.php#core_ai_delete_provider_instance | Delete a provider instance
*DefaultApi* | [**core_ai_get_policy_status**](docs/DefaultApi.md#core_ai_get_policy_status) | **POST** /webservice/rest/server.php#core_ai_get_policy_status | Get a users AI policy acceptance
*DefaultApi* | [**core_ai_set_action**](docs/DefaultApi.md#core_ai_set_action) | **POST** /webservice/rest/server.php#core_ai_set_action | Update action
*DefaultApi* | [**core_ai_set_policy_status**](docs/DefaultApi.md#core_ai_set_policy_status) | **POST** /webservice/rest/server.php#core_ai_set_policy_status | Set a users AI policy acceptance
*DefaultApi* | [**core_ai_set_provider_order**](docs/DefaultApi.md#core_ai_set_provider_order) | **POST** /webservice/rest/server.php#core_ai_set_provider_order | Set the order of a provider
*DefaultApi* | [**core_ai_set_provider_status**](docs/DefaultApi.md#core_ai_set_provider_status) | **POST** /webservice/rest/server.php#core_ai_set_provider_status | Set a providers status
*DefaultApi* | [**core_auth_confirm_user**](docs/DefaultApi.md#core_auth_confirm_user) | **GET** /lib/ajax/service-nologin.php#core_auth_confirm_user | Confirm a user account.
*DefaultApi* | [**core_auth_is_age_digital_consent_verification_enabled**](docs/DefaultApi.md#core_auth_is_age_digital_consent_verification_enabled) | **GET** /lib/ajax/service-nologin.php#core_auth_is_age_digital_consent_verification_enabled | Checks if age digital consent verification is enabled.
*DefaultApi* | [**core_auth_is_minor**](docs/DefaultApi.md#core_auth_is_minor) | **GET** /lib/ajax/service-nologin.php#core_auth_is_minor | Requests a check if a user is a digital minor.
*DefaultApi* | [**core_auth_request_password_reset**](docs/DefaultApi.md#core_auth_request_password_reset) | **GET** /lib/ajax/service-nologin.php#core_auth_request_password_reset | Requests a password reset.
*DefaultApi* | [**core_auth_resend_confirmation_email**](docs/DefaultApi.md#core_auth_resend_confirmation_email) | **GET** /lib/ajax/service-nologin.php#core_auth_resend_confirmation_email | Resend confirmation email.
*DefaultApi* | [**core_backup_get_async_backup_links_backup**](docs/DefaultApi.md#core_backup_get_async_backup_links_backup) | **POST** /webservice/rest/server.php#core_backup_get_async_backup_links_backup | Gets the data to use when updating the status table row in the UI for when an async backup completes.
*DefaultApi* | [**core_backup_get_async_backup_links_restore**](docs/DefaultApi.md#core_backup_get_async_backup_links_restore) | **POST** /webservice/rest/server.php#core_backup_get_async_backup_links_restore | Gets the data to use when updating the status table row in the UI for when an async restore completes.
*DefaultApi* | [**core_backup_get_async_backup_progress**](docs/DefaultApi.md#core_backup_get_async_backup_progress) | **POST** /webservice/rest/server.php#core_backup_get_async_backup_progress | Get the progress of an Asyncronhous backup.
*DefaultApi* | [**core_backup_get_copy_progress**](docs/DefaultApi.md#core_backup_get_copy_progress) | **POST** /webservice/rest/server.php#core_backup_get_copy_progress | Gets the progress of course copy operations.
*DefaultApi* | [**core_backup_submit_copy_form**](docs/DefaultApi.md#core_backup_submit_copy_form) | **POST** /webservice/rest/server.php#core_backup_submit_copy_form | Handles ajax submission of course copy form.
*DefaultApi* | [**core_badges_disable_badges**](docs/DefaultApi.md#core_badges_disable_badges) | **POST** /webservice/rest/server.php#core_badges_disable_badges | Disable badges
*DefaultApi* | [**core_badges_enable_badges**](docs/DefaultApi.md#core_badges_enable_badges) | **POST** /webservice/rest/server.php#core_badges_enable_badges | Enable badges
*DefaultApi* | [**core_badges_get_badge**](docs/DefaultApi.md#core_badges_get_badge) | **POST** /webservice/rest/server.php#core_badges_get_badge | Retrieves a badge by id.
*DefaultApi* | [**core_badges_get_user_badge_by_hash**](docs/DefaultApi.md#core_badges_get_user_badge_by_hash) | **POST** /webservice/rest/server.php#core_badges_get_user_badge_by_hash | Returns the badge awarded to a user by hash.
*DefaultApi* | [**core_badges_get_user_badges**](docs/DefaultApi.md#core_badges_get_user_badges) | **POST** /webservice/rest/server.php#core_badges_get_user_badges | Returns the list of badges awarded to a user.
*DefaultApi* | [**core_block_fetch_addable_blocks**](docs/DefaultApi.md#core_block_fetch_addable_blocks) | **POST** /webservice/rest/server.php#core_block_fetch_addable_blocks | Returns all addable blocks in a given page.
*DefaultApi* | [**core_block_get_course_blocks**](docs/DefaultApi.md#core_block_get_course_blocks) | **POST** /webservice/rest/server.php#core_block_get_course_blocks | Returns blocks information for a course.
*DefaultApi* | [**core_block_get_dashboard_blocks**](docs/DefaultApi.md#core_block_get_dashboard_blocks) | **POST** /webservice/rest/server.php#core_block_get_dashboard_blocks | Returns blocks information for the given user dashboard.
*DefaultApi* | [**core_blog_add_entry**](docs/DefaultApi.md#core_blog_add_entry) | **POST** /webservice/rest/server.php#core_blog_add_entry | Creates a new blog post entry.
*DefaultApi* | [**core_blog_delete_entry**](docs/DefaultApi.md#core_blog_delete_entry) | **POST** /webservice/rest/server.php#core_blog_delete_entry | Deletes a blog post entry.
*DefaultApi* | [**core_blog_get_access_information**](docs/DefaultApi.md#core_blog_get_access_information) | **POST** /webservice/rest/server.php#core_blog_get_access_information | Retrieves permission information for the current user.
*DefaultApi* | [**core_blog_get_entries**](docs/DefaultApi.md#core_blog_get_entries) | **GET** /lib/ajax/service-nologin.php#core_blog_get_entries | Returns blog entries.
*DefaultApi* | [**core_blog_prepare_entry_for_edition**](docs/DefaultApi.md#core_blog_prepare_entry_for_edition) | **POST** /webservice/rest/server.php#core_blog_prepare_entry_for_edition | Prepare a draft area for editing a blog entry..
*DefaultApi* | [**core_blog_update_entry**](docs/DefaultApi.md#core_blog_update_entry) | **POST** /webservice/rest/server.php#core_blog_update_entry | Updates a blog entry.
*DefaultApi* | [**core_blog_view_entries**](docs/DefaultApi.md#core_blog_view_entries) | **GET** /lib/ajax/service-nologin.php#core_blog_view_entries | Trigger the blog_entries_viewed event.
*DefaultApi* | [**core_calendar_create_calendar_events**](docs/DefaultApi.md#core_calendar_create_calendar_events) | **POST** /webservice/rest/server.php#core_calendar_create_calendar_events | Create calendar events
*DefaultApi* | [**core_calendar_delete_calendar_events**](docs/DefaultApi.md#core_calendar_delete_calendar_events) | **POST** /webservice/rest/server.php#core_calendar_delete_calendar_events | Delete calendar events
*DefaultApi* | [**core_calendar_delete_subscription**](docs/DefaultApi.md#core_calendar_delete_subscription) | **POST** /webservice/rest/server.php#core_calendar_delete_subscription | Delete the calendar subscription
*DefaultApi* | [**core_calendar_get_action_events_by_course**](docs/DefaultApi.md#core_calendar_get_action_events_by_course) | **POST** /webservice/rest/server.php#core_calendar_get_action_events_by_course | Get calendar action events by course
*DefaultApi* | [**core_calendar_get_action_events_by_courses**](docs/DefaultApi.md#core_calendar_get_action_events_by_courses) | **POST** /webservice/rest/server.php#core_calendar_get_action_events_by_courses | Get calendar action events by courses
*DefaultApi* | [**core_calendar_get_action_events_by_timesort**](docs/DefaultApi.md#core_calendar_get_action_events_by_timesort) | **POST** /webservice/rest/server.php#core_calendar_get_action_events_by_timesort | Get calendar action events by tiemsort
*DefaultApi* | [**core_calendar_get_allowed_event_types**](docs/DefaultApi.md#core_calendar_get_allowed_event_types) | **POST** /webservice/rest/server.php#core_calendar_get_allowed_event_types | Get the type of events a user can create in the given course.
*DefaultApi* | [**core_calendar_get_calendar_access_information**](docs/DefaultApi.md#core_calendar_get_calendar_access_information) | **POST** /webservice/rest/server.php#core_calendar_get_calendar_access_information | Convenience function to retrieve some permissions/access information for the given course calendar.
*DefaultApi* | [**core_calendar_get_calendar_day_view**](docs/DefaultApi.md#core_calendar_get_calendar_day_view) | **POST** /webservice/rest/server.php#core_calendar_get_calendar_day_view | Fetch the day view data for a calendar
*DefaultApi* | [**core_calendar_get_calendar_event_by_id**](docs/DefaultApi.md#core_calendar_get_calendar_event_by_id) | **POST** /webservice/rest/server.php#core_calendar_get_calendar_event_by_id | Get calendar event by id
*DefaultApi* | [**core_calendar_get_calendar_events**](docs/DefaultApi.md#core_calendar_get_calendar_events) | **POST** /webservice/rest/server.php#core_calendar_get_calendar_events | Get calendar events
*DefaultApi* | [**core_calendar_get_calendar_export_token**](docs/DefaultApi.md#core_calendar_get_calendar_export_token) | **POST** /webservice/rest/server.php#core_calendar_get_calendar_export_token | Return the auth token required for exporting a calendar.
*DefaultApi* | [**core_calendar_get_calendar_monthly_view**](docs/DefaultApi.md#core_calendar_get_calendar_monthly_view) | **POST** /webservice/rest/server.php#core_calendar_get_calendar_monthly_view | Fetch the monthly view data for a calendar
*DefaultApi* | [**core_calendar_get_calendar_upcoming_view**](docs/DefaultApi.md#core_calendar_get_calendar_upcoming_view) | **POST** /webservice/rest/server.php#core_calendar_get_calendar_upcoming_view | Fetch the upcoming view data for a calendar
*DefaultApi* | [**core_calendar_get_timestamps**](docs/DefaultApi.md#core_calendar_get_timestamps) | **POST** /webservice/rest/server.php#core_calendar_get_timestamps | Fetch unix timestamps for given date times.
*DefaultApi* | [**core_calendar_submit_create_update_form**](docs/DefaultApi.md#core_calendar_submit_create_update_form) | **POST** /webservice/rest/server.php#core_calendar_submit_create_update_form | Submit form data for event form
*DefaultApi* | [**core_calendar_update_event_start_day**](docs/DefaultApi.md#core_calendar_update_event_start_day) | **POST** /webservice/rest/server.php#core_calendar_update_event_start_day | Update the start day (but not time) for an event.
*DefaultApi* | [**core_change_editmode**](docs/DefaultApi.md#core_change_editmode) | **POST** /webservice/rest/server.php#core_change_editmode | Change the editing mode
*DefaultApi* | [**core_check_get_result_admintree**](docs/DefaultApi.md#core_check_get_result_admintree) | **POST** /webservice/rest/server.php#core_check_get_result_admintree | Executes a check stored in the admin tree and returns the result
*DefaultApi* | [**core_cohort_add_cohort_members**](docs/DefaultApi.md#core_cohort_add_cohort_members) | **POST** /webservice/rest/server.php#core_cohort_add_cohort_members | Adds cohort members.
*DefaultApi* | [**core_cohort_create_cohorts**](docs/DefaultApi.md#core_cohort_create_cohorts) | **POST** /webservice/rest/server.php#core_cohort_create_cohorts | Creates new cohorts.
*DefaultApi* | [**core_cohort_delete_cohort_members**](docs/DefaultApi.md#core_cohort_delete_cohort_members) | **POST** /webservice/rest/server.php#core_cohort_delete_cohort_members | Deletes cohort members.
*DefaultApi* | [**core_cohort_delete_cohorts**](docs/DefaultApi.md#core_cohort_delete_cohorts) | **POST** /webservice/rest/server.php#core_cohort_delete_cohorts | Deletes all specified cohorts.
*DefaultApi* | [**core_cohort_get_cohort_members**](docs/DefaultApi.md#core_cohort_get_cohort_members) | **POST** /webservice/rest/server.php#core_cohort_get_cohort_members | Returns cohort members.
*DefaultApi* | [**core_cohort_get_cohorts**](docs/DefaultApi.md#core_cohort_get_cohorts) | **POST** /webservice/rest/server.php#core_cohort_get_cohorts | Returns cohort details.
*DefaultApi* | [**core_cohort_search_cohorts**](docs/DefaultApi.md#core_cohort_search_cohorts) | **POST** /webservice/rest/server.php#core_cohort_search_cohorts | Search for cohorts.
*DefaultApi* | [**core_cohort_update_cohorts**](docs/DefaultApi.md#core_cohort_update_cohorts) | **POST** /webservice/rest/server.php#core_cohort_update_cohorts | Updates existing cohorts.
*DefaultApi* | [**core_comment_add_comments**](docs/DefaultApi.md#core_comment_add_comments) | **POST** /webservice/rest/server.php#core_comment_add_comments | Adds a comment or comments.
*DefaultApi* | [**core_comment_delete_comments**](docs/DefaultApi.md#core_comment_delete_comments) | **POST** /webservice/rest/server.php#core_comment_delete_comments | Deletes a comment or comments.
*DefaultApi* | [**core_comment_get_comments**](docs/DefaultApi.md#core_comment_get_comments) | **POST** /webservice/rest/server.php#core_comment_get_comments | Returns comments.
*DefaultApi* | [**core_competency_add_competency_to_course**](docs/DefaultApi.md#core_competency_add_competency_to_course) | **POST** /webservice/rest/server.php#core_competency_add_competency_to_course | Add the competency to a course
*DefaultApi* | [**core_competency_add_competency_to_plan**](docs/DefaultApi.md#core_competency_add_competency_to_plan) | **POST** /webservice/rest/server.php#core_competency_add_competency_to_plan | Add the competency to a learning plan
*DefaultApi* | [**core_competency_add_competency_to_template**](docs/DefaultApi.md#core_competency_add_competency_to_template) | **POST** /webservice/rest/server.php#core_competency_add_competency_to_template | Add the competency to a template
*DefaultApi* | [**core_competency_add_related_competency**](docs/DefaultApi.md#core_competency_add_related_competency) | **POST** /webservice/rest/server.php#core_competency_add_related_competency | Adds a related competency
*DefaultApi* | [**core_competency_approve_plan**](docs/DefaultApi.md#core_competency_approve_plan) | **POST** /webservice/rest/server.php#core_competency_approve_plan | Approve a plan.
*DefaultApi* | [**core_competency_competency_framework_viewed**](docs/DefaultApi.md#core_competency_competency_framework_viewed) | **POST** /webservice/rest/server.php#core_competency_competency_framework_viewed | Log event competency framework viewed
*DefaultApi* | [**core_competency_competency_viewed**](docs/DefaultApi.md#core_competency_competency_viewed) | **POST** /webservice/rest/server.php#core_competency_competency_viewed | Log event competency viewed
*DefaultApi* | [**core_competency_complete_plan**](docs/DefaultApi.md#core_competency_complete_plan) | **POST** /webservice/rest/server.php#core_competency_complete_plan | Complete learning plan.
*DefaultApi* | [**core_competency_count_competencies**](docs/DefaultApi.md#core_competency_count_competencies) | **POST** /webservice/rest/server.php#core_competency_count_competencies | Count a list of a competencies.
*DefaultApi* | [**core_competency_count_competencies_in_course**](docs/DefaultApi.md#core_competency_count_competencies_in_course) | **POST** /webservice/rest/server.php#core_competency_count_competencies_in_course | List the competencies in a course
*DefaultApi* | [**core_competency_count_competencies_in_template**](docs/DefaultApi.md#core_competency_count_competencies_in_template) | **POST** /webservice/rest/server.php#core_competency_count_competencies_in_template | Count a list of a competencies for a given template.
*DefaultApi* | [**core_competency_count_competency_frameworks**](docs/DefaultApi.md#core_competency_count_competency_frameworks) | **POST** /webservice/rest/server.php#core_competency_count_competency_frameworks | Count a list of a competency frameworks.
*DefaultApi* | [**core_competency_count_course_module_competencies**](docs/DefaultApi.md#core_competency_count_course_module_competencies) | **POST** /webservice/rest/server.php#core_competency_count_course_module_competencies | Count the competencies in a course module
*DefaultApi* | [**core_competency_count_courses_using_competency**](docs/DefaultApi.md#core_competency_count_courses_using_competency) | **POST** /webservice/rest/server.php#core_competency_count_courses_using_competency | List the courses using a competency
*DefaultApi* | [**core_competency_count_templates**](docs/DefaultApi.md#core_competency_count_templates) | **POST** /webservice/rest/server.php#core_competency_count_templates | Count a list of a learning plan templates.
*DefaultApi* | [**core_competency_count_templates_using_competency**](docs/DefaultApi.md#core_competency_count_templates_using_competency) | **POST** /webservice/rest/server.php#core_competency_count_templates_using_competency | Count a list of a learning plan templates for a given competency.
*DefaultApi* | [**core_competency_create_competency**](docs/DefaultApi.md#core_competency_create_competency) | **POST** /webservice/rest/server.php#core_competency_create_competency | Creates new competencies.
*DefaultApi* | [**core_competency_create_competency_framework**](docs/DefaultApi.md#core_competency_create_competency_framework) | **POST** /webservice/rest/server.php#core_competency_create_competency_framework | Creates new competency frameworks.
*DefaultApi* | [**core_competency_create_plan**](docs/DefaultApi.md#core_competency_create_plan) | **POST** /webservice/rest/server.php#core_competency_create_plan | Creates a learning plan.
*DefaultApi* | [**core_competency_create_template**](docs/DefaultApi.md#core_competency_create_template) | **POST** /webservice/rest/server.php#core_competency_create_template | Creates new learning plan templates.
*DefaultApi* | [**core_competency_create_user_evidence_competency**](docs/DefaultApi.md#core_competency_create_user_evidence_competency) | **POST** /webservice/rest/server.php#core_competency_create_user_evidence_competency | Create an evidence of prior learning relationship with a competency.
*DefaultApi* | [**core_competency_delete_competency**](docs/DefaultApi.md#core_competency_delete_competency) | **POST** /webservice/rest/server.php#core_competency_delete_competency | Delete a competency.
*DefaultApi* | [**core_competency_delete_competency_framework**](docs/DefaultApi.md#core_competency_delete_competency_framework) | **POST** /webservice/rest/server.php#core_competency_delete_competency_framework | Delete a competency framework.
*DefaultApi* | [**core_competency_delete_evidence**](docs/DefaultApi.md#core_competency_delete_evidence) | **POST** /webservice/rest/server.php#core_competency_delete_evidence | Delete an evidence
*DefaultApi* | [**core_competency_delete_plan**](docs/DefaultApi.md#core_competency_delete_plan) | **POST** /webservice/rest/server.php#core_competency_delete_plan | Delete a learning plan.
*DefaultApi* | [**core_competency_delete_template**](docs/DefaultApi.md#core_competency_delete_template) | **POST** /webservice/rest/server.php#core_competency_delete_template | Delete a learning plan template.
*DefaultApi* | [**core_competency_delete_user_evidence**](docs/DefaultApi.md#core_competency_delete_user_evidence) | **POST** /webservice/rest/server.php#core_competency_delete_user_evidence | Delete an evidence of prior learning.
*DefaultApi* | [**core_competency_delete_user_evidence_competency**](docs/DefaultApi.md#core_competency_delete_user_evidence_competency) | **POST** /webservice/rest/server.php#core_competency_delete_user_evidence_competency | Delete an evidence of prior learning relationship with a competency.
*DefaultApi* | [**core_competency_duplicate_competency_framework**](docs/DefaultApi.md#core_competency_duplicate_competency_framework) | **POST** /webservice/rest/server.php#core_competency_duplicate_competency_framework | Duplicate a competency framework.
*DefaultApi* | [**core_competency_duplicate_template**](docs/DefaultApi.md#core_competency_duplicate_template) | **POST** /webservice/rest/server.php#core_competency_duplicate_template | Duplicate learning plan template.
*DefaultApi* | [**core_competency_get_scale_values**](docs/DefaultApi.md#core_competency_get_scale_values) | **POST** /webservice/rest/server.php#core_competency_get_scale_values | Fetch the values for a specific scale
*DefaultApi* | [**core_competency_grade_competency**](docs/DefaultApi.md#core_competency_grade_competency) | **POST** /webservice/rest/server.php#core_competency_grade_competency | Grade a competency.
*DefaultApi* | [**core_competency_grade_competency_in_course**](docs/DefaultApi.md#core_competency_grade_competency_in_course) | **POST** /webservice/rest/server.php#core_competency_grade_competency_in_course | Grade a competency from the course page.
*DefaultApi* | [**core_competency_grade_competency_in_plan**](docs/DefaultApi.md#core_competency_grade_competency_in_plan) | **POST** /webservice/rest/server.php#core_competency_grade_competency_in_plan | Grade a competency from the user plan page.
*DefaultApi* | [**core_competency_list_competencies**](docs/DefaultApi.md#core_competency_list_competencies) | **POST** /webservice/rest/server.php#core_competency_list_competencies | Load a list of a competencies.
*DefaultApi* | [**core_competency_list_competencies_in_template**](docs/DefaultApi.md#core_competency_list_competencies_in_template) | **POST** /webservice/rest/server.php#core_competency_list_competencies_in_template | Load a list of a competencies for a given template.
*DefaultApi* | [**core_competency_list_competency_frameworks**](docs/DefaultApi.md#core_competency_list_competency_frameworks) | **POST** /webservice/rest/server.php#core_competency_list_competency_frameworks | Load a list of a competency frameworks.
*DefaultApi* | [**core_competency_list_course_competencies**](docs/DefaultApi.md#core_competency_list_course_competencies) | **POST** /webservice/rest/server.php#core_competency_list_course_competencies | List the competencies in a course
*DefaultApi* | [**core_competency_list_course_module_competencies**](docs/DefaultApi.md#core_competency_list_course_module_competencies) | **POST** /webservice/rest/server.php#core_competency_list_course_module_competencies | List the competencies in a course module
*DefaultApi* | [**core_competency_list_plan_competencies**](docs/DefaultApi.md#core_competency_list_plan_competencies) | **POST** /webservice/rest/server.php#core_competency_list_plan_competencies | List the competencies in a plan
*DefaultApi* | [**core_competency_list_templates**](docs/DefaultApi.md#core_competency_list_templates) | **POST** /webservice/rest/server.php#core_competency_list_templates | Load a list of a learning plan templates.
*DefaultApi* | [**core_competency_list_templates_using_competency**](docs/DefaultApi.md#core_competency_list_templates_using_competency) | **POST** /webservice/rest/server.php#core_competency_list_templates_using_competency | Load a list of a learning plan templates for a given competency.
*DefaultApi* | [**core_competency_list_user_plans**](docs/DefaultApi.md#core_competency_list_user_plans) | **POST** /webservice/rest/server.php#core_competency_list_user_plans | List a user&#39;s learning plans.
*DefaultApi* | [**core_competency_move_down_competency**](docs/DefaultApi.md#core_competency_move_down_competency) | **POST** /webservice/rest/server.php#core_competency_move_down_competency | Re-order a competency.
*DefaultApi* | [**core_competency_move_up_competency**](docs/DefaultApi.md#core_competency_move_up_competency) | **POST** /webservice/rest/server.php#core_competency_move_up_competency | Re-order a competency.
*DefaultApi* | [**core_competency_plan_cancel_review_request**](docs/DefaultApi.md#core_competency_plan_cancel_review_request) | **POST** /webservice/rest/server.php#core_competency_plan_cancel_review_request | Cancel the review of a plan.
*DefaultApi* | [**core_competency_plan_request_review**](docs/DefaultApi.md#core_competency_plan_request_review) | **POST** /webservice/rest/server.php#core_competency_plan_request_review | Request for a plan to be reviewed.
*DefaultApi* | [**core_competency_plan_start_review**](docs/DefaultApi.md#core_competency_plan_start_review) | **POST** /webservice/rest/server.php#core_competency_plan_start_review | Start the review of a plan.
*DefaultApi* | [**core_competency_plan_stop_review**](docs/DefaultApi.md#core_competency_plan_stop_review) | **POST** /webservice/rest/server.php#core_competency_plan_stop_review | Stop the review of a plan.
*DefaultApi* | [**core_competency_read_competency**](docs/DefaultApi.md#core_competency_read_competency) | **POST** /webservice/rest/server.php#core_competency_read_competency | Load a summary of a competency.
*DefaultApi* | [**core_competency_read_competency_framework**](docs/DefaultApi.md#core_competency_read_competency_framework) | **POST** /webservice/rest/server.php#core_competency_read_competency_framework | Load a summary of a competency framework.
*DefaultApi* | [**core_competency_read_plan**](docs/DefaultApi.md#core_competency_read_plan) | **POST** /webservice/rest/server.php#core_competency_read_plan | Load a learning plan.
*DefaultApi* | [**core_competency_read_template**](docs/DefaultApi.md#core_competency_read_template) | **POST** /webservice/rest/server.php#core_competency_read_template | Load a summary of a learning plan template.
*DefaultApi* | [**core_competency_read_user_evidence**](docs/DefaultApi.md#core_competency_read_user_evidence) | **POST** /webservice/rest/server.php#core_competency_read_user_evidence | Read an evidence of prior learning.
*DefaultApi* | [**core_competency_remove_competency_from_course**](docs/DefaultApi.md#core_competency_remove_competency_from_course) | **POST** /webservice/rest/server.php#core_competency_remove_competency_from_course | Remove a competency from a course
*DefaultApi* | [**core_competency_remove_competency_from_plan**](docs/DefaultApi.md#core_competency_remove_competency_from_plan) | **POST** /webservice/rest/server.php#core_competency_remove_competency_from_plan | Remove the competency from a learning plan
*DefaultApi* | [**core_competency_remove_competency_from_template**](docs/DefaultApi.md#core_competency_remove_competency_from_template) | **POST** /webservice/rest/server.php#core_competency_remove_competency_from_template | Remove a competency from a template
*DefaultApi* | [**core_competency_remove_related_competency**](docs/DefaultApi.md#core_competency_remove_related_competency) | **POST** /webservice/rest/server.php#core_competency_remove_related_competency | Remove a related competency
*DefaultApi* | [**core_competency_reopen_plan**](docs/DefaultApi.md#core_competency_reopen_plan) | **POST** /webservice/rest/server.php#core_competency_reopen_plan | Reopen learning plan.
*DefaultApi* | [**core_competency_reorder_course_competency**](docs/DefaultApi.md#core_competency_reorder_course_competency) | **POST** /webservice/rest/server.php#core_competency_reorder_course_competency | Move a course competency to a new relative sort order.
*DefaultApi* | [**core_competency_reorder_plan_competency**](docs/DefaultApi.md#core_competency_reorder_plan_competency) | **POST** /webservice/rest/server.php#core_competency_reorder_plan_competency | Move a plan competency to a new relative sort order.
*DefaultApi* | [**core_competency_reorder_template_competency**](docs/DefaultApi.md#core_competency_reorder_template_competency) | **POST** /webservice/rest/server.php#core_competency_reorder_template_competency | Move a template competency to a new relative sort order.
*DefaultApi* | [**core_competency_request_review_of_user_evidence_linked_competencies**](docs/DefaultApi.md#core_competency_request_review_of_user_evidence_linked_competencies) | **POST** /webservice/rest/server.php#core_competency_request_review_of_user_evidence_linked_competencies | Send user evidence competencies in review
*DefaultApi* | [**core_competency_search_competencies**](docs/DefaultApi.md#core_competency_search_competencies) | **POST** /webservice/rest/server.php#core_competency_search_competencies | Search a list of a competencies.
*DefaultApi* | [**core_competency_set_course_competency_ruleoutcome**](docs/DefaultApi.md#core_competency_set_course_competency_ruleoutcome) | **POST** /webservice/rest/server.php#core_competency_set_course_competency_ruleoutcome | Modify the ruleoutcome value for course competency
*DefaultApi* | [**core_competency_set_parent_competency**](docs/DefaultApi.md#core_competency_set_parent_competency) | **POST** /webservice/rest/server.php#core_competency_set_parent_competency | Set a new parent for a competency.
*DefaultApi* | [**core_competency_template_has_related_data**](docs/DefaultApi.md#core_competency_template_has_related_data) | **POST** /webservice/rest/server.php#core_competency_template_has_related_data | Check if a template has related data
*DefaultApi* | [**core_competency_template_viewed**](docs/DefaultApi.md#core_competency_template_viewed) | **POST** /webservice/rest/server.php#core_competency_template_viewed | Log event template viewed
*DefaultApi* | [**core_competency_unapprove_plan**](docs/DefaultApi.md#core_competency_unapprove_plan) | **POST** /webservice/rest/server.php#core_competency_unapprove_plan | Unapprove a plan.
*DefaultApi* | [**core_competency_unlink_plan_from_template**](docs/DefaultApi.md#core_competency_unlink_plan_from_template) | **POST** /webservice/rest/server.php#core_competency_unlink_plan_from_template | Unlink a plan form it template.
*DefaultApi* | [**core_competency_update_competency**](docs/DefaultApi.md#core_competency_update_competency) | **POST** /webservice/rest/server.php#core_competency_update_competency | Update a competency.
*DefaultApi* | [**core_competency_update_competency_framework**](docs/DefaultApi.md#core_competency_update_competency_framework) | **POST** /webservice/rest/server.php#core_competency_update_competency_framework | Update a competency framework.
*DefaultApi* | [**core_competency_update_course_competency_settings**](docs/DefaultApi.md#core_competency_update_course_competency_settings) | **POST** /webservice/rest/server.php#core_competency_update_course_competency_settings | Update the course competency settings
*DefaultApi* | [**core_competency_update_plan**](docs/DefaultApi.md#core_competency_update_plan) | **POST** /webservice/rest/server.php#core_competency_update_plan | Updates a learning plan.
*DefaultApi* | [**core_competency_update_template**](docs/DefaultApi.md#core_competency_update_template) | **POST** /webservice/rest/server.php#core_competency_update_template | Update a learning plan template.
*DefaultApi* | [**core_competency_user_competency_cancel_review_request**](docs/DefaultApi.md#core_competency_user_competency_cancel_review_request) | **POST** /webservice/rest/server.php#core_competency_user_competency_cancel_review_request | Cancel a review request.
*DefaultApi* | [**core_competency_user_competency_plan_viewed**](docs/DefaultApi.md#core_competency_user_competency_plan_viewed) | **POST** /webservice/rest/server.php#core_competency_user_competency_plan_viewed | Log the user competency plan viewed event.
*DefaultApi* | [**core_competency_user_competency_request_review**](docs/DefaultApi.md#core_competency_user_competency_request_review) | **POST** /webservice/rest/server.php#core_competency_user_competency_request_review | Request a review.
*DefaultApi* | [**core_competency_user_competency_start_review**](docs/DefaultApi.md#core_competency_user_competency_start_review) | **POST** /webservice/rest/server.php#core_competency_user_competency_start_review | Start a review.
*DefaultApi* | [**core_competency_user_competency_stop_review**](docs/DefaultApi.md#core_competency_user_competency_stop_review) | **POST** /webservice/rest/server.php#core_competency_user_competency_stop_review | Stop a review.
*DefaultApi* | [**core_competency_user_competency_viewed**](docs/DefaultApi.md#core_competency_user_competency_viewed) | **POST** /webservice/rest/server.php#core_competency_user_competency_viewed | Log the user competency viewed event.
*DefaultApi* | [**core_competency_user_competency_viewed_in_course**](docs/DefaultApi.md#core_competency_user_competency_viewed_in_course) | **POST** /webservice/rest/server.php#core_competency_user_competency_viewed_in_course | Log the user competency viewed in course event
*DefaultApi* | [**core_competency_user_competency_viewed_in_plan**](docs/DefaultApi.md#core_competency_user_competency_viewed_in_plan) | **POST** /webservice/rest/server.php#core_competency_user_competency_viewed_in_plan | Log the user competency viewed in plan event.
*DefaultApi* | [**core_completion_get_activities_completion_status**](docs/DefaultApi.md#core_completion_get_activities_completion_status) | **POST** /webservice/rest/server.php#core_completion_get_activities_completion_status | Return the activities completion status for a user in a course.
*DefaultApi* | [**core_completion_get_course_completion_status**](docs/DefaultApi.md#core_completion_get_course_completion_status) | **POST** /webservice/rest/server.php#core_completion_get_course_completion_status | Returns course completion status.
*DefaultApi* | [**core_completion_mark_course_self_completed**](docs/DefaultApi.md#core_completion_mark_course_self_completed) | **POST** /webservice/rest/server.php#core_completion_mark_course_self_completed | Update the course completion status for the current user (if course self-completion is enabled).
*DefaultApi* | [**core_completion_override_activity_completion_status**](docs/DefaultApi.md#core_completion_override_activity_completion_status) | **POST** /webservice/rest/server.php#core_completion_override_activity_completion_status | Update completion status for a user in an activity by overriding it.
*DefaultApi* | [**core_completion_update_activity_completion_status_manually**](docs/DefaultApi.md#core_completion_update_activity_completion_status_manually) | **POST** /webservice/rest/server.php#core_completion_update_activity_completion_status_manually | Update completion status for the current user in an activity, only for activities with manual tracking.
*DefaultApi* | [**core_contentbank_copy_content**](docs/DefaultApi.md#core_contentbank_copy_content) | **POST** /webservice/rest/server.php#core_contentbank_copy_content | Copy a content in the content bank.
*DefaultApi* | [**core_contentbank_delete_content**](docs/DefaultApi.md#core_contentbank_delete_content) | **POST** /webservice/rest/server.php#core_contentbank_delete_content | Delete a content from the content bank.
*DefaultApi* | [**core_contentbank_rename_content**](docs/DefaultApi.md#core_contentbank_rename_content) | **POST** /webservice/rest/server.php#core_contentbank_rename_content | Rename a content in the content bank.
*DefaultApi* | [**core_contentbank_set_content_visibility**](docs/DefaultApi.md#core_contentbank_set_content_visibility) | **POST** /webservice/rest/server.php#core_contentbank_set_content_visibility | Set the visibility of a content in the content bank.
*DefaultApi* | [**core_course_add_content_item_to_user_favourites**](docs/DefaultApi.md#core_course_add_content_item_to_user_favourites) | **POST** /webservice/rest/server.php#core_course_add_content_item_to_user_favourites | Adds a content item (activity, resource or their subtypes) to the favourites for the user.
*DefaultApi* | [**core_course_check_updates**](docs/DefaultApi.md#core_course_check_updates) | **POST** /webservice/rest/server.php#core_course_check_updates | Check if there is updates affecting the user for the given course and contexts.
*DefaultApi* | [**core_course_create_categories**](docs/DefaultApi.md#core_course_create_categories) | **POST** /webservice/rest/server.php#core_course_create_categories | Create course categories
*DefaultApi* | [**core_course_create_courses**](docs/DefaultApi.md#core_course_create_courses) | **POST** /webservice/rest/server.php#core_course_create_courses | Create new courses
*DefaultApi* | [**core_course_delete_categories**](docs/DefaultApi.md#core_course_delete_categories) | **POST** /webservice/rest/server.php#core_course_delete_categories | Delete course categories
*DefaultApi* | [**core_course_delete_courses**](docs/DefaultApi.md#core_course_delete_courses) | **POST** /webservice/rest/server.php#core_course_delete_courses | Deletes all specified courses
*DefaultApi* | [**core_course_delete_modules**](docs/DefaultApi.md#core_course_delete_modules) | **POST** /webservice/rest/server.php#core_course_delete_modules | Deletes all specified module instances
*DefaultApi* | [**core_course_duplicate_course**](docs/DefaultApi.md#core_course_duplicate_course) | **POST** /webservice/rest/server.php#core_course_duplicate_course | Duplicate an existing course (creating a new one).
*DefaultApi* | [**core_course_edit_module**](docs/DefaultApi.md#core_course_edit_module) | **POST** /webservice/rest/server.php#core_course_edit_module | ** DEPRECATED ** Please do not call this function any more (will be removed in Moodle 6.0). Performs an action on course module (change visibility, duplicate, delete, etc.) Use core_courseformat_update_course instead.
*DefaultApi* | [**core_course_edit_section**](docs/DefaultApi.md#core_course_edit_section) | **POST** /webservice/rest/server.php#core_course_edit_section | ** DEPRECATED ** Please do not call this function any more (will be removed in Moodle 6.0).Performs an action on course section (change visibility, set marker, delete) Use core_courseformat_update_course instead.
*DefaultApi* | [**core_course_get_activity_chooser_footer**](docs/DefaultApi.md#core_course_get_activity_chooser_footer) | **POST** /webservice/rest/server.php#core_course_get_activity_chooser_footer | Fetch the data for the activity chooser footer.
*DefaultApi* | [**core_course_get_categories**](docs/DefaultApi.md#core_course_get_categories) | **POST** /webservice/rest/server.php#core_course_get_categories | Return category details
*DefaultApi* | [**core_course_get_contents**](docs/DefaultApi.md#core_course_get_contents) | **POST** /webservice/rest/server.php#core_course_get_contents | Get course contents
*DefaultApi* | [**core_course_get_course_content_items**](docs/DefaultApi.md#core_course_get_course_content_items) | **POST** /webservice/rest/server.php#core_course_get_course_content_items | Fetch all the content items (activities, resources and their subtypes) for the activity picker
*DefaultApi* | [**core_course_get_course_module**](docs/DefaultApi.md#core_course_get_course_module) | **POST** /webservice/rest/server.php#core_course_get_course_module | Return information about a course module
*DefaultApi* | [**core_course_get_course_module_by_instance**](docs/DefaultApi.md#core_course_get_course_module_by_instance) | **POST** /webservice/rest/server.php#core_course_get_course_module_by_instance | Return information about a given module name and instance id
*DefaultApi* | [**core_course_get_courses**](docs/DefaultApi.md#core_course_get_courses) | **POST** /webservice/rest/server.php#core_course_get_courses | Return course details
*DefaultApi* | [**core_course_get_courses_by_field**](docs/DefaultApi.md#core_course_get_courses_by_field) | **POST** /webservice/rest/server.php#core_course_get_courses_by_field | Get courses matching a specific field (id/s, shortname, idnumber, category)
*DefaultApi* | [**core_course_get_enrolled_courses_by_timeline_classification**](docs/DefaultApi.md#core_course_get_enrolled_courses_by_timeline_classification) | **POST** /webservice/rest/server.php#core_course_get_enrolled_courses_by_timeline_classification | List of enrolled courses for the given timeline classification (past, inprogress, or future).
*DefaultApi* | [**core_course_get_enrolled_courses_with_action_events_by_timeline_classification**](docs/DefaultApi.md#core_course_get_enrolled_courses_with_action_events_by_timeline_classification) | **POST** /webservice/rest/server.php#core_course_get_enrolled_courses_with_action_events_by_timeline_classification | List of enrolled courses with action events in a given timeframe, for the given timeline classification.
*DefaultApi* | [**core_course_get_enrolled_users_by_cmid**](docs/DefaultApi.md#core_course_get_enrolled_users_by_cmid) | **POST** /webservice/rest/server.php#core_course_get_enrolled_users_by_cmid | List users by course module id, filter by group and active enrolment status.
*DefaultApi* | [**core_course_get_module**](docs/DefaultApi.md#core_course_get_module) | **POST** /webservice/rest/server.php#core_course_get_module | ** DEPRECATED ** Please do not call this function any more (will be removed in Moodle 6.0).Returns html with one activity module on course page.Use fragment API using component core_courseformat and fragment cmitem instead.
*DefaultApi* | [**core_course_get_recent_courses**](docs/DefaultApi.md#core_course_get_recent_courses) | **POST** /webservice/rest/server.php#core_course_get_recent_courses | List of courses a user has accessed most recently.
*DefaultApi* | [**core_course_get_updates_since**](docs/DefaultApi.md#core_course_get_updates_since) | **POST** /webservice/rest/server.php#core_course_get_updates_since | Check if there are updates affecting the user for the given course since the given time stamp.
*DefaultApi* | [**core_course_get_user_administration_options**](docs/DefaultApi.md#core_course_get_user_administration_options) | **POST** /webservice/rest/server.php#core_course_get_user_administration_options | Return a list of administration options in a set of courses that are avaialable or not for the current                             user.
*DefaultApi* | [**core_course_get_user_navigation_options**](docs/DefaultApi.md#core_course_get_user_navigation_options) | **POST** /webservice/rest/server.php#core_course_get_user_navigation_options | Return a list of navigation options in a set of courses that are avaialable or not for the current user.
*DefaultApi* | [**core_course_import_course**](docs/DefaultApi.md#core_course_import_course) | **POST** /webservice/rest/server.php#core_course_import_course | Import course data from a course into another course. Does not include any user data.
*DefaultApi* | [**core_course_remove_content_item_from_user_favourites**](docs/DefaultApi.md#core_course_remove_content_item_from_user_favourites) | **POST** /webservice/rest/server.php#core_course_remove_content_item_from_user_favourites | Removes a content item (activity, resource or their subtypes) from the favourites for the user.
*DefaultApi* | [**core_course_search_courses**](docs/DefaultApi.md#core_course_search_courses) | **POST** /webservice/rest/server.php#core_course_search_courses | Search courses by (name, module, block, tag)
*DefaultApi* | [**core_course_set_favourite_courses**](docs/DefaultApi.md#core_course_set_favourite_courses) | **POST** /webservice/rest/server.php#core_course_set_favourite_courses | Add a list of courses to the list of favourite courses.
*DefaultApi* | [**core_course_toggle_activity_recommendation**](docs/DefaultApi.md#core_course_toggle_activity_recommendation) | **POST** /webservice/rest/server.php#core_course_toggle_activity_recommendation | Adds or removes an activity as a recommendation in the activity chooser.
*DefaultApi* | [**core_course_update_categories**](docs/DefaultApi.md#core_course_update_categories) | **POST** /webservice/rest/server.php#core_course_update_categories | Update categories
*DefaultApi* | [**core_course_update_courses**](docs/DefaultApi.md#core_course_update_courses) | **POST** /webservice/rest/server.php#core_course_update_courses | Update courses
*DefaultApi* | [**core_course_view_course**](docs/DefaultApi.md#core_course_view_course) | **POST** /webservice/rest/server.php#core_course_view_course | Log that the course was viewed
*DefaultApi* | [**core_courseformat_create_module**](docs/DefaultApi.md#core_courseformat_create_module) | **POST** /webservice/rest/server.php#core_courseformat_create_module | ** DEPRECATED ** Please do not call this function any more. Use core_courseformat_new_module instead. Add module to course.
*DefaultApi* | [**core_courseformat_file_handlers**](docs/DefaultApi.md#core_courseformat_file_handlers) | **POST** /webservice/rest/server.php#core_courseformat_file_handlers | Get the current course file hanlders.
*DefaultApi* | [**core_courseformat_get_state**](docs/DefaultApi.md#core_courseformat_get_state) | **POST** /webservice/rest/server.php#core_courseformat_get_state | Get the current course state.
*DefaultApi* | [**core_courseformat_new_module**](docs/DefaultApi.md#core_courseformat_new_module) | **POST** /webservice/rest/server.php#core_courseformat_new_module | Create a new module to course.
*DefaultApi* | [**core_courseformat_update_course**](docs/DefaultApi.md#core_courseformat_update_course) | **POST** /webservice/rest/server.php#core_courseformat_update_course | Update course contents.
*DefaultApi* | [**core_create_userfeedback_action_record**](docs/DefaultApi.md#core_create_userfeedback_action_record) | **POST** /webservice/rest/server.php#core_create_userfeedback_action_record | Record the action that the user takes in the user feedback notification for future use.
*DefaultApi* | [**core_customfield_create_category**](docs/DefaultApi.md#core_customfield_create_category) | **POST** /webservice/rest/server.php#core_customfield_create_category | Creates a new category
*DefaultApi* | [**core_customfield_delete_category**](docs/DefaultApi.md#core_customfield_delete_category) | **POST** /webservice/rest/server.php#core_customfield_delete_category | Deletes a category
*DefaultApi* | [**core_customfield_delete_field**](docs/DefaultApi.md#core_customfield_delete_field) | **POST** /webservice/rest/server.php#core_customfield_delete_field | Deletes an entry
*DefaultApi* | [**core_customfield_move_category**](docs/DefaultApi.md#core_customfield_move_category) | **POST** /webservice/rest/server.php#core_customfield_move_category | Drag and drop categories
*DefaultApi* | [**core_customfield_move_field**](docs/DefaultApi.md#core_customfield_move_field) | **POST** /webservice/rest/server.php#core_customfield_move_field | Drag and drop
*DefaultApi* | [**core_customfield_reload_template**](docs/DefaultApi.md#core_customfield_reload_template) | **POST** /webservice/rest/server.php#core_customfield_reload_template | Reloads template
*DefaultApi* | [**core_dynamic_tabs_get_content**](docs/DefaultApi.md#core_dynamic_tabs_get_content) | **POST** /webservice/rest/server.php#core_dynamic_tabs_get_content | Returns the content for a dynamic tab
*DefaultApi* | [**core_enrol_get_course_enrolment_methods**](docs/DefaultApi.md#core_enrol_get_course_enrolment_methods) | **POST** /webservice/rest/server.php#core_enrol_get_course_enrolment_methods | Get the list of course enrolment methods
*DefaultApi* | [**core_enrol_get_enrolled_users**](docs/DefaultApi.md#core_enrol_get_enrolled_users) | **POST** /webservice/rest/server.php#core_enrol_get_enrolled_users | Get enrolled users by course id.
*DefaultApi* | [**core_enrol_get_enrolled_users_with_capability**](docs/DefaultApi.md#core_enrol_get_enrolled_users_with_capability) | **POST** /webservice/rest/server.php#core_enrol_get_enrolled_users_with_capability | For each course and capability specified, return a list of the users that are enrolled in the course                                   and have that capability
*DefaultApi* | [**core_enrol_get_potential_users**](docs/DefaultApi.md#core_enrol_get_potential_users) | **POST** /webservice/rest/server.php#core_enrol_get_potential_users | Get the list of potential users to enrol
*DefaultApi* | [**core_enrol_get_users_courses**](docs/DefaultApi.md#core_enrol_get_users_courses) | **POST** /webservice/rest/server.php#core_enrol_get_users_courses | Get the list of courses where a user is enrolled in
*DefaultApi* | [**core_enrol_search_users**](docs/DefaultApi.md#core_enrol_search_users) | **POST** /webservice/rest/server.php#core_enrol_search_users | Search within the list of course participants
*DefaultApi* | [**core_enrol_submit_user_enrolment_form**](docs/DefaultApi.md#core_enrol_submit_user_enrolment_form) | **POST** /webservice/rest/server.php#core_enrol_submit_user_enrolment_form | Submit form data for enrolment form
*DefaultApi* | [**core_enrol_unenrol_user_enrolment**](docs/DefaultApi.md#core_enrol_unenrol_user_enrolment) | **POST** /webservice/rest/server.php#core_enrol_unenrol_user_enrolment | External function that unenrols a given user enrolment
*DefaultApi* | [**core_fetch_notifications**](docs/DefaultApi.md#core_fetch_notifications) | **GET** /lib/ajax/service-nologin.php#core_fetch_notifications | Return a list of notifications for the current session
*DefaultApi* | [**core_files_delete_draft_files**](docs/DefaultApi.md#core_files_delete_draft_files) | **POST** /webservice/rest/server.php#core_files_delete_draft_files | Delete the indicated files (or directories) from a user draft file area.
*DefaultApi* | [**core_files_get_files**](docs/DefaultApi.md#core_files_get_files) | **POST** /webservice/rest/server.php#core_files_get_files | browse moodle files
*DefaultApi* | [**core_files_get_unused_draft_itemid**](docs/DefaultApi.md#core_files_get_unused_draft_itemid) | **POST** /webservice/rest/server.php#core_files_get_unused_draft_itemid | Generate a new draft itemid for the current user.
*DefaultApi* | [**core_files_upload**](docs/DefaultApi.md#core_files_upload) | **POST** /webservice/rest/server.php#core_files_upload | upload a file to moodle
*DefaultApi* | [**core_filters_get_all_states**](docs/DefaultApi.md#core_filters_get_all_states) | **POST** /webservice/rest/server.php#core_filters_get_all_states | Retrieve all the filters and their states (including overridden ones in any context).
*DefaultApi* | [**core_filters_get_available_in_context**](docs/DefaultApi.md#core_filters_get_available_in_context) | **POST** /webservice/rest/server.php#core_filters_get_available_in_context | Returns the filters available in the given contexts.
*DefaultApi* | [**core_form_dynamic_form**](docs/DefaultApi.md#core_form_dynamic_form) | **POST** /webservice/rest/server.php#core_form_dynamic_form | Process submission of a dynamic (modal) form
*DefaultApi* | [**core_form_get_filetypes_browser_data**](docs/DefaultApi.md#core_form_get_filetypes_browser_data) | **GET** /lib/ajax/service-nologin.php#core_form_get_filetypes_browser_data | Provides data for the filetypes element browser.
*DefaultApi* | [**core_get_component_strings**](docs/DefaultApi.md#core_get_component_strings) | **GET** /lib/ajax/service-nologin.php#core_get_component_strings | Return all raw strings (with {$a-&gt;xxx}), for a specific component - similar to core get_component_strings(), call
*DefaultApi* | [**core_get_fragment**](docs/DefaultApi.md#core_get_fragment) | **POST** /webservice/rest/server.php#core_get_fragment | Return a fragment for inclusion, such as a JavaScript page.
*DefaultApi* | [**core_get_string**](docs/DefaultApi.md#core_get_string) | **GET** /lib/ajax/service-nologin.php#core_get_string | Return a translated string - similar to core get_string(), call
*DefaultApi* | [**core_get_strings**](docs/DefaultApi.md#core_get_strings) | **GET** /lib/ajax/service-nologin.php#core_get_strings | Return some translated strings - like several core get_string(), calls
*DefaultApi* | [**core_get_user_dates**](docs/DefaultApi.md#core_get_user_dates) | **POST** /webservice/rest/server.php#core_get_user_dates | Return formatted timestamps
*DefaultApi* | [**core_grades_create_gradecategories**](docs/DefaultApi.md#core_grades_create_gradecategories) | **POST** /webservice/rest/server.php#core_grades_create_gradecategories | Create grade categories inside a course gradebook.
*DefaultApi* | [**core_grades_get_enrolled_users_for_selector**](docs/DefaultApi.md#core_grades_get_enrolled_users_for_selector) | **POST** /webservice/rest/server.php#core_grades_get_enrolled_users_for_selector | Returns the enrolled users within and map some fields to the returned array of user objects.
*DefaultApi* | [**core_grades_get_feedback**](docs/DefaultApi.md#core_grades_get_feedback) | **POST** /webservice/rest/server.php#core_grades_get_feedback | Get the feedback data for a grade item
*DefaultApi* | [**core_grades_get_gradable_users**](docs/DefaultApi.md#core_grades_get_gradable_users) | **POST** /webservice/rest/server.php#core_grades_get_gradable_users | Returns the gradable users in a course
*DefaultApi* | [**core_grades_get_grade_tree**](docs/DefaultApi.md#core_grades_get_grade_tree) | **POST** /webservice/rest/server.php#core_grades_get_grade_tree | Get the grade tree structure for a course
*DefaultApi* | [**core_grades_get_gradeitems**](docs/DefaultApi.md#core_grades_get_gradeitems) | **POST** /webservice/rest/server.php#core_grades_get_gradeitems | Get the gradeitems for a course
*DefaultApi* | [**core_grades_get_groups_for_selector**](docs/DefaultApi.md#core_grades_get_groups_for_selector) | **POST** /webservice/rest/server.php#core_grades_get_groups_for_selector | ** DEPRECATED ** Please do not call this function any more. Use core_group_get_groups_for_selector instead. Get the group/(s) for a course
*DefaultApi* | [**core_grades_grader_gradingpanel_point_fetch**](docs/DefaultApi.md#core_grades_grader_gradingpanel_point_fetch) | **POST** /webservice/rest/server.php#core_grades_grader_gradingpanel_point_fetch | Fetch the data required to display the grader grading panel for simple grading, creating the grade item if required
*DefaultApi* | [**core_grades_grader_gradingpanel_point_store**](docs/DefaultApi.md#core_grades_grader_gradingpanel_point_store) | **POST** /webservice/rest/server.php#core_grades_grader_gradingpanel_point_store | Store the data required to display the grader grading panel for simple grading
*DefaultApi* | [**core_grades_grader_gradingpanel_scale_fetch**](docs/DefaultApi.md#core_grades_grader_gradingpanel_scale_fetch) | **POST** /webservice/rest/server.php#core_grades_grader_gradingpanel_scale_fetch | Fetch the data required to display the grader grading panel for scale-based grading, creating the grade item if required
*DefaultApi* | [**core_grades_grader_gradingpanel_scale_store**](docs/DefaultApi.md#core_grades_grader_gradingpanel_scale_store) | **POST** /webservice/rest/server.php#core_grades_grader_gradingpanel_scale_store | Store the data required to display the grader grading panel for scale-based grading
*DefaultApi* | [**core_grades_update_grades**](docs/DefaultApi.md#core_grades_update_grades) | **POST** /webservice/rest/server.php#core_grades_update_grades | Update a grade item and associated student grades.
*DefaultApi* | [**core_grading_get_definitions**](docs/DefaultApi.md#core_grading_get_definitions) | **POST** /webservice/rest/server.php#core_grading_get_definitions | Get grading definitions
*DefaultApi* | [**core_grading_get_gradingform_instances**](docs/DefaultApi.md#core_grading_get_gradingform_instances) | **POST** /webservice/rest/server.php#core_grading_get_gradingform_instances | Get grading form instances
*DefaultApi* | [**core_grading_save_definitions**](docs/DefaultApi.md#core_grading_save_definitions) | **POST** /webservice/rest/server.php#core_grading_save_definitions | Save grading definitions
*DefaultApi* | [**core_group_add_group_members**](docs/DefaultApi.md#core_group_add_group_members) | **POST** /webservice/rest/server.php#core_group_add_group_members | Adds group members.
*DefaultApi* | [**core_group_assign_grouping**](docs/DefaultApi.md#core_group_assign_grouping) | **POST** /webservice/rest/server.php#core_group_assign_grouping | Assing groups from groupings
*DefaultApi* | [**core_group_create_groupings**](docs/DefaultApi.md#core_group_create_groupings) | **POST** /webservice/rest/server.php#core_group_create_groupings | Creates new groupings
*DefaultApi* | [**core_group_create_groups**](docs/DefaultApi.md#core_group_create_groups) | **POST** /webservice/rest/server.php#core_group_create_groups | Creates new groups.
*DefaultApi* | [**core_group_delete_group_members**](docs/DefaultApi.md#core_group_delete_group_members) | **POST** /webservice/rest/server.php#core_group_delete_group_members | Deletes group members.
*DefaultApi* | [**core_group_delete_groupings**](docs/DefaultApi.md#core_group_delete_groupings) | **POST** /webservice/rest/server.php#core_group_delete_groupings | Deletes all specified groupings.
*DefaultApi* | [**core_group_delete_groups**](docs/DefaultApi.md#core_group_delete_groups) | **POST** /webservice/rest/server.php#core_group_delete_groups | Deletes all specified groups.
*DefaultApi* | [**core_group_get_activity_allowed_groups**](docs/DefaultApi.md#core_group_get_activity_allowed_groups) | **POST** /webservice/rest/server.php#core_group_get_activity_allowed_groups | Gets a list of groups that the user is allowed to access within the specified activity.
*DefaultApi* | [**core_group_get_activity_groupmode**](docs/DefaultApi.md#core_group_get_activity_groupmode) | **POST** /webservice/rest/server.php#core_group_get_activity_groupmode | Returns effective groupmode used in a given activity.
*DefaultApi* | [**core_group_get_course_groupings**](docs/DefaultApi.md#core_group_get_course_groupings) | **POST** /webservice/rest/server.php#core_group_get_course_groupings | Returns all groupings in specified course.
*DefaultApi* | [**core_group_get_course_groups**](docs/DefaultApi.md#core_group_get_course_groups) | **POST** /webservice/rest/server.php#core_group_get_course_groups | Returns all groups in specified course.
*DefaultApi* | [**core_group_get_course_user_groups**](docs/DefaultApi.md#core_group_get_course_user_groups) | **POST** /webservice/rest/server.php#core_group_get_course_user_groups | Returns all groups in specified course for the specified user.
*DefaultApi* | [**core_group_get_group_members**](docs/DefaultApi.md#core_group_get_group_members) | **POST** /webservice/rest/server.php#core_group_get_group_members | Returns group members.
*DefaultApi* | [**core_group_get_groupings**](docs/DefaultApi.md#core_group_get_groupings) | **POST** /webservice/rest/server.php#core_group_get_groupings | Returns groupings details.
*DefaultApi* | [**core_group_get_groups**](docs/DefaultApi.md#core_group_get_groups) | **POST** /webservice/rest/server.php#core_group_get_groups | Returns group details.
*DefaultApi* | [**core_group_get_groups_for_selector**](docs/DefaultApi.md#core_group_get_groups_for_selector) | **POST** /webservice/rest/server.php#core_group_get_groups_for_selector | Get the group/(s) for a course
*DefaultApi* | [**core_group_unassign_grouping**](docs/DefaultApi.md#core_group_unassign_grouping) | **POST** /webservice/rest/server.php#core_group_unassign_grouping | Unassing groups from groupings
*DefaultApi* | [**core_group_update_groupings**](docs/DefaultApi.md#core_group_update_groupings) | **POST** /webservice/rest/server.php#core_group_update_groupings | Updates existing groupings
*DefaultApi* | [**core_group_update_groups**](docs/DefaultApi.md#core_group_update_groups) | **POST** /webservice/rest/server.php#core_group_update_groups | Updates existing groups.
*DefaultApi* | [**core_h5p_get_trusted_h5p_file**](docs/DefaultApi.md#core_h5p_get_trusted_h5p_file) | **POST** /webservice/rest/server.php#core_h5p_get_trusted_h5p_file | Get the H5P file cleaned for Mobile App.
*DefaultApi* | [**core_message_block_user**](docs/DefaultApi.md#core_message_block_user) | **POST** /webservice/rest/server.php#core_message_block_user | Blocks a user
*DefaultApi* | [**core_message_confirm_contact_request**](docs/DefaultApi.md#core_message_confirm_contact_request) | **POST** /webservice/rest/server.php#core_message_confirm_contact_request | Confirms a contact request
*DefaultApi* | [**core_message_create_contact_request**](docs/DefaultApi.md#core_message_create_contact_request) | **POST** /webservice/rest/server.php#core_message_create_contact_request | Creates a contact request
*DefaultApi* | [**core_message_data_for_messagearea_search_messages**](docs/DefaultApi.md#core_message_data_for_messagearea_search_messages) | **POST** /webservice/rest/server.php#core_message_data_for_messagearea_search_messages | Retrieve the template data for searching for messages
*DefaultApi* | [**core_message_decline_contact_request**](docs/DefaultApi.md#core_message_decline_contact_request) | **POST** /webservice/rest/server.php#core_message_decline_contact_request | Declines a contact request
*DefaultApi* | [**core_message_delete_contacts**](docs/DefaultApi.md#core_message_delete_contacts) | **POST** /webservice/rest/server.php#core_message_delete_contacts | Remove contacts from the contact list
*DefaultApi* | [**core_message_delete_conversations_by_id**](docs/DefaultApi.md#core_message_delete_conversations_by_id) | **POST** /webservice/rest/server.php#core_message_delete_conversations_by_id | Deletes a list of conversations.
*DefaultApi* | [**core_message_delete_message**](docs/DefaultApi.md#core_message_delete_message) | **POST** /webservice/rest/server.php#core_message_delete_message | Deletes a message.
*DefaultApi* | [**core_message_delete_message_for_all_users**](docs/DefaultApi.md#core_message_delete_message_for_all_users) | **POST** /webservice/rest/server.php#core_message_delete_message_for_all_users | Deletes a message for all users.
*DefaultApi* | [**core_message_get_blocked_users**](docs/DefaultApi.md#core_message_get_blocked_users) | **POST** /webservice/rest/server.php#core_message_get_blocked_users | Retrieve a list of users blocked
*DefaultApi* | [**core_message_get_contact_requests**](docs/DefaultApi.md#core_message_get_contact_requests) | **POST** /webservice/rest/server.php#core_message_get_contact_requests | Returns contact requests for a user
*DefaultApi* | [**core_message_get_conversation**](docs/DefaultApi.md#core_message_get_conversation) | **POST** /webservice/rest/server.php#core_message_get_conversation | Retrieve a conversation for a user
*DefaultApi* | [**core_message_get_conversation_between_users**](docs/DefaultApi.md#core_message_get_conversation_between_users) | **POST** /webservice/rest/server.php#core_message_get_conversation_between_users | Retrieve a conversation for a user between another user
*DefaultApi* | [**core_message_get_conversation_counts**](docs/DefaultApi.md#core_message_get_conversation_counts) | **POST** /webservice/rest/server.php#core_message_get_conversation_counts | Retrieve a list of conversation counts, indexed by type.
*DefaultApi* | [**core_message_get_conversation_members**](docs/DefaultApi.md#core_message_get_conversation_members) | **POST** /webservice/rest/server.php#core_message_get_conversation_members | Retrieve a list of members in a conversation
*DefaultApi* | [**core_message_get_conversation_messages**](docs/DefaultApi.md#core_message_get_conversation_messages) | **POST** /webservice/rest/server.php#core_message_get_conversation_messages | Retrieve the conversation messages and relevant member information
*DefaultApi* | [**core_message_get_conversations**](docs/DefaultApi.md#core_message_get_conversations) | **POST** /webservice/rest/server.php#core_message_get_conversations | Retrieve a list of conversations for a user
*DefaultApi* | [**core_message_get_member_info**](docs/DefaultApi.md#core_message_get_member_info) | **POST** /webservice/rest/server.php#core_message_get_member_info | Retrieve a user message profiles
*DefaultApi* | [**core_message_get_message_processor**](docs/DefaultApi.md#core_message_get_message_processor) | **POST** /webservice/rest/server.php#core_message_get_message_processor | Get a message processor
*DefaultApi* | [**core_message_get_messages**](docs/DefaultApi.md#core_message_get_messages) | **POST** /webservice/rest/server.php#core_message_get_messages | Retrieve a list of messages sent and received by a user (conversations, notifications or both)
*DefaultApi* | [**core_message_get_received_contact_requests_count**](docs/DefaultApi.md#core_message_get_received_contact_requests_count) | **POST** /webservice/rest/server.php#core_message_get_received_contact_requests_count | Gets the number of received contact requests
*DefaultApi* | [**core_message_get_self_conversation**](docs/DefaultApi.md#core_message_get_self_conversation) | **POST** /webservice/rest/server.php#core_message_get_self_conversation | Retrieve a self-conversation for a user
*DefaultApi* | [**core_message_get_unread_conversation_counts**](docs/DefaultApi.md#core_message_get_unread_conversation_counts) | **POST** /webservice/rest/server.php#core_message_get_unread_conversation_counts | Retrieve a list of unread conversation counts, indexed by type.
*DefaultApi* | [**core_message_get_unread_conversations_count**](docs/DefaultApi.md#core_message_get_unread_conversations_count) | **POST** /webservice/rest/server.php#core_message_get_unread_conversations_count | Retrieve the count of unread conversations for a given user
*DefaultApi* | [**core_message_get_unread_notification_count**](docs/DefaultApi.md#core_message_get_unread_notification_count) | **POST** /webservice/rest/server.php#core_message_get_unread_notification_count | Get number of unread notifications.
*DefaultApi* | [**core_message_get_unsent_message**](docs/DefaultApi.md#core_message_get_unsent_message) | **POST** /webservice/rest/server.php#core_message_get_unsent_message | Get an unsent message string
*DefaultApi* | [**core_message_get_user_contacts**](docs/DefaultApi.md#core_message_get_user_contacts) | **POST** /webservice/rest/server.php#core_message_get_user_contacts | Retrieve the contact list
*DefaultApi* | [**core_message_get_user_message_preferences**](docs/DefaultApi.md#core_message_get_user_message_preferences) | **POST** /webservice/rest/server.php#core_message_get_user_message_preferences | Get the message preferences for a given user.
*DefaultApi* | [**core_message_get_user_notification_preferences**](docs/DefaultApi.md#core_message_get_user_notification_preferences) | **POST** /webservice/rest/server.php#core_message_get_user_notification_preferences | Get the notification preferences for a given user.
*DefaultApi* | [**core_message_mark_all_conversation_messages_as_read**](docs/DefaultApi.md#core_message_mark_all_conversation_messages_as_read) | **POST** /webservice/rest/server.php#core_message_mark_all_conversation_messages_as_read | Mark all conversation messages as read for a given user
*DefaultApi* | [**core_message_mark_all_notifications_as_read**](docs/DefaultApi.md#core_message_mark_all_notifications_as_read) | **POST** /webservice/rest/server.php#core_message_mark_all_notifications_as_read | Mark all notifications as read for a given user
*DefaultApi* | [**core_message_mark_message_read**](docs/DefaultApi.md#core_message_mark_message_read) | **POST** /webservice/rest/server.php#core_message_mark_message_read | Mark a single message as read, trigger message_viewed event.
*DefaultApi* | [**core_message_mark_notification_read**](docs/DefaultApi.md#core_message_mark_notification_read) | **POST** /webservice/rest/server.php#core_message_mark_notification_read | Mark a single notification as read, trigger notification_viewed event.
*DefaultApi* | [**core_message_message_processor_config_form**](docs/DefaultApi.md#core_message_message_processor_config_form) | **POST** /webservice/rest/server.php#core_message_message_processor_config_form | Process the message processor config form
*DefaultApi* | [**core_message_message_search_users**](docs/DefaultApi.md#core_message_message_search_users) | **POST** /webservice/rest/server.php#core_message_message_search_users | Retrieve the data for searching for people
*DefaultApi* | [**core_message_mute_conversations**](docs/DefaultApi.md#core_message_mute_conversations) | **POST** /webservice/rest/server.php#core_message_mute_conversations | Mutes a list of conversations
*DefaultApi* | [**core_message_search_contacts**](docs/DefaultApi.md#core_message_search_contacts) | **POST** /webservice/rest/server.php#core_message_search_contacts | Search for contacts
*DefaultApi* | [**core_message_send_instant_messages**](docs/DefaultApi.md#core_message_send_instant_messages) | **POST** /webservice/rest/server.php#core_message_send_instant_messages | Send instant messages
*DefaultApi* | [**core_message_send_messages_to_conversation**](docs/DefaultApi.md#core_message_send_messages_to_conversation) | **POST** /webservice/rest/server.php#core_message_send_messages_to_conversation | Send messages to an existing conversation between users
*DefaultApi* | [**core_message_set_default_notification**](docs/DefaultApi.md#core_message_set_default_notification) | **POST** /webservice/rest/server.php#core_message_set_default_notification | Set the default value for a given notification preference
*DefaultApi* | [**core_message_set_favourite_conversations**](docs/DefaultApi.md#core_message_set_favourite_conversations) | **POST** /webservice/rest/server.php#core_message_set_favourite_conversations | Mark a conversation or group of conversations as favourites/starred conversations.
*DefaultApi* | [**core_message_set_unsent_message**](docs/DefaultApi.md#core_message_set_unsent_message) | **POST** /webservice/rest/server.php#core_message_set_unsent_message | Store an unsent message string
*DefaultApi* | [**core_message_unblock_user**](docs/DefaultApi.md#core_message_unblock_user) | **POST** /webservice/rest/server.php#core_message_unblock_user | Unblocks a user
*DefaultApi* | [**core_message_unmute_conversations**](docs/DefaultApi.md#core_message_unmute_conversations) | **POST** /webservice/rest/server.php#core_message_unmute_conversations | Unmutes a list of conversations
*DefaultApi* | [**core_message_unset_favourite_conversations**](docs/DefaultApi.md#core_message_unset_favourite_conversations) | **POST** /webservice/rest/server.php#core_message_unset_favourite_conversations | Unset a conversation or group of conversations as favourites/starred conversations.
*DefaultApi* | [**core_moodlenet_auth_check**](docs/DefaultApi.md#core_moodlenet_auth_check) | **POST** /webservice/rest/server.php#core_moodlenet_auth_check | Check a user has authorized for a given MoodleNet site
*DefaultApi* | [**core_moodlenet_get_share_info_activity**](docs/DefaultApi.md#core_moodlenet_get_share_info_activity) | **POST** /webservice/rest/server.php#core_moodlenet_get_share_info_activity | Get information about an activity being shared
*DefaultApi* | [**core_moodlenet_get_shared_course_info**](docs/DefaultApi.md#core_moodlenet_get_shared_course_info) | **POST** /webservice/rest/server.php#core_moodlenet_get_shared_course_info | Get information about an course being shared
*DefaultApi* | [**core_moodlenet_send_activity**](docs/DefaultApi.md#core_moodlenet_send_activity) | **POST** /webservice/rest/server.php#core_moodlenet_send_activity | Send activity to MoodleNet
*DefaultApi* | [**core_moodlenet_send_course**](docs/DefaultApi.md#core_moodlenet_send_course) | **POST** /webservice/rest/server.php#core_moodlenet_send_course | Send course to MoodleNet
*DefaultApi* | [**core_my_view_page**](docs/DefaultApi.md#core_my_view_page) | **POST** /webservice/rest/server.php#core_my_view_page | Trigger the My or Dashboard viewed event.
*DefaultApi* | [**core_notes_create_notes**](docs/DefaultApi.md#core_notes_create_notes) | **POST** /webservice/rest/server.php#core_notes_create_notes | Create notes
*DefaultApi* | [**core_notes_delete_notes**](docs/DefaultApi.md#core_notes_delete_notes) | **POST** /webservice/rest/server.php#core_notes_delete_notes | Delete notes
*DefaultApi* | [**core_notes_get_course_notes**](docs/DefaultApi.md#core_notes_get_course_notes) | **POST** /webservice/rest/server.php#core_notes_get_course_notes | Returns all notes in specified course (or site), for the specified user.
*DefaultApi* | [**core_notes_get_notes**](docs/DefaultApi.md#core_notes_get_notes) | **POST** /webservice/rest/server.php#core_notes_get_notes | Get notes
*DefaultApi* | [**core_notes_update_notes**](docs/DefaultApi.md#core_notes_update_notes) | **POST** /webservice/rest/server.php#core_notes_update_notes | Update notes
*DefaultApi* | [**core_notes_view_notes**](docs/DefaultApi.md#core_notes_view_notes) | **POST** /webservice/rest/server.php#core_notes_view_notes | Simulates the web interface view of notes/index.php: trigger events.
*DefaultApi* | [**core_output_load_fontawesome_icon_system_map**](docs/DefaultApi.md#core_output_load_fontawesome_icon_system_map) | **GET** /lib/ajax/service-nologin.php#core_output_load_fontawesome_icon_system_map | Load the mapping of moodle pix names to fontawesome icon names
*DefaultApi* | [**core_output_load_template**](docs/DefaultApi.md#core_output_load_template) | **GET** /lib/ajax/service-nologin.php#core_output_load_template | Load a template for a renderable
*DefaultApi* | [**core_output_load_template_with_dependencies**](docs/DefaultApi.md#core_output_load_template_with_dependencies) | **GET** /lib/ajax/service-nologin.php#core_output_load_template_with_dependencies | Load a template and its dependencies for a renderable
*DefaultApi* | [**core_output_poll_stored_progress**](docs/DefaultApi.md#core_output_poll_stored_progress) | **POST** /webservice/rest/server.php#core_output_poll_stored_progress | Polls for the current percentage progress of a stored progress object
*DefaultApi* | [**core_payment_get_available_gateways**](docs/DefaultApi.md#core_payment_get_available_gateways) | **POST** /webservice/rest/server.php#core_payment_get_available_gateways | Get the list of payment gateways that support the given component/area
*DefaultApi* | [**core_question_get_random_question_summaries**](docs/DefaultApi.md#core_question_get_random_question_summaries) | **POST** /webservice/rest/server.php#core_question_get_random_question_summaries | Get the random question set for a criteria
*DefaultApi* | [**core_question_move_questions**](docs/DefaultApi.md#core_question_move_questions) | **POST** /webservice/rest/server.php#core_question_move_questions | Bulk move questions to a new category.
*DefaultApi* | [**core_question_search_shared_banks**](docs/DefaultApi.md#core_question_search_shared_banks) | **POST** /webservice/rest/server.php#core_question_search_shared_banks | Get a list of shared question banks filtered by a search term.
*DefaultApi* | [**core_question_update_flag**](docs/DefaultApi.md#core_question_update_flag) | **POST** /webservice/rest/server.php#core_question_update_flag | Update the flag state of a question attempt.
*DefaultApi* | [**core_rating_add_rating**](docs/DefaultApi.md#core_rating_add_rating) | **POST** /webservice/rest/server.php#core_rating_add_rating | Rates an item.
*DefaultApi* | [**core_rating_get_item_ratings**](docs/DefaultApi.md#core_rating_get_item_ratings) | **POST** /webservice/rest/server.php#core_rating_get_item_ratings | Retrieve all the ratings for an item.
*DefaultApi* | [**core_reportbuilder_audiences_delete**](docs/DefaultApi.md#core_reportbuilder_audiences_delete) | **POST** /webservice/rest/server.php#core_reportbuilder_audiences_delete | Delete audience from report
*DefaultApi* | [**core_reportbuilder_can_view_system_report**](docs/DefaultApi.md#core_reportbuilder_can_view_system_report) | **POST** /webservice/rest/server.php#core_reportbuilder_can_view_system_report | Determine access to a system report
*DefaultApi* | [**core_reportbuilder_columns_add**](docs/DefaultApi.md#core_reportbuilder_columns_add) | **POST** /webservice/rest/server.php#core_reportbuilder_columns_add | Add column to report
*DefaultApi* | [**core_reportbuilder_columns_delete**](docs/DefaultApi.md#core_reportbuilder_columns_delete) | **POST** /webservice/rest/server.php#core_reportbuilder_columns_delete | Delete column from report
*DefaultApi* | [**core_reportbuilder_columns_reorder**](docs/DefaultApi.md#core_reportbuilder_columns_reorder) | **POST** /webservice/rest/server.php#core_reportbuilder_columns_reorder | Re-order column within report
*DefaultApi* | [**core_reportbuilder_columns_sort_get**](docs/DefaultApi.md#core_reportbuilder_columns_sort_get) | **POST** /webservice/rest/server.php#core_reportbuilder_columns_sort_get | Retrieve column sorting for report
*DefaultApi* | [**core_reportbuilder_columns_sort_reorder**](docs/DefaultApi.md#core_reportbuilder_columns_sort_reorder) | **POST** /webservice/rest/server.php#core_reportbuilder_columns_sort_reorder | Re-order column sorting within report
*DefaultApi* | [**core_reportbuilder_columns_sort_toggle**](docs/DefaultApi.md#core_reportbuilder_columns_sort_toggle) | **POST** /webservice/rest/server.php#core_reportbuilder_columns_sort_toggle | Toggle sorting of column within report
*DefaultApi* | [**core_reportbuilder_conditions_add**](docs/DefaultApi.md#core_reportbuilder_conditions_add) | **POST** /webservice/rest/server.php#core_reportbuilder_conditions_add | Add condition to report
*DefaultApi* | [**core_reportbuilder_conditions_delete**](docs/DefaultApi.md#core_reportbuilder_conditions_delete) | **POST** /webservice/rest/server.php#core_reportbuilder_conditions_delete | Delete condition from report
*DefaultApi* | [**core_reportbuilder_conditions_reorder**](docs/DefaultApi.md#core_reportbuilder_conditions_reorder) | **POST** /webservice/rest/server.php#core_reportbuilder_conditions_reorder | Re-order condition within report
*DefaultApi* | [**core_reportbuilder_conditions_reset**](docs/DefaultApi.md#core_reportbuilder_conditions_reset) | **POST** /webservice/rest/server.php#core_reportbuilder_conditions_reset | Reset conditions for given report
*DefaultApi* | [**core_reportbuilder_filters_add**](docs/DefaultApi.md#core_reportbuilder_filters_add) | **POST** /webservice/rest/server.php#core_reportbuilder_filters_add | Add filter to report
*DefaultApi* | [**core_reportbuilder_filters_delete**](docs/DefaultApi.md#core_reportbuilder_filters_delete) | **POST** /webservice/rest/server.php#core_reportbuilder_filters_delete | Delete filter from report
*DefaultApi* | [**core_reportbuilder_filters_reorder**](docs/DefaultApi.md#core_reportbuilder_filters_reorder) | **POST** /webservice/rest/server.php#core_reportbuilder_filters_reorder | Re-order filter within report
*DefaultApi* | [**core_reportbuilder_filters_reset**](docs/DefaultApi.md#core_reportbuilder_filters_reset) | **POST** /webservice/rest/server.php#core_reportbuilder_filters_reset | Reset filters for given report
*DefaultApi* | [**core_reportbuilder_list_reports**](docs/DefaultApi.md#core_reportbuilder_list_reports) | **POST** /webservice/rest/server.php#core_reportbuilder_list_reports | List custom reports for current user
*DefaultApi* | [**core_reportbuilder_reports_delete**](docs/DefaultApi.md#core_reportbuilder_reports_delete) | **POST** /webservice/rest/server.php#core_reportbuilder_reports_delete | Delete report
*DefaultApi* | [**core_reportbuilder_reports_get**](docs/DefaultApi.md#core_reportbuilder_reports_get) | **POST** /webservice/rest/server.php#core_reportbuilder_reports_get | Get custom report
*DefaultApi* | [**core_reportbuilder_retrieve_report**](docs/DefaultApi.md#core_reportbuilder_retrieve_report) | **POST** /webservice/rest/server.php#core_reportbuilder_retrieve_report | Retrieve custom report content
*DefaultApi* | [**core_reportbuilder_retrieve_system_report**](docs/DefaultApi.md#core_reportbuilder_retrieve_system_report) | **POST** /webservice/rest/server.php#core_reportbuilder_retrieve_system_report | Retrieve system report content
*DefaultApi* | [**core_reportbuilder_schedules_delete**](docs/DefaultApi.md#core_reportbuilder_schedules_delete) | **POST** /webservice/rest/server.php#core_reportbuilder_schedules_delete | Delete schedule from report
*DefaultApi* | [**core_reportbuilder_schedules_send**](docs/DefaultApi.md#core_reportbuilder_schedules_send) | **POST** /webservice/rest/server.php#core_reportbuilder_schedules_send | Send report schedule
*DefaultApi* | [**core_reportbuilder_schedules_toggle**](docs/DefaultApi.md#core_reportbuilder_schedules_toggle) | **POST** /webservice/rest/server.php#core_reportbuilder_schedules_toggle | Toggle state of report schedule
*DefaultApi* | [**core_reportbuilder_set_filters**](docs/DefaultApi.md#core_reportbuilder_set_filters) | **POST** /webservice/rest/server.php#core_reportbuilder_set_filters | Set filter values for given report
*DefaultApi* | [**core_reportbuilder_view_report**](docs/DefaultApi.md#core_reportbuilder_view_report) | **POST** /webservice/rest/server.php#core_reportbuilder_view_report | Trigger custom report viewed
*DefaultApi* | [**core_role_assign_roles**](docs/DefaultApi.md#core_role_assign_roles) | **POST** /webservice/rest/server.php#core_role_assign_roles | Manual role assignments.
*DefaultApi* | [**core_role_unassign_roles**](docs/DefaultApi.md#core_role_unassign_roles) | **POST** /webservice/rest/server.php#core_role_unassign_roles | Manual role unassignments.
*DefaultApi* | [**core_search_get_relevant_users**](docs/DefaultApi.md#core_search_get_relevant_users) | **POST** /webservice/rest/server.php#core_search_get_relevant_users | Gets relevant users for a search request.
*DefaultApi* | [**core_search_get_results**](docs/DefaultApi.md#core_search_get_results) | **POST** /webservice/rest/server.php#core_search_get_results | Get search results.
*DefaultApi* | [**core_search_get_search_areas_list**](docs/DefaultApi.md#core_search_get_search_areas_list) | **POST** /webservice/rest/server.php#core_search_get_search_areas_list | Get search areas.
*DefaultApi* | [**core_search_get_top_results**](docs/DefaultApi.md#core_search_get_top_results) | **POST** /webservice/rest/server.php#core_search_get_top_results | Get top search results.
*DefaultApi* | [**core_search_view_results**](docs/DefaultApi.md#core_search_view_results) | **POST** /webservice/rest/server.php#core_search_view_results | Trigger view search results event.
*DefaultApi* | [**core_session_time_remaining**](docs/DefaultApi.md#core_session_time_remaining) | **POST** /webservice/rest/server.php#core_session_time_remaining | Count the seconds remaining in this session
*DefaultApi* | [**core_session_touch**](docs/DefaultApi.md#core_session_touch) | **POST** /webservice/rest/server.php#core_session_touch | Keep the users session alive
*DefaultApi* | [**core_sms_set_gateway_status**](docs/DefaultApi.md#core_sms_set_gateway_status) | **POST** /webservice/rest/server.php#core_sms_set_gateway_status | Set the sms gateway status
*DefaultApi* | [**core_table_get_dynamic_table_content**](docs/DefaultApi.md#core_table_get_dynamic_table_content) | **POST** /webservice/rest/server.php#core_table_get_dynamic_table_content | Get the dynamic table content raw html
*DefaultApi* | [**core_tag_get_tag_areas**](docs/DefaultApi.md#core_tag_get_tag_areas) | **POST** /webservice/rest/server.php#core_tag_get_tag_areas | Retrieves existing tag areas.
*DefaultApi* | [**core_tag_get_tag_cloud**](docs/DefaultApi.md#core_tag_get_tag_cloud) | **POST** /webservice/rest/server.php#core_tag_get_tag_cloud | Retrieves a tag cloud for the given collection and/or query search.
*DefaultApi* | [**core_tag_get_tag_collections**](docs/DefaultApi.md#core_tag_get_tag_collections) | **POST** /webservice/rest/server.php#core_tag_get_tag_collections | Retrieves existing tag collections.
*DefaultApi* | [**core_tag_get_tagindex**](docs/DefaultApi.md#core_tag_get_tagindex) | **POST** /webservice/rest/server.php#core_tag_get_tagindex | Gets tag index page for one tag and one tag area
*DefaultApi* | [**core_tag_get_tagindex_per_area**](docs/DefaultApi.md#core_tag_get_tagindex_per_area) | **POST** /webservice/rest/server.php#core_tag_get_tagindex_per_area | Gets tag index page per different areas.
*DefaultApi* | [**core_tag_get_tags**](docs/DefaultApi.md#core_tag_get_tags) | **POST** /webservice/rest/server.php#core_tag_get_tags | Gets tags by their ids
*DefaultApi* | [**core_tag_update_tags**](docs/DefaultApi.md#core_tag_update_tags) | **POST** /webservice/rest/server.php#core_tag_update_tags | Updates tags
*DefaultApi* | [**core_update_inplace_editable**](docs/DefaultApi.md#core_update_inplace_editable) | **POST** /webservice/rest/server.php#core_update_inplace_editable | Generic service to update title
*DefaultApi* | [**core_user_add_user_device**](docs/DefaultApi.md#core_user_add_user_device) | **POST** /webservice/rest/server.php#core_user_add_user_device | Store mobile user devices information for PUSH Notifications.
*DefaultApi* | [**core_user_add_user_private_files**](docs/DefaultApi.md#core_user_add_user_private_files) | **POST** /webservice/rest/server.php#core_user_add_user_private_files | Copy files from a draft area to users private files area.
*DefaultApi* | [**core_user_agree_site_policy**](docs/DefaultApi.md#core_user_agree_site_policy) | **POST** /webservice/rest/server.php#core_user_agree_site_policy | Agree the site policy for the current user.
*DefaultApi* | [**core_user_create_users**](docs/DefaultApi.md#core_user_create_users) | **POST** /webservice/rest/server.php#core_user_create_users | Create users.
*DefaultApi* | [**core_user_delete_users**](docs/DefaultApi.md#core_user_delete_users) | **POST** /webservice/rest/server.php#core_user_delete_users | Delete users.
*DefaultApi* | [**core_user_get_course_user_profiles**](docs/DefaultApi.md#core_user_get_course_user_profiles) | **POST** /webservice/rest/server.php#core_user_get_course_user_profiles | Get course user profiles (each of the profils matching a course id and a user id),.
*DefaultApi* | [**core_user_get_private_files_info**](docs/DefaultApi.md#core_user_get_private_files_info) | **POST** /webservice/rest/server.php#core_user_get_private_files_info | Returns general information about files in the user private files area.
*DefaultApi* | [**core_user_get_user_preferences**](docs/DefaultApi.md#core_user_get_user_preferences) | **POST** /webservice/rest/server.php#core_user_get_user_preferences | Return user preferences.
*DefaultApi* | [**core_user_get_users**](docs/DefaultApi.md#core_user_get_users) | **POST** /webservice/rest/server.php#core_user_get_users | search for users matching the parameters
*DefaultApi* | [**core_user_get_users_by_field**](docs/DefaultApi.md#core_user_get_users_by_field) | **POST** /webservice/rest/server.php#core_user_get_users_by_field | Retrieve users&#39; information for a specified unique field - If you want to do a user search, use core_user_get_users() or core_user_search_identity().
*DefaultApi* | [**core_user_prepare_private_files_for_edition**](docs/DefaultApi.md#core_user_prepare_private_files_for_edition) | **POST** /webservice/rest/server.php#core_user_prepare_private_files_for_edition | Prepares the draft area for user private files.
*DefaultApi* | [**core_user_remove_user_device**](docs/DefaultApi.md#core_user_remove_user_device) | **POST** /webservice/rest/server.php#core_user_remove_user_device | Remove a user device from the Moodle database.
*DefaultApi* | [**core_user_search_identity**](docs/DefaultApi.md#core_user_search_identity) | **POST** /webservice/rest/server.php#core_user_search_identity | Return list of users identities matching the given criteria in their name or other identity fields.
*DefaultApi* | [**core_user_set_user_preferences**](docs/DefaultApi.md#core_user_set_user_preferences) | **GET** /lib/ajax/service-nologin.php#core_user_set_user_preferences | Set user preferences.
*DefaultApi* | [**core_user_update_picture**](docs/DefaultApi.md#core_user_update_picture) | **POST** /webservice/rest/server.php#core_user_update_picture | Update or delete the user picture in the site
*DefaultApi* | [**core_user_update_private_files**](docs/DefaultApi.md#core_user_update_private_files) | **POST** /webservice/rest/server.php#core_user_update_private_files | Copy files from a draft area to users private files area.
*DefaultApi* | [**core_user_update_user_device_public_key**](docs/DefaultApi.md#core_user_update_user_device_public_key) | **POST** /webservice/rest/server.php#core_user_update_user_device_public_key | Store mobile user public key.
*DefaultApi* | [**core_user_update_user_preferences**](docs/DefaultApi.md#core_user_update_user_preferences) | **POST** /webservice/rest/server.php#core_user_update_user_preferences | Update a user&#39;s preferences
*DefaultApi* | [**core_user_update_users**](docs/DefaultApi.md#core_user_update_users) | **POST** /webservice/rest/server.php#core_user_update_users | Update users.
*DefaultApi* | [**core_user_view_user_list**](docs/DefaultApi.md#core_user_view_user_list) | **POST** /webservice/rest/server.php#core_user_view_user_list | Simulates the web-interface view of user/index.php (triggering events),.
*DefaultApi* | [**core_user_view_user_profile**](docs/DefaultApi.md#core_user_view_user_profile) | **POST** /webservice/rest/server.php#core_user_view_user_profile | Simulates the web-interface view of user/view.php and user/profile.php (triggering events),.
*DefaultApi* | [**core_webservice_get_site_info**](docs/DefaultApi.md#core_webservice_get_site_info) | **POST** /webservice/rest/server.php#core_webservice_get_site_info | Return some site info / user info / list web service functions
*DefaultApi* | [**core_xapi_delete_state**](docs/DefaultApi.md#core_xapi_delete_state) | **POST** /webservice/rest/server.php#core_xapi_delete_state | Delete an xAPI state data from an activityId.
*DefaultApi* | [**core_xapi_delete_states**](docs/DefaultApi.md#core_xapi_delete_states) | **POST** /webservice/rest/server.php#core_xapi_delete_states | Delete all xAPI state data from an activityId.
*DefaultApi* | [**core_xapi_get_state**](docs/DefaultApi.md#core_xapi_get_state) | **POST** /webservice/rest/server.php#core_xapi_get_state | Get an xAPI state data from an activityId.
*DefaultApi* | [**core_xapi_get_states**](docs/DefaultApi.md#core_xapi_get_states) | **POST** /webservice/rest/server.php#core_xapi_get_states | Get all state ID from an activityId.
*DefaultApi* | [**core_xapi_post_state**](docs/DefaultApi.md#core_xapi_post_state) | **POST** /webservice/rest/server.php#core_xapi_post_state | Post an xAPI state into an activityId.
*DefaultApi* | [**core_xapi_statement_post**](docs/DefaultApi.md#core_xapi_statement_post) | **POST** /webservice/rest/server.php#core_xapi_statement_post | Post an xAPI statement.
*DefaultApi* | [**customfield_number_recalculate_value**](docs/DefaultApi.md#customfield_number_recalculate_value) | **POST** /webservice/rest/server.php#customfield_number_recalculate_value | This web service is used to recalculate the value of automatically populated number custom field.
*DefaultApi* | [**editor_tiny_get_configuration**](docs/DefaultApi.md#editor_tiny_get_configuration) | **POST** /webservice/rest/server.php#editor_tiny_get_configuration | Returns the TinyMCE configuration for a context.
*DefaultApi* | [**enrol_guest_get_instance_info**](docs/DefaultApi.md#enrol_guest_get_instance_info) | **POST** /webservice/rest/server.php#enrol_guest_get_instance_info | Return guest enrolment instance information.
*DefaultApi* | [**enrol_guest_validate_password**](docs/DefaultApi.md#enrol_guest_validate_password) | **POST** /webservice/rest/server.php#enrol_guest_validate_password | Perform password validation.
*DefaultApi* | [**enrol_manual_enrol_users**](docs/DefaultApi.md#enrol_manual_enrol_users) | **POST** /webservice/rest/server.php#enrol_manual_enrol_users | Manual enrol users
*DefaultApi* | [**enrol_manual_unenrol_users**](docs/DefaultApi.md#enrol_manual_unenrol_users) | **POST** /webservice/rest/server.php#enrol_manual_unenrol_users | Manual unenrol users
*DefaultApi* | [**enrol_meta_add_instances**](docs/DefaultApi.md#enrol_meta_add_instances) | **POST** /webservice/rest/server.php#enrol_meta_add_instances | Add meta enrolment instances
*DefaultApi* | [**enrol_meta_delete_instances**](docs/DefaultApi.md#enrol_meta_delete_instances) | **POST** /webservice/rest/server.php#enrol_meta_delete_instances | Delete meta enrolment instances
*DefaultApi* | [**enrol_self_enrol_user**](docs/DefaultApi.md#enrol_self_enrol_user) | **POST** /webservice/rest/server.php#enrol_self_enrol_user | Self enrol the current user in the given course.
*DefaultApi* | [**enrol_self_get_instance_info**](docs/DefaultApi.md#enrol_self_get_instance_info) | **POST** /webservice/rest/server.php#enrol_self_get_instance_info | self enrolment instance information.
*DefaultApi* | [**gradereport_grader_get_users_in_report**](docs/DefaultApi.md#gradereport_grader_get_users_in_report) | **POST** /webservice/rest/server.php#gradereport_grader_get_users_in_report | Returns the dataset of users within the report
*DefaultApi* | [**gradereport_overview_get_course_grades**](docs/DefaultApi.md#gradereport_overview_get_course_grades) | **POST** /webservice/rest/server.php#gradereport_overview_get_course_grades | Get the given user courses final grades
*DefaultApi* | [**gradereport_overview_view_grade_report**](docs/DefaultApi.md#gradereport_overview_view_grade_report) | **POST** /webservice/rest/server.php#gradereport_overview_view_grade_report | Trigger the report view event
*DefaultApi* | [**gradereport_singleview_get_grade_items_for_search_widget**](docs/DefaultApi.md#gradereport_singleview_get_grade_items_for_search_widget) | **POST** /webservice/rest/server.php#gradereport_singleview_get_grade_items_for_search_widget | Get the gradeitem/(s) for a course
*DefaultApi* | [**gradereport_user_get_access_information**](docs/DefaultApi.md#gradereport_user_get_access_information) | **POST** /webservice/rest/server.php#gradereport_user_get_access_information | Returns user access information for the user grade report.
*DefaultApi* | [**gradereport_user_get_grade_items**](docs/DefaultApi.md#gradereport_user_get_grade_items) | **POST** /webservice/rest/server.php#gradereport_user_get_grade_items | Returns the complete list of grade items for users in a course
*DefaultApi* | [**gradereport_user_get_grades_table**](docs/DefaultApi.md#gradereport_user_get_grades_table) | **POST** /webservice/rest/server.php#gradereport_user_get_grades_table | Get the user/s report grades table for a course
*DefaultApi* | [**gradereport_user_view_grade_report**](docs/DefaultApi.md#gradereport_user_view_grade_report) | **POST** /webservice/rest/server.php#gradereport_user_view_grade_report | Trigger the report view event
*DefaultApi* | [**gradingform_guide_grader_gradingpanel_fetch**](docs/DefaultApi.md#gradingform_guide_grader_gradingpanel_fetch) | **POST** /webservice/rest/server.php#gradingform_guide_grader_gradingpanel_fetch | Fetch the data required to display the grader grading panel, creating the grade item if required
*DefaultApi* | [**gradingform_guide_grader_gradingpanel_store**](docs/DefaultApi.md#gradingform_guide_grader_gradingpanel_store) | **POST** /webservice/rest/server.php#gradingform_guide_grader_gradingpanel_store | Store the grading data for a user from the grader grading panel.
*DefaultApi* | [**gradingform_rubric_grader_gradingpanel_fetch**](docs/DefaultApi.md#gradingform_rubric_grader_gradingpanel_fetch) | **POST** /webservice/rest/server.php#gradingform_rubric_grader_gradingpanel_fetch | Fetch the data required to display the grader grading panel, creating the grade item if required
*DefaultApi* | [**gradingform_rubric_grader_gradingpanel_store**](docs/DefaultApi.md#gradingform_rubric_grader_gradingpanel_store) | **POST** /webservice/rest/server.php#gradingform_rubric_grader_gradingpanel_store | Store the grading data for a user from the grader grading panel.
*DefaultApi* | [**login_token**](docs/DefaultApi.md#login_token) | **POST** /login/token.php | 
*DefaultApi* | [**media_videojs_get_language**](docs/DefaultApi.md#media_videojs_get_language) | **GET** /lib/ajax/service-nologin.php#media_videojs_get_language | get language.
*DefaultApi* | [**message_airnotifier_are_notification_preferences_configured**](docs/DefaultApi.md#message_airnotifier_are_notification_preferences_configured) | **POST** /webservice/rest/server.php#message_airnotifier_are_notification_preferences_configured | Check if the users have notification preferences configured yet
*DefaultApi* | [**message_airnotifier_enable_device**](docs/DefaultApi.md#message_airnotifier_enable_device) | **POST** /webservice/rest/server.php#message_airnotifier_enable_device | Enables or disables a registered user device so it can receive Push notifications
*DefaultApi* | [**message_airnotifier_get_user_devices**](docs/DefaultApi.md#message_airnotifier_get_user_devices) | **POST** /webservice/rest/server.php#message_airnotifier_get_user_devices | Return the list of mobile devices that are registered in Moodle for the given user
*DefaultApi* | [**message_airnotifier_is_system_configured**](docs/DefaultApi.md#message_airnotifier_is_system_configured) | **POST** /webservice/rest/server.php#message_airnotifier_is_system_configured | Check whether the airnotifier settings have been configured
*DefaultApi* | [**message_popup_get_popup_notifications**](docs/DefaultApi.md#message_popup_get_popup_notifications) | **POST** /webservice/rest/server.php#message_popup_get_popup_notifications | Retrieve a list of popup notifications for a user
*DefaultApi* | [**message_popup_get_unread_popup_notification_count**](docs/DefaultApi.md#message_popup_get_unread_popup_notification_count) | **POST** /webservice/rest/server.php#message_popup_get_unread_popup_notification_count | Retrieve the count of unread popup notifications for a given user
*DefaultApi* | [**mod_assign_copy_previous_attempt**](docs/DefaultApi.md#mod_assign_copy_previous_attempt) | **POST** /webservice/rest/server.php#mod_assign_copy_previous_attempt | Copy a students previous attempt to a new attempt.
*DefaultApi* | [**mod_assign_get_assignments**](docs/DefaultApi.md#mod_assign_get_assignments) | **POST** /webservice/rest/server.php#mod_assign_get_assignments | Returns the courses and assignments for the users capability
*DefaultApi* | [**mod_assign_get_grades**](docs/DefaultApi.md#mod_assign_get_grades) | **POST** /webservice/rest/server.php#mod_assign_get_grades | Returns grades from the assignment
*DefaultApi* | [**mod_assign_get_participant**](docs/DefaultApi.md#mod_assign_get_participant) | **POST** /webservice/rest/server.php#mod_assign_get_participant | Get a participant for an assignment, with some summary info about their submissions.
*DefaultApi* | [**mod_assign_get_submission_status**](docs/DefaultApi.md#mod_assign_get_submission_status) | **POST** /webservice/rest/server.php#mod_assign_get_submission_status | Returns information about an assignment submission status for a given user.
*DefaultApi* | [**mod_assign_get_submissions**](docs/DefaultApi.md#mod_assign_get_submissions) | **POST** /webservice/rest/server.php#mod_assign_get_submissions | Returns the submissions for assignments
*DefaultApi* | [**mod_assign_get_user_flags**](docs/DefaultApi.md#mod_assign_get_user_flags) | **POST** /webservice/rest/server.php#mod_assign_get_user_flags | Returns the user flags for assignments
*DefaultApi* | [**mod_assign_get_user_mappings**](docs/DefaultApi.md#mod_assign_get_user_mappings) | **POST** /webservice/rest/server.php#mod_assign_get_user_mappings | Returns the blind marking mappings for assignments
*DefaultApi* | [**mod_assign_list_participants**](docs/DefaultApi.md#mod_assign_list_participants) | **POST** /webservice/rest/server.php#mod_assign_list_participants | List the participants for a single assignment, with some summary info about their submissions.
*DefaultApi* | [**mod_assign_lock_submissions**](docs/DefaultApi.md#mod_assign_lock_submissions) | **POST** /webservice/rest/server.php#mod_assign_lock_submissions | Prevent students from making changes to a list of submissions
*DefaultApi* | [**mod_assign_remove_submission**](docs/DefaultApi.md#mod_assign_remove_submission) | **POST** /webservice/rest/server.php#mod_assign_remove_submission | Remove submission.
*DefaultApi* | [**mod_assign_reveal_identities**](docs/DefaultApi.md#mod_assign_reveal_identities) | **POST** /webservice/rest/server.php#mod_assign_reveal_identities | Reveal the identities for a blind marking assignment
*DefaultApi* | [**mod_assign_revert_submissions_to_draft**](docs/DefaultApi.md#mod_assign_revert_submissions_to_draft) | **POST** /webservice/rest/server.php#mod_assign_revert_submissions_to_draft | Reverts the list of submissions to draft status
*DefaultApi* | [**mod_assign_save_grade**](docs/DefaultApi.md#mod_assign_save_grade) | **POST** /webservice/rest/server.php#mod_assign_save_grade | Save a grade update for a single student.
*DefaultApi* | [**mod_assign_save_grades**](docs/DefaultApi.md#mod_assign_save_grades) | **POST** /webservice/rest/server.php#mod_assign_save_grades | Save multiple grade updates for an assignment.
*DefaultApi* | [**mod_assign_save_submission**](docs/DefaultApi.md#mod_assign_save_submission) | **POST** /webservice/rest/server.php#mod_assign_save_submission | Update the current students submission
*DefaultApi* | [**mod_assign_save_user_extensions**](docs/DefaultApi.md#mod_assign_save_user_extensions) | **POST** /webservice/rest/server.php#mod_assign_save_user_extensions | Save a list of assignment extensions
*DefaultApi* | [**mod_assign_set_user_flags**](docs/DefaultApi.md#mod_assign_set_user_flags) | **POST** /webservice/rest/server.php#mod_assign_set_user_flags | Creates or updates user flags
*DefaultApi* | [**mod_assign_start_submission**](docs/DefaultApi.md#mod_assign_start_submission) | **POST** /webservice/rest/server.php#mod_assign_start_submission | Start a submission for user if assignment has a time limit.
*DefaultApi* | [**mod_assign_submit_for_grading**](docs/DefaultApi.md#mod_assign_submit_for_grading) | **POST** /webservice/rest/server.php#mod_assign_submit_for_grading | Submit the current students assignment for grading
*DefaultApi* | [**mod_assign_submit_grading_form**](docs/DefaultApi.md#mod_assign_submit_grading_form) | **POST** /webservice/rest/server.php#mod_assign_submit_grading_form | Submit the grading form data via ajax
*DefaultApi* | [**mod_assign_unlock_submissions**](docs/DefaultApi.md#mod_assign_unlock_submissions) | **POST** /webservice/rest/server.php#mod_assign_unlock_submissions | Allow students to make changes to a list of submissions
*DefaultApi* | [**mod_assign_view_assign**](docs/DefaultApi.md#mod_assign_view_assign) | **POST** /webservice/rest/server.php#mod_assign_view_assign | Update the module completion status.
*DefaultApi* | [**mod_assign_view_grading_table**](docs/DefaultApi.md#mod_assign_view_grading_table) | **POST** /webservice/rest/server.php#mod_assign_view_grading_table | Trigger the grading_table_viewed event.
*DefaultApi* | [**mod_assign_view_submission_status**](docs/DefaultApi.md#mod_assign_view_submission_status) | **POST** /webservice/rest/server.php#mod_assign_view_submission_status | Trigger the submission status viewed event.
*DefaultApi* | [**mod_bigbluebuttonbn_can_join**](docs/DefaultApi.md#mod_bigbluebuttonbn_can_join) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_can_join | Returns information if the current user can join or not.
*DefaultApi* | [**mod_bigbluebuttonbn_completion_validate**](docs/DefaultApi.md#mod_bigbluebuttonbn_completion_validate) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_completion_validate | Validate completion
*DefaultApi* | [**mod_bigbluebuttonbn_end_meeting**](docs/DefaultApi.md#mod_bigbluebuttonbn_end_meeting) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_end_meeting | End a meeting
*DefaultApi* | [**mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses**](docs/DefaultApi.md#mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses | Returns a list of bigbluebuttonbns in a provided list of courses, if no list is provided                             all bigbluebuttonbns that the user can view will be returned.
*DefaultApi* | [**mod_bigbluebuttonbn_get_join_url**](docs/DefaultApi.md#mod_bigbluebuttonbn_get_join_url) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_get_join_url | Get the join URL for the meeting and create if it does not exist.
*DefaultApi* | [**mod_bigbluebuttonbn_get_recordings**](docs/DefaultApi.md#mod_bigbluebuttonbn_get_recordings) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_get_recordings | Returns a list of recordings ready to be processed by a datatable.
*DefaultApi* | [**mod_bigbluebuttonbn_get_recordings_to_import**](docs/DefaultApi.md#mod_bigbluebuttonbn_get_recordings_to_import) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_get_recordings_to_import | Returns a list of recordings ready to import to be processed by a datatable.
*DefaultApi* | [**mod_bigbluebuttonbn_meeting_info**](docs/DefaultApi.md#mod_bigbluebuttonbn_meeting_info) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_meeting_info | Get displayable information on the meeting
*DefaultApi* | [**mod_bigbluebuttonbn_update_recording**](docs/DefaultApi.md#mod_bigbluebuttonbn_update_recording) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_update_recording | Update a single recording
*DefaultApi* | [**mod_bigbluebuttonbn_view_bigbluebuttonbn**](docs/DefaultApi.md#mod_bigbluebuttonbn_view_bigbluebuttonbn) | **POST** /webservice/rest/server.php#mod_bigbluebuttonbn_view_bigbluebuttonbn | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_book_get_books_by_courses**](docs/DefaultApi.md#mod_book_get_books_by_courses) | **POST** /webservice/rest/server.php#mod_book_get_books_by_courses | Returns a list of book instances in a provided set of courses,                             if no courses are provided then all the book instances the user has access to will be returned.
*DefaultApi* | [**mod_book_view_book**](docs/DefaultApi.md#mod_book_view_book) | **POST** /webservice/rest/server.php#mod_book_view_book | Simulate the view.php web interface book: trigger events, completion, etc...
*DefaultApi* | [**mod_choice_delete_choice_responses**](docs/DefaultApi.md#mod_choice_delete_choice_responses) | **POST** /webservice/rest/server.php#mod_choice_delete_choice_responses | Delete the given submitted responses in a choice
*DefaultApi* | [**mod_choice_get_choice_options**](docs/DefaultApi.md#mod_choice_get_choice_options) | **POST** /webservice/rest/server.php#mod_choice_get_choice_options | Retrieve options for a specific choice.
*DefaultApi* | [**mod_choice_get_choice_results**](docs/DefaultApi.md#mod_choice_get_choice_results) | **POST** /webservice/rest/server.php#mod_choice_get_choice_results | Retrieve users results for a given choice.
*DefaultApi* | [**mod_choice_get_choices_by_courses**](docs/DefaultApi.md#mod_choice_get_choices_by_courses) | **POST** /webservice/rest/server.php#mod_choice_get_choices_by_courses | Returns a list of choice instances in a provided set of courses,                             if no courses are provided then all the choice instances the user has access to will be returned.
*DefaultApi* | [**mod_choice_submit_choice_response**](docs/DefaultApi.md#mod_choice_submit_choice_response) | **POST** /webservice/rest/server.php#mod_choice_submit_choice_response | Submit responses to a specific choice item.
*DefaultApi* | [**mod_choice_view_choice**](docs/DefaultApi.md#mod_choice_view_choice) | **POST** /webservice/rest/server.php#mod_choice_view_choice | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_data_add_entry**](docs/DefaultApi.md#mod_data_add_entry) | **POST** /webservice/rest/server.php#mod_data_add_entry | Adds a new entry.
*DefaultApi* | [**mod_data_approve_entry**](docs/DefaultApi.md#mod_data_approve_entry) | **POST** /webservice/rest/server.php#mod_data_approve_entry | Approves or unapproves an entry.
*DefaultApi* | [**mod_data_delete_entry**](docs/DefaultApi.md#mod_data_delete_entry) | **POST** /webservice/rest/server.php#mod_data_delete_entry | Deletes an entry.
*DefaultApi* | [**mod_data_delete_saved_preset**](docs/DefaultApi.md#mod_data_delete_saved_preset) | **POST** /webservice/rest/server.php#mod_data_delete_saved_preset | Delete site user preset.
*DefaultApi* | [**mod_data_get_data_access_information**](docs/DefaultApi.md#mod_data_get_data_access_information) | **POST** /webservice/rest/server.php#mod_data_get_data_access_information | Return access information for a given database.
*DefaultApi* | [**mod_data_get_databases_by_courses**](docs/DefaultApi.md#mod_data_get_databases_by_courses) | **POST** /webservice/rest/server.php#mod_data_get_databases_by_courses | Returns a list of database instances in a provided set of courses, if             no courses are provided then all the database instances the user has access to will be returned.
*DefaultApi* | [**mod_data_get_entries**](docs/DefaultApi.md#mod_data_get_entries) | **POST** /webservice/rest/server.php#mod_data_get_entries | Return the complete list of entries of the given database.
*DefaultApi* | [**mod_data_get_entry**](docs/DefaultApi.md#mod_data_get_entry) | **POST** /webservice/rest/server.php#mod_data_get_entry | Return one entry record from the database, including contents optionally.
*DefaultApi* | [**mod_data_get_fields**](docs/DefaultApi.md#mod_data_get_fields) | **POST** /webservice/rest/server.php#mod_data_get_fields | Return the list of configured fields for the given database.
*DefaultApi* | [**mod_data_get_mapping_information**](docs/DefaultApi.md#mod_data_get_mapping_information) | **POST** /webservice/rest/server.php#mod_data_get_mapping_information | Get importing information
*DefaultApi* | [**mod_data_search_entries**](docs/DefaultApi.md#mod_data_search_entries) | **POST** /webservice/rest/server.php#mod_data_search_entries | Search for entries in the given database.
*DefaultApi* | [**mod_data_update_entry**](docs/DefaultApi.md#mod_data_update_entry) | **POST** /webservice/rest/server.php#mod_data_update_entry | Updates an existing entry.
*DefaultApi* | [**mod_data_view_database**](docs/DefaultApi.md#mod_data_view_database) | **POST** /webservice/rest/server.php#mod_data_view_database | Simulate the view.php web interface data: trigger events, completion, etc...
*DefaultApi* | [**mod_feedback_get_analysis**](docs/DefaultApi.md#mod_feedback_get_analysis) | **POST** /webservice/rest/server.php#mod_feedback_get_analysis | Retrieves the feedback analysis.
*DefaultApi* | [**mod_feedback_get_current_completed_tmp**](docs/DefaultApi.md#mod_feedback_get_current_completed_tmp) | **POST** /webservice/rest/server.php#mod_feedback_get_current_completed_tmp | Returns the temporary completion record for the current user.
*DefaultApi* | [**mod_feedback_get_feedback_access_information**](docs/DefaultApi.md#mod_feedback_get_feedback_access_information) | **POST** /webservice/rest/server.php#mod_feedback_get_feedback_access_information | Return access information for a given feedback.
*DefaultApi* | [**mod_feedback_get_feedbacks_by_courses**](docs/DefaultApi.md#mod_feedback_get_feedbacks_by_courses) | **POST** /webservice/rest/server.php#mod_feedback_get_feedbacks_by_courses | Returns a list of feedbacks in a provided list of courses, if no list is provided all feedbacks that                             the user can view will be returned.
*DefaultApi* | [**mod_feedback_get_finished_responses**](docs/DefaultApi.md#mod_feedback_get_finished_responses) | **POST** /webservice/rest/server.php#mod_feedback_get_finished_responses | Retrieves responses from the last finished attempt.
*DefaultApi* | [**mod_feedback_get_items**](docs/DefaultApi.md#mod_feedback_get_items) | **POST** /webservice/rest/server.php#mod_feedback_get_items | Returns the items (questions) in the given feedback.
*DefaultApi* | [**mod_feedback_get_last_completed**](docs/DefaultApi.md#mod_feedback_get_last_completed) | **POST** /webservice/rest/server.php#mod_feedback_get_last_completed | Retrieves the last completion record for the current user.
*DefaultApi* | [**mod_feedback_get_non_respondents**](docs/DefaultApi.md#mod_feedback_get_non_respondents) | **POST** /webservice/rest/server.php#mod_feedback_get_non_respondents | Retrieves a list of students who didn&#39;t submit the feedback.
*DefaultApi* | [**mod_feedback_get_page_items**](docs/DefaultApi.md#mod_feedback_get_page_items) | **POST** /webservice/rest/server.php#mod_feedback_get_page_items | Get a single feedback page items.
*DefaultApi* | [**mod_feedback_get_responses_analysis**](docs/DefaultApi.md#mod_feedback_get_responses_analysis) | **POST** /webservice/rest/server.php#mod_feedback_get_responses_analysis | Return the feedback user responses analysis.
*DefaultApi* | [**mod_feedback_get_unfinished_responses**](docs/DefaultApi.md#mod_feedback_get_unfinished_responses) | **POST** /webservice/rest/server.php#mod_feedback_get_unfinished_responses | Retrieves responses from the current unfinished attempt.
*DefaultApi* | [**mod_feedback_launch_feedback**](docs/DefaultApi.md#mod_feedback_launch_feedback) | **POST** /webservice/rest/server.php#mod_feedback_launch_feedback | Starts or continues a feedback submission.
*DefaultApi* | [**mod_feedback_process_page**](docs/DefaultApi.md#mod_feedback_process_page) | **POST** /webservice/rest/server.php#mod_feedback_process_page | Process a jump between pages.
*DefaultApi* | [**mod_feedback_questions_reorder**](docs/DefaultApi.md#mod_feedback_questions_reorder) | **POST** /webservice/rest/server.php#mod_feedback_questions_reorder | Saves the new order of the questions in the feedback.
*DefaultApi* | [**mod_feedback_view_feedback**](docs/DefaultApi.md#mod_feedback_view_feedback) | **POST** /webservice/rest/server.php#mod_feedback_view_feedback | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_folder_get_folders_by_courses**](docs/DefaultApi.md#mod_folder_get_folders_by_courses) | **POST** /webservice/rest/server.php#mod_folder_get_folders_by_courses | Returns a list of folders in a provided list of courses, if no list is provided all folders that                             the user can view will be returned. Please note that this WS is not returning the folder contents.
*DefaultApi* | [**mod_folder_view_folder**](docs/DefaultApi.md#mod_folder_view_folder) | **POST** /webservice/rest/server.php#mod_folder_view_folder | Simulate the view.php web interface folder: trigger events, completion, etc...
*DefaultApi* | [**mod_forum_add_discussion**](docs/DefaultApi.md#mod_forum_add_discussion) | **POST** /webservice/rest/server.php#mod_forum_add_discussion | Add a new discussion into an existing forum.
*DefaultApi* | [**mod_forum_add_discussion_post**](docs/DefaultApi.md#mod_forum_add_discussion_post) | **POST** /webservice/rest/server.php#mod_forum_add_discussion_post | Create new posts into an existing discussion.
*DefaultApi* | [**mod_forum_can_add_discussion**](docs/DefaultApi.md#mod_forum_can_add_discussion) | **POST** /webservice/rest/server.php#mod_forum_can_add_discussion | Check if the current user can add discussions in the given forum (and optionally for the given group).
*DefaultApi* | [**mod_forum_delete_post**](docs/DefaultApi.md#mod_forum_delete_post) | **POST** /webservice/rest/server.php#mod_forum_delete_post | Deletes a post or a discussion completely when the post is the discussion topic.
*DefaultApi* | [**mod_forum_get_discussion_post**](docs/DefaultApi.md#mod_forum_get_discussion_post) | **POST** /webservice/rest/server.php#mod_forum_get_discussion_post | Get a particular discussion post.
*DefaultApi* | [**mod_forum_get_discussion_posts**](docs/DefaultApi.md#mod_forum_get_discussion_posts) | **POST** /webservice/rest/server.php#mod_forum_get_discussion_posts | Returns a list of forum posts for a discussion.
*DefaultApi* | [**mod_forum_get_discussion_posts_by_userid**](docs/DefaultApi.md#mod_forum_get_discussion_posts_by_userid) | **POST** /webservice/rest/server.php#mod_forum_get_discussion_posts_by_userid | Returns a list of forum posts for a discussion for a user.
*DefaultApi* | [**mod_forum_get_forum_access_information**](docs/DefaultApi.md#mod_forum_get_forum_access_information) | **POST** /webservice/rest/server.php#mod_forum_get_forum_access_information | Return capabilities information for a given forum.
*DefaultApi* | [**mod_forum_get_forum_discussions**](docs/DefaultApi.md#mod_forum_get_forum_discussions) | **POST** /webservice/rest/server.php#mod_forum_get_forum_discussions | Returns a list of forum discussions optionally sorted and paginated.
*DefaultApi* | [**mod_forum_get_forums_by_courses**](docs/DefaultApi.md#mod_forum_get_forums_by_courses) | **POST** /webservice/rest/server.php#mod_forum_get_forums_by_courses | Returns a list of forum instances in a provided set of courses, if             no courses are provided then all the forum instances the user has access to will be             returned.
*DefaultApi* | [**mod_forum_prepare_draft_area_for_post**](docs/DefaultApi.md#mod_forum_prepare_draft_area_for_post) | **POST** /webservice/rest/server.php#mod_forum_prepare_draft_area_for_post | Prepares a draft area for editing a post.
*DefaultApi* | [**mod_forum_set_lock_state**](docs/DefaultApi.md#mod_forum_set_lock_state) | **POST** /webservice/rest/server.php#mod_forum_set_lock_state | Set the lock state for the discussion
*DefaultApi* | [**mod_forum_set_pin_state**](docs/DefaultApi.md#mod_forum_set_pin_state) | **POST** /webservice/rest/server.php#mod_forum_set_pin_state | Set the pin state
*DefaultApi* | [**mod_forum_set_subscription_state**](docs/DefaultApi.md#mod_forum_set_subscription_state) | **POST** /webservice/rest/server.php#mod_forum_set_subscription_state | Set the subscription state
*DefaultApi* | [**mod_forum_toggle_favourite_state**](docs/DefaultApi.md#mod_forum_toggle_favourite_state) | **POST** /webservice/rest/server.php#mod_forum_toggle_favourite_state | Toggle the favourite state
*DefaultApi* | [**mod_forum_update_discussion_post**](docs/DefaultApi.md#mod_forum_update_discussion_post) | **POST** /webservice/rest/server.php#mod_forum_update_discussion_post | Updates a post or a discussion topic post.
*DefaultApi* | [**mod_forum_view_forum**](docs/DefaultApi.md#mod_forum_view_forum) | **POST** /webservice/rest/server.php#mod_forum_view_forum | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_forum_view_forum_discussion**](docs/DefaultApi.md#mod_forum_view_forum_discussion) | **POST** /webservice/rest/server.php#mod_forum_view_forum_discussion | Trigger the forum discussion viewed event.
*DefaultApi* | [**mod_glossary_add_entry**](docs/DefaultApi.md#mod_glossary_add_entry) | **POST** /webservice/rest/server.php#mod_glossary_add_entry | Add a new entry to a given glossary
*DefaultApi* | [**mod_glossary_delete_entry**](docs/DefaultApi.md#mod_glossary_delete_entry) | **POST** /webservice/rest/server.php#mod_glossary_delete_entry | Delete the given entry from the glossary.
*DefaultApi* | [**mod_glossary_get_authors**](docs/DefaultApi.md#mod_glossary_get_authors) | **POST** /webservice/rest/server.php#mod_glossary_get_authors | Get the authors.
*DefaultApi* | [**mod_glossary_get_categories**](docs/DefaultApi.md#mod_glossary_get_categories) | **POST** /webservice/rest/server.php#mod_glossary_get_categories | Get the categories.
*DefaultApi* | [**mod_glossary_get_entries_by_author**](docs/DefaultApi.md#mod_glossary_get_entries_by_author) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_by_author | Browse entries by author.
*DefaultApi* | [**mod_glossary_get_entries_by_author_id**](docs/DefaultApi.md#mod_glossary_get_entries_by_author_id) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_by_author_id | Browse entries by author ID.
*DefaultApi* | [**mod_glossary_get_entries_by_category**](docs/DefaultApi.md#mod_glossary_get_entries_by_category) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_by_category | Browse entries by category.
*DefaultApi* | [**mod_glossary_get_entries_by_date**](docs/DefaultApi.md#mod_glossary_get_entries_by_date) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_by_date | Browse entries by date.
*DefaultApi* | [**mod_glossary_get_entries_by_letter**](docs/DefaultApi.md#mod_glossary_get_entries_by_letter) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_by_letter | Browse entries by letter.
*DefaultApi* | [**mod_glossary_get_entries_by_search**](docs/DefaultApi.md#mod_glossary_get_entries_by_search) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_by_search | Browse entries by search query.
*DefaultApi* | [**mod_glossary_get_entries_by_term**](docs/DefaultApi.md#mod_glossary_get_entries_by_term) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_by_term | Browse entries by term (concept or alias).
*DefaultApi* | [**mod_glossary_get_entries_to_approve**](docs/DefaultApi.md#mod_glossary_get_entries_to_approve) | **POST** /webservice/rest/server.php#mod_glossary_get_entries_to_approve | Browse entries to be approved.
*DefaultApi* | [**mod_glossary_get_entry_by_id**](docs/DefaultApi.md#mod_glossary_get_entry_by_id) | **POST** /webservice/rest/server.php#mod_glossary_get_entry_by_id | Get an entry by ID
*DefaultApi* | [**mod_glossary_get_glossaries_by_courses**](docs/DefaultApi.md#mod_glossary_get_glossaries_by_courses) | **POST** /webservice/rest/server.php#mod_glossary_get_glossaries_by_courses | Retrieve a list of glossaries from several courses.
*DefaultApi* | [**mod_glossary_prepare_entry_for_edition**](docs/DefaultApi.md#mod_glossary_prepare_entry_for_edition) | **POST** /webservice/rest/server.php#mod_glossary_prepare_entry_for_edition | Prepares the given entry for edition returning draft item areas and file areas information.
*DefaultApi* | [**mod_glossary_update_entry**](docs/DefaultApi.md#mod_glossary_update_entry) | **POST** /webservice/rest/server.php#mod_glossary_update_entry | Updates the given glossary entry.
*DefaultApi* | [**mod_glossary_view_entry**](docs/DefaultApi.md#mod_glossary_view_entry) | **POST** /webservice/rest/server.php#mod_glossary_view_entry | Notify a glossary entry as being viewed.
*DefaultApi* | [**mod_glossary_view_glossary**](docs/DefaultApi.md#mod_glossary_view_glossary) | **POST** /webservice/rest/server.php#mod_glossary_view_glossary | Notify the glossary as being viewed.
*DefaultApi* | [**mod_h5pactivity_get_attempts**](docs/DefaultApi.md#mod_h5pactivity_get_attempts) | **POST** /webservice/rest/server.php#mod_h5pactivity_get_attempts | Return the information needed to list a user attempts.
*DefaultApi* | [**mod_h5pactivity_get_h5pactivities_by_courses**](docs/DefaultApi.md#mod_h5pactivity_get_h5pactivities_by_courses) | **POST** /webservice/rest/server.php#mod_h5pactivity_get_h5pactivities_by_courses | Returns a list of h5p activities in a list of             provided courses, if no list is provided all h5p activities             that the user can view will be returned.
*DefaultApi* | [**mod_h5pactivity_get_h5pactivity_access_information**](docs/DefaultApi.md#mod_h5pactivity_get_h5pactivity_access_information) | **POST** /webservice/rest/server.php#mod_h5pactivity_get_h5pactivity_access_information | Return access information for a given h5p activity.
*DefaultApi* | [**mod_h5pactivity_get_results**](docs/DefaultApi.md#mod_h5pactivity_get_results) | **POST** /webservice/rest/server.php#mod_h5pactivity_get_results | Return the information needed to list a user attempt results.
*DefaultApi* | [**mod_h5pactivity_get_user_attempts**](docs/DefaultApi.md#mod_h5pactivity_get_user_attempts) | **POST** /webservice/rest/server.php#mod_h5pactivity_get_user_attempts | Return the information needed to list all enrolled user attempts.
*DefaultApi* | [**mod_h5pactivity_log_report_viewed**](docs/DefaultApi.md#mod_h5pactivity_log_report_viewed) | **POST** /webservice/rest/server.php#mod_h5pactivity_log_report_viewed | Log that the h5pactivity was viewed.
*DefaultApi* | [**mod_h5pactivity_view_h5pactivity**](docs/DefaultApi.md#mod_h5pactivity_view_h5pactivity) | **POST** /webservice/rest/server.php#mod_h5pactivity_view_h5pactivity | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_imscp_get_imscps_by_courses**](docs/DefaultApi.md#mod_imscp_get_imscps_by_courses) | **POST** /webservice/rest/server.php#mod_imscp_get_imscps_by_courses | Returns a list of IMSCP instances in a provided set of courses,                             if no courses are provided then all the IMSCP instances the user has access to will be returned.
*DefaultApi* | [**mod_imscp_view_imscp**](docs/DefaultApi.md#mod_imscp_view_imscp) | **POST** /webservice/rest/server.php#mod_imscp_view_imscp | Simulate the view.php web interface imscp: trigger events, completion, etc...
*DefaultApi* | [**mod_label_get_labels_by_courses**](docs/DefaultApi.md#mod_label_get_labels_by_courses) | **POST** /webservice/rest/server.php#mod_label_get_labels_by_courses | Returns a list of labels in a provided list of courses, if no list is provided all labels that the user                             can view will be returned.
*DefaultApi* | [**mod_lesson_finish_attempt**](docs/DefaultApi.md#mod_lesson_finish_attempt) | **POST** /webservice/rest/server.php#mod_lesson_finish_attempt | Finishes the current attempt.
*DefaultApi* | [**mod_lesson_get_attempts_overview**](docs/DefaultApi.md#mod_lesson_get_attempts_overview) | **POST** /webservice/rest/server.php#mod_lesson_get_attempts_overview | Get a list of all the attempts made by users in a lesson.
*DefaultApi* | [**mod_lesson_get_content_pages_viewed**](docs/DefaultApi.md#mod_lesson_get_content_pages_viewed) | **POST** /webservice/rest/server.php#mod_lesson_get_content_pages_viewed | Return the list of content pages viewed by a user during a lesson attempt.
*DefaultApi* | [**mod_lesson_get_lesson**](docs/DefaultApi.md#mod_lesson_get_lesson) | **POST** /webservice/rest/server.php#mod_lesson_get_lesson | Return information of a given lesson.
*DefaultApi* | [**mod_lesson_get_lesson_access_information**](docs/DefaultApi.md#mod_lesson_get_lesson_access_information) | **POST** /webservice/rest/server.php#mod_lesson_get_lesson_access_information | Return access information for a given lesson.
*DefaultApi* | [**mod_lesson_get_lessons_by_courses**](docs/DefaultApi.md#mod_lesson_get_lessons_by_courses) | **POST** /webservice/rest/server.php#mod_lesson_get_lessons_by_courses | Returns a list of lessons in a provided list of courses,                             if no list is provided all lessons that the user can view will be returned.
*DefaultApi* | [**mod_lesson_get_page_data**](docs/DefaultApi.md#mod_lesson_get_page_data) | **POST** /webservice/rest/server.php#mod_lesson_get_page_data | Return information of a given page, including its contents.
*DefaultApi* | [**mod_lesson_get_pages**](docs/DefaultApi.md#mod_lesson_get_pages) | **POST** /webservice/rest/server.php#mod_lesson_get_pages | Return the list of pages in a lesson (based on the user permissions).
*DefaultApi* | [**mod_lesson_get_pages_possible_jumps**](docs/DefaultApi.md#mod_lesson_get_pages_possible_jumps) | **POST** /webservice/rest/server.php#mod_lesson_get_pages_possible_jumps | Return all the possible jumps for the pages in a given lesson.
*DefaultApi* | [**mod_lesson_get_questions_attempts**](docs/DefaultApi.md#mod_lesson_get_questions_attempts) | **POST** /webservice/rest/server.php#mod_lesson_get_questions_attempts | Return the list of questions attempts in a given lesson.
*DefaultApi* | [**mod_lesson_get_user_attempt**](docs/DefaultApi.md#mod_lesson_get_user_attempt) | **POST** /webservice/rest/server.php#mod_lesson_get_user_attempt | Return information about the given user attempt (including answers).
*DefaultApi* | [**mod_lesson_get_user_attempt_grade**](docs/DefaultApi.md#mod_lesson_get_user_attempt_grade) | **POST** /webservice/rest/server.php#mod_lesson_get_user_attempt_grade | Return grade information in the attempt for a given user.
*DefaultApi* | [**mod_lesson_get_user_grade**](docs/DefaultApi.md#mod_lesson_get_user_grade) | **POST** /webservice/rest/server.php#mod_lesson_get_user_grade | Return the final grade in the lesson for the given user.
*DefaultApi* | [**mod_lesson_get_user_timers**](docs/DefaultApi.md#mod_lesson_get_user_timers) | **POST** /webservice/rest/server.php#mod_lesson_get_user_timers | Return the timers in the current lesson for the given user.
*DefaultApi* | [**mod_lesson_launch_attempt**](docs/DefaultApi.md#mod_lesson_launch_attempt) | **POST** /webservice/rest/server.php#mod_lesson_launch_attempt | Starts a new attempt or continues an existing one.
*DefaultApi* | [**mod_lesson_process_page**](docs/DefaultApi.md#mod_lesson_process_page) | **POST** /webservice/rest/server.php#mod_lesson_process_page | Processes page responses.
*DefaultApi* | [**mod_lesson_view_lesson**](docs/DefaultApi.md#mod_lesson_view_lesson) | **POST** /webservice/rest/server.php#mod_lesson_view_lesson | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_lti_create_tool_proxy**](docs/DefaultApi.md#mod_lti_create_tool_proxy) | **POST** /webservice/rest/server.php#mod_lti_create_tool_proxy | Create a tool proxy
*DefaultApi* | [**mod_lti_create_tool_type**](docs/DefaultApi.md#mod_lti_create_tool_type) | **POST** /webservice/rest/server.php#mod_lti_create_tool_type | Create a tool type
*DefaultApi* | [**mod_lti_delete_course_tool_type**](docs/DefaultApi.md#mod_lti_delete_course_tool_type) | **POST** /webservice/rest/server.php#mod_lti_delete_course_tool_type | Delete a course tool type
*DefaultApi* | [**mod_lti_delete_tool_proxy**](docs/DefaultApi.md#mod_lti_delete_tool_proxy) | **POST** /webservice/rest/server.php#mod_lti_delete_tool_proxy | Delete a tool proxy
*DefaultApi* | [**mod_lti_delete_tool_type**](docs/DefaultApi.md#mod_lti_delete_tool_type) | **POST** /webservice/rest/server.php#mod_lti_delete_tool_type | Delete a tool type
*DefaultApi* | [**mod_lti_get_ltis_by_courses**](docs/DefaultApi.md#mod_lti_get_ltis_by_courses) | **POST** /webservice/rest/server.php#mod_lti_get_ltis_by_courses | Returns a list of external tool instances in a provided set of courses, if                             no courses are provided then all the external tool instances the user has access to will be returned.
*DefaultApi* | [**mod_lti_get_tool_launch_data**](docs/DefaultApi.md#mod_lti_get_tool_launch_data) | **POST** /webservice/rest/server.php#mod_lti_get_tool_launch_data | Return the launch data for a given external tool.
*DefaultApi* | [**mod_lti_get_tool_proxies**](docs/DefaultApi.md#mod_lti_get_tool_proxies) | **POST** /webservice/rest/server.php#mod_lti_get_tool_proxies | Get a list of the tool proxies
*DefaultApi* | [**mod_lti_get_tool_proxy_registration_request**](docs/DefaultApi.md#mod_lti_get_tool_proxy_registration_request) | **POST** /webservice/rest/server.php#mod_lti_get_tool_proxy_registration_request | Get a registration request for a tool proxy
*DefaultApi* | [**mod_lti_get_tool_types**](docs/DefaultApi.md#mod_lti_get_tool_types) | **POST** /webservice/rest/server.php#mod_lti_get_tool_types | Get a list of the tool types
*DefaultApi* | [**mod_lti_get_tool_types_and_proxies**](docs/DefaultApi.md#mod_lti_get_tool_types_and_proxies) | **POST** /webservice/rest/server.php#mod_lti_get_tool_types_and_proxies | Get a list of the tool types and tool proxies
*DefaultApi* | [**mod_lti_get_tool_types_and_proxies_count**](docs/DefaultApi.md#mod_lti_get_tool_types_and_proxies_count) | **POST** /webservice/rest/server.php#mod_lti_get_tool_types_and_proxies_count | Get total number of the tool types and tool proxies
*DefaultApi* | [**mod_lti_is_cartridge**](docs/DefaultApi.md#mod_lti_is_cartridge) | **POST** /webservice/rest/server.php#mod_lti_is_cartridge | Determine if the given url is for a cartridge
*DefaultApi* | [**mod_lti_toggle_showinactivitychooser**](docs/DefaultApi.md#mod_lti_toggle_showinactivitychooser) | **POST** /webservice/rest/server.php#mod_lti_toggle_showinactivitychooser | Toggle showinactivitychooser for a tool type in a course
*DefaultApi* | [**mod_lti_update_tool_type**](docs/DefaultApi.md#mod_lti_update_tool_type) | **POST** /webservice/rest/server.php#mod_lti_update_tool_type | Update a tool type
*DefaultApi* | [**mod_lti_view_lti**](docs/DefaultApi.md#mod_lti_view_lti) | **POST** /webservice/rest/server.php#mod_lti_view_lti | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_page_get_pages_by_courses**](docs/DefaultApi.md#mod_page_get_pages_by_courses) | **POST** /webservice/rest/server.php#mod_page_get_pages_by_courses | Returns a list of pages in a provided list of courses, if no list is provided all pages that the user                             can view will be returned.
*DefaultApi* | [**mod_page_view_page**](docs/DefaultApi.md#mod_page_view_page) | **POST** /webservice/rest/server.php#mod_page_view_page | Simulate the view.php web interface page: trigger events, completion, etc...
*DefaultApi* | [**mod_quiz_add_random_questions**](docs/DefaultApi.md#mod_quiz_add_random_questions) | **POST** /webservice/rest/server.php#mod_quiz_add_random_questions | Add a number of random questions to a quiz.
*DefaultApi* | [**mod_quiz_create_grade_item_per_section**](docs/DefaultApi.md#mod_quiz_create_grade_item_per_section) | **POST** /webservice/rest/server.php#mod_quiz_create_grade_item_per_section | For a quiz with no grade items yet, create a grade item for each section, with the questions in that section assigned.
*DefaultApi* | [**mod_quiz_create_grade_items**](docs/DefaultApi.md#mod_quiz_create_grade_items) | **POST** /webservice/rest/server.php#mod_quiz_create_grade_items | Create quiz grade items. All grade items must belong to the same quiz.
*DefaultApi* | [**mod_quiz_delete_grade_items**](docs/DefaultApi.md#mod_quiz_delete_grade_items) | **POST** /webservice/rest/server.php#mod_quiz_delete_grade_items | Delete quiz grade items. All grade items must belong to the same quiz.
*DefaultApi* | [**mod_quiz_delete_overrides**](docs/DefaultApi.md#mod_quiz_delete_overrides) | **POST** /webservice/rest/server.php#mod_quiz_delete_overrides | Delete quiz overrides
*DefaultApi* | [**mod_quiz_get_attempt_access_information**](docs/DefaultApi.md#mod_quiz_get_attempt_access_information) | **POST** /webservice/rest/server.php#mod_quiz_get_attempt_access_information | Return access information for a given attempt in a quiz.
*DefaultApi* | [**mod_quiz_get_attempt_data**](docs/DefaultApi.md#mod_quiz_get_attempt_data) | **POST** /webservice/rest/server.php#mod_quiz_get_attempt_data | Returns information for the given attempt page for a quiz attempt in progress.
*DefaultApi* | [**mod_quiz_get_attempt_review**](docs/DefaultApi.md#mod_quiz_get_attempt_review) | **POST** /webservice/rest/server.php#mod_quiz_get_attempt_review | Returns review information for the given finished attempt, can be used by users or teachers.
*DefaultApi* | [**mod_quiz_get_attempt_summary**](docs/DefaultApi.md#mod_quiz_get_attempt_summary) | **POST** /webservice/rest/server.php#mod_quiz_get_attempt_summary | Returns a summary of a quiz attempt before it is submitted.
*DefaultApi* | [**mod_quiz_get_combined_review_options**](docs/DefaultApi.md#mod_quiz_get_combined_review_options) | **POST** /webservice/rest/server.php#mod_quiz_get_combined_review_options | Combines the review options from a number of different quiz attempts.
*DefaultApi* | [**mod_quiz_get_edit_grading_page_data**](docs/DefaultApi.md#mod_quiz_get_edit_grading_page_data) | **POST** /webservice/rest/server.php#mod_quiz_get_edit_grading_page_data | Get the data required to re-render the Quiz grading setup page
*DefaultApi* | [**mod_quiz_get_overrides**](docs/DefaultApi.md#mod_quiz_get_overrides) | **POST** /webservice/rest/server.php#mod_quiz_get_overrides | Get quiz overrides
*DefaultApi* | [**mod_quiz_get_quiz_access_information**](docs/DefaultApi.md#mod_quiz_get_quiz_access_information) | **POST** /webservice/rest/server.php#mod_quiz_get_quiz_access_information | Return access information for a given quiz.
*DefaultApi* | [**mod_quiz_get_quiz_feedback_for_grade**](docs/DefaultApi.md#mod_quiz_get_quiz_feedback_for_grade) | **POST** /webservice/rest/server.php#mod_quiz_get_quiz_feedback_for_grade | Get the feedback text that should be show to a student who got the given grade in the given quiz.
*DefaultApi* | [**mod_quiz_get_quiz_required_qtypes**](docs/DefaultApi.md#mod_quiz_get_quiz_required_qtypes) | **POST** /webservice/rest/server.php#mod_quiz_get_quiz_required_qtypes | Return the potential question types that would be required for a given quiz.
*DefaultApi* | [**mod_quiz_get_quizzes_by_courses**](docs/DefaultApi.md#mod_quiz_get_quizzes_by_courses) | **POST** /webservice/rest/server.php#mod_quiz_get_quizzes_by_courses | Returns a list of quizzes in a provided list of courses,                             if no list is provided all quizzes that the user can view will be returned.
*DefaultApi* | [**mod_quiz_get_reopen_attempt_confirmation**](docs/DefaultApi.md#mod_quiz_get_reopen_attempt_confirmation) | **POST** /webservice/rest/server.php#mod_quiz_get_reopen_attempt_confirmation | Verify it is OK to re-open a given quiz attempt, and if so, return a suitable confirmation message.
*DefaultApi* | [**mod_quiz_get_user_attempts**](docs/DefaultApi.md#mod_quiz_get_user_attempts) | **POST** /webservice/rest/server.php#mod_quiz_get_user_attempts | Return a list of attempts for the given quiz and user. (Deprecated in favour of mod_quiz_get_user_quiz_attempts).
*DefaultApi* | [**mod_quiz_get_user_best_grade**](docs/DefaultApi.md#mod_quiz_get_user_best_grade) | **POST** /webservice/rest/server.php#mod_quiz_get_user_best_grade | Get the best current grade for the given user on a quiz.
*DefaultApi* | [**mod_quiz_get_user_quiz_attempts**](docs/DefaultApi.md#mod_quiz_get_user_quiz_attempts) | **POST** /webservice/rest/server.php#mod_quiz_get_user_quiz_attempts | Return a list of attempts for the given quiz and user.
*DefaultApi* | [**mod_quiz_process_attempt**](docs/DefaultApi.md#mod_quiz_process_attempt) | **POST** /webservice/rest/server.php#mod_quiz_process_attempt | Process responses during an attempt at a quiz and also deals with attempts finishing.
*DefaultApi* | [**mod_quiz_reopen_attempt**](docs/DefaultApi.md#mod_quiz_reopen_attempt) | **POST** /webservice/rest/server.php#mod_quiz_reopen_attempt | Re-open an attempt that is currently in the never submitted state.
*DefaultApi* | [**mod_quiz_save_attempt**](docs/DefaultApi.md#mod_quiz_save_attempt) | **POST** /webservice/rest/server.php#mod_quiz_save_attempt | Processes save requests during the quiz.                             This function is intended for the quiz auto-save feature.
*DefaultApi* | [**mod_quiz_save_overrides**](docs/DefaultApi.md#mod_quiz_save_overrides) | **POST** /webservice/rest/server.php#mod_quiz_save_overrides | Update or insert quiz overrides
*DefaultApi* | [**mod_quiz_set_question_version**](docs/DefaultApi.md#mod_quiz_set_question_version) | **POST** /webservice/rest/server.php#mod_quiz_set_question_version | Set the version of question that would be required for a given quiz.
*DefaultApi* | [**mod_quiz_start_attempt**](docs/DefaultApi.md#mod_quiz_start_attempt) | **POST** /webservice/rest/server.php#mod_quiz_start_attempt | Starts a new attempt at a quiz.
*DefaultApi* | [**mod_quiz_update_filter_condition**](docs/DefaultApi.md#mod_quiz_update_filter_condition) | **POST** /webservice/rest/server.php#mod_quiz_update_filter_condition | Update filter condition for a random question slot.
*DefaultApi* | [**mod_quiz_update_grade_items**](docs/DefaultApi.md#mod_quiz_update_grade_items) | **POST** /webservice/rest/server.php#mod_quiz_update_grade_items | Update quiz grade items. All grade items must belong to the same quiz.
*DefaultApi* | [**mod_quiz_update_slots**](docs/DefaultApi.md#mod_quiz_update_slots) | **POST** /webservice/rest/server.php#mod_quiz_update_slots | Update the properties of slots in a quiz. All slots must belong to the same quiz.
*DefaultApi* | [**mod_quiz_view_attempt**](docs/DefaultApi.md#mod_quiz_view_attempt) | **POST** /webservice/rest/server.php#mod_quiz_view_attempt | Trigger the attempt viewed event.
*DefaultApi* | [**mod_quiz_view_attempt_review**](docs/DefaultApi.md#mod_quiz_view_attempt_review) | **POST** /webservice/rest/server.php#mod_quiz_view_attempt_review | Trigger the attempt reviewed event.
*DefaultApi* | [**mod_quiz_view_attempt_summary**](docs/DefaultApi.md#mod_quiz_view_attempt_summary) | **POST** /webservice/rest/server.php#mod_quiz_view_attempt_summary | Trigger the attempt summary viewed event.
*DefaultApi* | [**mod_quiz_view_quiz**](docs/DefaultApi.md#mod_quiz_view_quiz) | **POST** /webservice/rest/server.php#mod_quiz_view_quiz | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_resource_get_resources_by_courses**](docs/DefaultApi.md#mod_resource_get_resources_by_courses) | **POST** /webservice/rest/server.php#mod_resource_get_resources_by_courses | Returns a list of files in a provided list of courses, if no list is provided all files that                             the user can view will be returned.
*DefaultApi* | [**mod_resource_view_resource**](docs/DefaultApi.md#mod_resource_view_resource) | **POST** /webservice/rest/server.php#mod_resource_view_resource | Simulate the view.php web interface resource: trigger events, completion, etc...
*DefaultApi* | [**mod_scorm_get_scorm_access_information**](docs/DefaultApi.md#mod_scorm_get_scorm_access_information) | **POST** /webservice/rest/server.php#mod_scorm_get_scorm_access_information | Return capabilities information for a given scorm.
*DefaultApi* | [**mod_scorm_get_scorm_attempt_count**](docs/DefaultApi.md#mod_scorm_get_scorm_attempt_count) | **POST** /webservice/rest/server.php#mod_scorm_get_scorm_attempt_count | Return the number of attempts done by a user in the given SCORM.
*DefaultApi* | [**mod_scorm_get_scorm_sco_tracks**](docs/DefaultApi.md#mod_scorm_get_scorm_sco_tracks) | **POST** /webservice/rest/server.php#mod_scorm_get_scorm_sco_tracks | Retrieves SCO tracking data for the given user id and attempt number
*DefaultApi* | [**mod_scorm_get_scorm_scoes**](docs/DefaultApi.md#mod_scorm_get_scorm_scoes) | **POST** /webservice/rest/server.php#mod_scorm_get_scorm_scoes | Returns a list containing all the scoes data related to the given scorm id
*DefaultApi* | [**mod_scorm_get_scorm_user_data**](docs/DefaultApi.md#mod_scorm_get_scorm_user_data) | **POST** /webservice/rest/server.php#mod_scorm_get_scorm_user_data | Retrieves user tracking and SCO data and default SCORM values
*DefaultApi* | [**mod_scorm_get_scorms_by_courses**](docs/DefaultApi.md#mod_scorm_get_scorms_by_courses) | **POST** /webservice/rest/server.php#mod_scorm_get_scorms_by_courses | Returns a list of scorm instances in a provided set of courses, if                             no courses are provided then all the scorm instances the user has access to will be returned.
*DefaultApi* | [**mod_scorm_insert_scorm_tracks**](docs/DefaultApi.md#mod_scorm_insert_scorm_tracks) | **POST** /webservice/rest/server.php#mod_scorm_insert_scorm_tracks | Saves a scorm tracking record.                           It will overwrite any existing tracking data for this attempt.                           Validation should be performed before running the function to ensure the user will not lose any existing                           attempt data.
*DefaultApi* | [**mod_scorm_launch_sco**](docs/DefaultApi.md#mod_scorm_launch_sco) | **POST** /webservice/rest/server.php#mod_scorm_launch_sco | Trigger the SCO launched event.
*DefaultApi* | [**mod_scorm_view_scorm**](docs/DefaultApi.md#mod_scorm_view_scorm) | **POST** /webservice/rest/server.php#mod_scorm_view_scorm | Trigger the course module viewed event.
*DefaultApi* | [**mod_url_get_urls_by_courses**](docs/DefaultApi.md#mod_url_get_urls_by_courses) | **POST** /webservice/rest/server.php#mod_url_get_urls_by_courses | Returns a list of urls in a provided list of courses, if no list is provided all urls that the user                             can view will be returned.
*DefaultApi* | [**mod_url_view_url**](docs/DefaultApi.md#mod_url_view_url) | **POST** /webservice/rest/server.php#mod_url_view_url | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_wiki_edit_page**](docs/DefaultApi.md#mod_wiki_edit_page) | **POST** /webservice/rest/server.php#mod_wiki_edit_page | Save the contents of a page.
*DefaultApi* | [**mod_wiki_get_page_contents**](docs/DefaultApi.md#mod_wiki_get_page_contents) | **POST** /webservice/rest/server.php#mod_wiki_get_page_contents | Returns the contents of a page.
*DefaultApi* | [**mod_wiki_get_page_for_editing**](docs/DefaultApi.md#mod_wiki_get_page_for_editing) | **POST** /webservice/rest/server.php#mod_wiki_get_page_for_editing | Locks and retrieves info of page-section to be edited.
*DefaultApi* | [**mod_wiki_get_subwiki_files**](docs/DefaultApi.md#mod_wiki_get_subwiki_files) | **POST** /webservice/rest/server.php#mod_wiki_get_subwiki_files | Returns the list of files for a specific subwiki.
*DefaultApi* | [**mod_wiki_get_subwiki_pages**](docs/DefaultApi.md#mod_wiki_get_subwiki_pages) | **POST** /webservice/rest/server.php#mod_wiki_get_subwiki_pages | Returns the list of pages for a specific subwiki.
*DefaultApi* | [**mod_wiki_get_subwikis**](docs/DefaultApi.md#mod_wiki_get_subwikis) | **POST** /webservice/rest/server.php#mod_wiki_get_subwikis | Returns the list of subwikis the user can see in a specific wiki.
*DefaultApi* | [**mod_wiki_get_wikis_by_courses**](docs/DefaultApi.md#mod_wiki_get_wikis_by_courses) | **POST** /webservice/rest/server.php#mod_wiki_get_wikis_by_courses | Returns a list of wiki instances in a provided set of courses, if no courses are provided then all the wiki instances the user has access to will be returned.
*DefaultApi* | [**mod_wiki_new_page**](docs/DefaultApi.md#mod_wiki_new_page) | **POST** /webservice/rest/server.php#mod_wiki_new_page | Create a new page in a subwiki.
*DefaultApi* | [**mod_wiki_view_page**](docs/DefaultApi.md#mod_wiki_view_page) | **POST** /webservice/rest/server.php#mod_wiki_view_page | Trigger the page viewed event and update the module completion status.
*DefaultApi* | [**mod_wiki_view_wiki**](docs/DefaultApi.md#mod_wiki_view_wiki) | **POST** /webservice/rest/server.php#mod_wiki_view_wiki | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**mod_workshop_add_submission**](docs/DefaultApi.md#mod_workshop_add_submission) | **POST** /webservice/rest/server.php#mod_workshop_add_submission | Add a new submission to a given workshop.
*DefaultApi* | [**mod_workshop_delete_submission**](docs/DefaultApi.md#mod_workshop_delete_submission) | **POST** /webservice/rest/server.php#mod_workshop_delete_submission | Deletes the given submission.
*DefaultApi* | [**mod_workshop_evaluate_assessment**](docs/DefaultApi.md#mod_workshop_evaluate_assessment) | **POST** /webservice/rest/server.php#mod_workshop_evaluate_assessment | Evaluates an assessment (used by teachers for provide feedback to the reviewer).
*DefaultApi* | [**mod_workshop_evaluate_submission**](docs/DefaultApi.md#mod_workshop_evaluate_submission) | **POST** /webservice/rest/server.php#mod_workshop_evaluate_submission | Evaluates a submission (used by teachers for provide feedback or override the submission grade).
*DefaultApi* | [**mod_workshop_get_assessment**](docs/DefaultApi.md#mod_workshop_get_assessment) | **POST** /webservice/rest/server.php#mod_workshop_get_assessment | Retrieves the given assessment.
*DefaultApi* | [**mod_workshop_get_assessment_form_definition**](docs/DefaultApi.md#mod_workshop_get_assessment_form_definition) | **POST** /webservice/rest/server.php#mod_workshop_get_assessment_form_definition | Retrieves the assessment form definition.
*DefaultApi* | [**mod_workshop_get_grades**](docs/DefaultApi.md#mod_workshop_get_grades) | **POST** /webservice/rest/server.php#mod_workshop_get_grades | Returns the assessment and submission grade for the given user.
*DefaultApi* | [**mod_workshop_get_grades_report**](docs/DefaultApi.md#mod_workshop_get_grades_report) | **POST** /webservice/rest/server.php#mod_workshop_get_grades_report | Retrieves the assessment grades report.
*DefaultApi* | [**mod_workshop_get_reviewer_assessments**](docs/DefaultApi.md#mod_workshop_get_reviewer_assessments) | **POST** /webservice/rest/server.php#mod_workshop_get_reviewer_assessments | Retrieves all the assessments reviewed by the given user.
*DefaultApi* | [**mod_workshop_get_submission**](docs/DefaultApi.md#mod_workshop_get_submission) | **POST** /webservice/rest/server.php#mod_workshop_get_submission | Retrieves the given submission.
*DefaultApi* | [**mod_workshop_get_submission_assessments**](docs/DefaultApi.md#mod_workshop_get_submission_assessments) | **POST** /webservice/rest/server.php#mod_workshop_get_submission_assessments | Retrieves all the assessments of the given submission.
*DefaultApi* | [**mod_workshop_get_submissions**](docs/DefaultApi.md#mod_workshop_get_submissions) | **POST** /webservice/rest/server.php#mod_workshop_get_submissions | Retrieves all the workshop submissions or the one done by the given user (except example submissions).
*DefaultApi* | [**mod_workshop_get_user_plan**](docs/DefaultApi.md#mod_workshop_get_user_plan) | **POST** /webservice/rest/server.php#mod_workshop_get_user_plan | Return the planner information for the given user.
*DefaultApi* | [**mod_workshop_get_workshop_access_information**](docs/DefaultApi.md#mod_workshop_get_workshop_access_information) | **POST** /webservice/rest/server.php#mod_workshop_get_workshop_access_information | Return access information for a given workshop.
*DefaultApi* | [**mod_workshop_get_workshops_by_courses**](docs/DefaultApi.md#mod_workshop_get_workshops_by_courses) | **POST** /webservice/rest/server.php#mod_workshop_get_workshops_by_courses | Returns a list of workshops in a provided list of courses, if no list is provided all workshops that                             the user can view will be returned.
*DefaultApi* | [**mod_workshop_update_assessment**](docs/DefaultApi.md#mod_workshop_update_assessment) | **POST** /webservice/rest/server.php#mod_workshop_update_assessment | Add information to an allocated assessment.
*DefaultApi* | [**mod_workshop_update_submission**](docs/DefaultApi.md#mod_workshop_update_submission) | **POST** /webservice/rest/server.php#mod_workshop_update_submission | Update the given submission.
*DefaultApi* | [**mod_workshop_view_submission**](docs/DefaultApi.md#mod_workshop_view_submission) | **POST** /webservice/rest/server.php#mod_workshop_view_submission | Trigger the submission viewed event.
*DefaultApi* | [**mod_workshop_view_workshop**](docs/DefaultApi.md#mod_workshop_view_workshop) | **POST** /webservice/rest/server.php#mod_workshop_view_workshop | Trigger the course module viewed event and update the module completion status.
*DefaultApi* | [**paygw_paypal_create_transaction_complete**](docs/DefaultApi.md#paygw_paypal_create_transaction_complete) | **GET** /lib/ajax/service-nologin.php#paygw_paypal_create_transaction_complete | Takes care of what needs to be done when a PayPal transaction comes back as complete.
*DefaultApi* | [**paygw_paypal_get_config_for_js**](docs/DefaultApi.md#paygw_paypal_get_config_for_js) | **POST** /webservice/rest/server.php#paygw_paypal_get_config_for_js | Returns the configuration settings to be used in js
*DefaultApi* | [**qbank_columnsortorder_set_column_size**](docs/DefaultApi.md#qbank_columnsortorder_set_column_size) | **POST** /webservice/rest/server.php#qbank_columnsortorder_set_column_size | Column size
*DefaultApi* | [**qbank_columnsortorder_set_columnbank_order**](docs/DefaultApi.md#qbank_columnsortorder_set_columnbank_order) | **POST** /webservice/rest/server.php#qbank_columnsortorder_set_columnbank_order | Sets question columns order in database
*DefaultApi* | [**qbank_columnsortorder_set_hidden_columns**](docs/DefaultApi.md#qbank_columnsortorder_set_hidden_columns) | **POST** /webservice/rest/server.php#qbank_columnsortorder_set_hidden_columns | Hidden Columns
*DefaultApi* | [**qbank_editquestion_set_status**](docs/DefaultApi.md#qbank_editquestion_set_status) | **POST** /webservice/rest/server.php#qbank_editquestion_set_status | Update the question status.
*DefaultApi* | [**qbank_managecategories_move_category**](docs/DefaultApi.md#qbank_managecategories_move_category) | **POST** /webservice/rest/server.php#qbank_managecategories_move_category | Move a question category
*DefaultApi* | [**qbank_tagquestion_submit_tags_form**](docs/DefaultApi.md#qbank_tagquestion_submit_tags_form) | **POST** /webservice/rest/server.php#qbank_tagquestion_submit_tags_form | Update the question tags.
*DefaultApi* | [**qbank_viewquestiontext_set_question_text_format**](docs/DefaultApi.md#qbank_viewquestiontext_set_question_text_format) | **POST** /webservice/rest/server.php#qbank_viewquestiontext_set_question_text_format | Sets the preference for displaying and formatting the question text
*DefaultApi* | [**quizaccess_seb_validate_quiz_keys**](docs/DefaultApi.md#quizaccess_seb_validate_quiz_keys) | **POST** /webservice/rest/server.php#quizaccess_seb_validate_quiz_keys | Validate a Safe Exam Browser config key or a browser exam key.
*DefaultApi* | [**report_competency_data_for_report**](docs/DefaultApi.md#report_competency_data_for_report) | **POST** /webservice/rest/server.php#report_competency_data_for_report | Load the data for the competency report in a course.
*DefaultApi* | [**report_insights_action_executed**](docs/DefaultApi.md#report_insights_action_executed) | **POST** /webservice/rest/server.php#report_insights_action_executed | Stores an action executed over a group of predictions.
*DefaultApi* | [**tiny_autosave_reset_session**](docs/DefaultApi.md#tiny_autosave_reset_session) | **GET** /lib/ajax/service-nologin.php#tiny_autosave_reset_session | Reset an autosave session
*DefaultApi* | [**tiny_autosave_resume_session**](docs/DefaultApi.md#tiny_autosave_resume_session) | **GET** /lib/ajax/service-nologin.php#tiny_autosave_resume_session | Resume an autosave session
*DefaultApi* | [**tiny_autosave_update_session**](docs/DefaultApi.md#tiny_autosave_update_session) | **GET** /lib/ajax/service-nologin.php#tiny_autosave_update_session | Update an autosave session
*DefaultApi* | [**tiny_equation_filter**](docs/DefaultApi.md#tiny_equation_filter) | **POST** /webservice/rest/server.php#tiny_equation_filter | Filter the equation
*DefaultApi* | [**tiny_media_preview**](docs/DefaultApi.md#tiny_media_preview) | **POST** /webservice/rest/server.php#tiny_media_preview | Filters the content
*DefaultApi* | [**tiny_premium_get_api_key**](docs/DefaultApi.md#tiny_premium_get_api_key) | **POST** /webservice/rest/server.php#tiny_premium_get_api_key | Get the Tiny Premium API key from Moodle
*DefaultApi* | [**tool_admin_presets_delete_preset**](docs/DefaultApi.md#tool_admin_presets_delete_preset) | **POST** /webservice/rest/server.php#tool_admin_presets_delete_preset | Delete a custom preset
*DefaultApi* | [**tool_analytics_potential_contexts**](docs/DefaultApi.md#tool_analytics_potential_contexts) | **POST** /webservice/rest/server.php#tool_analytics_potential_contexts | Retrieve the list of potential contexts for a model.
*DefaultApi* | [**tool_behat_get_entity_generator**](docs/DefaultApi.md#tool_behat_get_entity_generator) | **POST** /webservice/rest/server.php#tool_behat_get_entity_generator | Get the generator details for an entity
*DefaultApi* | [**tool_dataprivacy_approve_data_request**](docs/DefaultApi.md#tool_dataprivacy_approve_data_request) | **POST** /webservice/rest/server.php#tool_dataprivacy_approve_data_request | Approve a data request
*DefaultApi* | [**tool_dataprivacy_bulk_approve_data_requests**](docs/DefaultApi.md#tool_dataprivacy_bulk_approve_data_requests) | **POST** /webservice/rest/server.php#tool_dataprivacy_bulk_approve_data_requests | Bulk approve data requests
*DefaultApi* | [**tool_dataprivacy_bulk_deny_data_requests**](docs/DefaultApi.md#tool_dataprivacy_bulk_deny_data_requests) | **POST** /webservice/rest/server.php#tool_dataprivacy_bulk_deny_data_requests | Bulk deny data requests
*DefaultApi* | [**tool_dataprivacy_cancel_data_request**](docs/DefaultApi.md#tool_dataprivacy_cancel_data_request) | **POST** /webservice/rest/server.php#tool_dataprivacy_cancel_data_request | Cancel the data request made by the user
*DefaultApi* | [**tool_dataprivacy_confirm_contexts_for_deletion**](docs/DefaultApi.md#tool_dataprivacy_confirm_contexts_for_deletion) | **POST** /webservice/rest/server.php#tool_dataprivacy_confirm_contexts_for_deletion | Mark the selected expired contexts as confirmed for deletion
*DefaultApi* | [**tool_dataprivacy_contact_dpo**](docs/DefaultApi.md#tool_dataprivacy_contact_dpo) | **POST** /webservice/rest/server.php#tool_dataprivacy_contact_dpo | Contact the site Data Protection Officer(s)
*DefaultApi* | [**tool_dataprivacy_create_category_form**](docs/DefaultApi.md#tool_dataprivacy_create_category_form) | **POST** /webservice/rest/server.php#tool_dataprivacy_create_category_form | Adds a data category
*DefaultApi* | [**tool_dataprivacy_create_data_request**](docs/DefaultApi.md#tool_dataprivacy_create_data_request) | **POST** /webservice/rest/server.php#tool_dataprivacy_create_data_request | Creates a data request.
*DefaultApi* | [**tool_dataprivacy_create_purpose_form**](docs/DefaultApi.md#tool_dataprivacy_create_purpose_form) | **POST** /webservice/rest/server.php#tool_dataprivacy_create_purpose_form | Adds a data purpose
*DefaultApi* | [**tool_dataprivacy_delete_category**](docs/DefaultApi.md#tool_dataprivacy_delete_category) | **POST** /webservice/rest/server.php#tool_dataprivacy_delete_category | Deletes an existing data category
*DefaultApi* | [**tool_dataprivacy_delete_purpose**](docs/DefaultApi.md#tool_dataprivacy_delete_purpose) | **POST** /webservice/rest/server.php#tool_dataprivacy_delete_purpose | Deletes an existing data purpose
*DefaultApi* | [**tool_dataprivacy_deny_data_request**](docs/DefaultApi.md#tool_dataprivacy_deny_data_request) | **POST** /webservice/rest/server.php#tool_dataprivacy_deny_data_request | Deny a data request
*DefaultApi* | [**tool_dataprivacy_get_access_information**](docs/DefaultApi.md#tool_dataprivacy_get_access_information) | **POST** /webservice/rest/server.php#tool_dataprivacy_get_access_information | Retrieving privacy API access (permissions) information for the current user.
*DefaultApi* | [**tool_dataprivacy_get_activity_options**](docs/DefaultApi.md#tool_dataprivacy_get_activity_options) | **POST** /webservice/rest/server.php#tool_dataprivacy_get_activity_options | Fetches a list of activity options
*DefaultApi* | [**tool_dataprivacy_get_category_options**](docs/DefaultApi.md#tool_dataprivacy_get_category_options) | **POST** /webservice/rest/server.php#tool_dataprivacy_get_category_options | Fetches a list of data category options
*DefaultApi* | [**tool_dataprivacy_get_data_request**](docs/DefaultApi.md#tool_dataprivacy_get_data_request) | **POST** /webservice/rest/server.php#tool_dataprivacy_get_data_request | Fetch the details of a user&#39;s data request
*DefaultApi* | [**tool_dataprivacy_get_data_requests**](docs/DefaultApi.md#tool_dataprivacy_get_data_requests) | **POST** /webservice/rest/server.php#tool_dataprivacy_get_data_requests | Gets data request.
*DefaultApi* | [**tool_dataprivacy_get_purpose_options**](docs/DefaultApi.md#tool_dataprivacy_get_purpose_options) | **POST** /webservice/rest/server.php#tool_dataprivacy_get_purpose_options | Fetches a list of data storage purpose options
*DefaultApi* | [**tool_dataprivacy_get_users**](docs/DefaultApi.md#tool_dataprivacy_get_users) | **POST** /webservice/rest/server.php#tool_dataprivacy_get_users | Fetches a list of users
*DefaultApi* | [**tool_dataprivacy_mark_complete**](docs/DefaultApi.md#tool_dataprivacy_mark_complete) | **POST** /webservice/rest/server.php#tool_dataprivacy_mark_complete | Mark a user&#39;s general enquiry as complete
*DefaultApi* | [**tool_dataprivacy_set_context_defaults**](docs/DefaultApi.md#tool_dataprivacy_set_context_defaults) | **POST** /webservice/rest/server.php#tool_dataprivacy_set_context_defaults | Updates the default category and purpose for a given context level (and optionally, a plugin)
*DefaultApi* | [**tool_dataprivacy_set_context_form**](docs/DefaultApi.md#tool_dataprivacy_set_context_form) | **POST** /webservice/rest/server.php#tool_dataprivacy_set_context_form | Sets purpose and category for a specific context
*DefaultApi* | [**tool_dataprivacy_set_contextlevel_form**](docs/DefaultApi.md#tool_dataprivacy_set_contextlevel_form) | **POST** /webservice/rest/server.php#tool_dataprivacy_set_contextlevel_form | Sets purpose and category across a context level
*DefaultApi* | [**tool_dataprivacy_submit_selected_courses_form**](docs/DefaultApi.md#tool_dataprivacy_submit_selected_courses_form) | **POST** /webservice/rest/server.php#tool_dataprivacy_submit_selected_courses_form | Save list of selected courses for export
*DefaultApi* | [**tool_dataprivacy_tree_extra_branches**](docs/DefaultApi.md#tool_dataprivacy_tree_extra_branches) | **POST** /webservice/rest/server.php#tool_dataprivacy_tree_extra_branches | Return branches for the context tree
*DefaultApi* | [**tool_lp_data_for_competencies_manage_page**](docs/DefaultApi.md#tool_lp_data_for_competencies_manage_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_competencies_manage_page | Load the data for the competencies manage page template
*DefaultApi* | [**tool_lp_data_for_competency_frameworks_manage_page**](docs/DefaultApi.md#tool_lp_data_for_competency_frameworks_manage_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_competency_frameworks_manage_page | Load the data for the competency frameworks manage page template
*DefaultApi* | [**tool_lp_data_for_competency_summary**](docs/DefaultApi.md#tool_lp_data_for_competency_summary) | **POST** /webservice/rest/server.php#tool_lp_data_for_competency_summary | Load competency data for summary template.
*DefaultApi* | [**tool_lp_data_for_course_competencies_page**](docs/DefaultApi.md#tool_lp_data_for_course_competencies_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_course_competencies_page | Load the data for the course competencies page template.
*DefaultApi* | [**tool_lp_data_for_plan_page**](docs/DefaultApi.md#tool_lp_data_for_plan_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_plan_page | Load the data for the plan page template.
*DefaultApi* | [**tool_lp_data_for_plans_page**](docs/DefaultApi.md#tool_lp_data_for_plans_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_plans_page | Load the data for the plans page template
*DefaultApi* | [**tool_lp_data_for_related_competencies_section**](docs/DefaultApi.md#tool_lp_data_for_related_competencies_section) | **POST** /webservice/rest/server.php#tool_lp_data_for_related_competencies_section | Load the data for the related competencies template.
*DefaultApi* | [**tool_lp_data_for_template_competencies_page**](docs/DefaultApi.md#tool_lp_data_for_template_competencies_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_template_competencies_page | Load the data for the template competencies page template.
*DefaultApi* | [**tool_lp_data_for_templates_manage_page**](docs/DefaultApi.md#tool_lp_data_for_templates_manage_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_templates_manage_page | Load the data for the learning plan templates manage page template
*DefaultApi* | [**tool_lp_data_for_user_competency_summary**](docs/DefaultApi.md#tool_lp_data_for_user_competency_summary) | **POST** /webservice/rest/server.php#tool_lp_data_for_user_competency_summary | Load a summary of a user competency.
*DefaultApi* | [**tool_lp_data_for_user_competency_summary_in_course**](docs/DefaultApi.md#tool_lp_data_for_user_competency_summary_in_course) | **POST** /webservice/rest/server.php#tool_lp_data_for_user_competency_summary_in_course | Load a summary of a user competency.
*DefaultApi* | [**tool_lp_data_for_user_competency_summary_in_plan**](docs/DefaultApi.md#tool_lp_data_for_user_competency_summary_in_plan) | **POST** /webservice/rest/server.php#tool_lp_data_for_user_competency_summary_in_plan | Load a summary of a user competency.
*DefaultApi* | [**tool_lp_data_for_user_evidence_list_page**](docs/DefaultApi.md#tool_lp_data_for_user_evidence_list_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_user_evidence_list_page | Load the data for the user evidence list page template
*DefaultApi* | [**tool_lp_data_for_user_evidence_page**](docs/DefaultApi.md#tool_lp_data_for_user_evidence_page) | **POST** /webservice/rest/server.php#tool_lp_data_for_user_evidence_page | Load the data for the user evidence page template
*DefaultApi* | [**tool_lp_list_courses_using_competency**](docs/DefaultApi.md#tool_lp_list_courses_using_competency) | **POST** /webservice/rest/server.php#tool_lp_list_courses_using_competency | List the courses using a competency
*DefaultApi* | [**tool_lp_search_cohorts**](docs/DefaultApi.md#tool_lp_search_cohorts) | **POST** /webservice/rest/server.php#tool_lp_search_cohorts | Search for cohorts. This method is deprecated, please call &#39;core_cohort_search_cohorts&#39; instead
*DefaultApi* | [**tool_lp_search_users**](docs/DefaultApi.md#tool_lp_search_users) | **POST** /webservice/rest/server.php#tool_lp_search_users | Search for users.
*DefaultApi* | [**tool_mobile_call_external_functions**](docs/DefaultApi.md#tool_mobile_call_external_functions) | **POST** /webservice/rest/server.php#tool_mobile_call_external_functions | Call multiple external functions and return all responses.
*DefaultApi* | [**tool_mobile_get_autologin_key**](docs/DefaultApi.md#tool_mobile_get_autologin_key) | **POST** /webservice/rest/server.php#tool_mobile_get_autologin_key | Creates an auto-login key for the current user.                             Is created only in https sites and is restricted by time, ip address and only works if the request                             comes from the Moodle mobile or desktop app.
*DefaultApi* | [**tool_mobile_get_config**](docs/DefaultApi.md#tool_mobile_get_config) | **POST** /webservice/rest/server.php#tool_mobile_get_config | Returns a list of the site configurations, filtering by section.
*DefaultApi* | [**tool_mobile_get_content**](docs/DefaultApi.md#tool_mobile_get_content) | **POST** /webservice/rest/server.php#tool_mobile_get_content | Returns a piece of content to be displayed in the Mobile app.
*DefaultApi* | [**tool_mobile_get_plugins_supporting_mobile**](docs/DefaultApi.md#tool_mobile_get_plugins_supporting_mobile) | **GET** /lib/ajax/service-nologin.php#tool_mobile_get_plugins_supporting_mobile | Returns a list of Moodle plugins supporting the mobile app.
*DefaultApi* | [**tool_mobile_get_public_config**](docs/DefaultApi.md#tool_mobile_get_public_config) | **GET** /lib/ajax/service-nologin.php#tool_mobile_get_public_config | Returns a list of the site public settings, those not requiring authentication.
*DefaultApi* | [**tool_mobile_get_tokens_for_qr_login**](docs/DefaultApi.md#tool_mobile_get_tokens_for_qr_login) | **GET** /lib/ajax/service-nologin.php#tool_mobile_get_tokens_for_qr_login | Returns a WebService token (and private token) for QR login.
*DefaultApi* | [**tool_mobile_validate_subscription_key**](docs/DefaultApi.md#tool_mobile_validate_subscription_key) | **GET** /lib/ajax/service-nologin.php#tool_mobile_validate_subscription_key | Check if the given site subscription key is valid.
*DefaultApi* | [**tool_moodlenet_search_courses**](docs/DefaultApi.md#tool_moodlenet_search_courses) | **POST** /webservice/rest/server.php#tool_moodlenet_search_courses | For some given input search for a course that matches
*DefaultApi* | [**tool_moodlenet_verify_webfinger**](docs/DefaultApi.md#tool_moodlenet_verify_webfinger) | **POST** /webservice/rest/server.php#tool_moodlenet_verify_webfinger | Verify if the passed information resolves into a WebFinger profile URL
*DefaultApi* | [**tool_policy_get_policy_version**](docs/DefaultApi.md#tool_policy_get_policy_version) | **GET** /lib/ajax/service-nologin.php#tool_policy_get_policy_version | Fetch the details of a policy version
*DefaultApi* | [**tool_policy_get_user_acceptances**](docs/DefaultApi.md#tool_policy_get_user_acceptances) | **POST** /webservice/rest/server.php#tool_policy_get_user_acceptances | Get user policies acceptances.
*DefaultApi* | [**tool_policy_set_acceptances_status**](docs/DefaultApi.md#tool_policy_set_acceptances_status) | **POST** /webservice/rest/server.php#tool_policy_set_acceptances_status | Set the acceptance status (accept or decline only) for the indicated policies for the given user.
*DefaultApi* | [**tool_policy_submit_accept_on_behalf**](docs/DefaultApi.md#tool_policy_submit_accept_on_behalf) | **POST** /webservice/rest/server.php#tool_policy_submit_accept_on_behalf | Accept policies on behalf of other users
*DefaultApi* | [**tool_templatelibrary_list_templates**](docs/DefaultApi.md#tool_templatelibrary_list_templates) | **GET** /lib/ajax/service-nologin.php#tool_templatelibrary_list_templates | List/search templates by component.
*DefaultApi* | [**tool_templatelibrary_load_canonical_template**](docs/DefaultApi.md#tool_templatelibrary_load_canonical_template) | **GET** /lib/ajax/service-nologin.php#tool_templatelibrary_load_canonical_template | Load a canonical template by name (not the theme overidden one).
*DefaultApi* | [**tool_usertours_complete_tour**](docs/DefaultApi.md#tool_usertours_complete_tour) | **POST** /webservice/rest/server.php#tool_usertours_complete_tour | Mark the specified tour as completed for the current user
*DefaultApi* | [**tool_usertours_fetch_and_start_tour**](docs/DefaultApi.md#tool_usertours_fetch_and_start_tour) | **POST** /webservice/rest/server.php#tool_usertours_fetch_and_start_tour | Fetch the specified tour
*DefaultApi* | [**tool_usertours_reset_tour**](docs/DefaultApi.md#tool_usertours_reset_tour) | **POST** /webservice/rest/server.php#tool_usertours_reset_tour | Remove the specified tour
*DefaultApi* | [**tool_usertours_step_shown**](docs/DefaultApi.md#tool_usertours_step_shown) | **POST** /webservice/rest/server.php#tool_usertours_step_shown | Mark the specified step as completed for the current user
*DefaultApi* | [**tool_xmldb_invoke_move_action**](docs/DefaultApi.md#tool_xmldb_invoke_move_action) | **POST** /webservice/rest/server.php#tool_xmldb_invoke_move_action | moves element up/down


## Documentation For Models

 - [AiplacementCourseassistExplainTextResponse](docs/AiplacementCourseassistExplainTextResponse.md)
 - [AiplacementCourseassistSummariseTextResponse](docs/AiplacementCourseassistSummariseTextResponse.md)
 - [AiplacementEditorGenerateImageResponse](docs/AiplacementEditorGenerateImageResponse.md)
 - [AiplacementEditorGenerateTextResponse](docs/AiplacementEditorGenerateTextResponse.md)
 - [AuthEmailGetSignupSettingsResponse](docs/AuthEmailGetSignupSettingsResponse.md)
 - [AuthEmailGetSignupSettingsResponseProfilefieldsInner](docs/AuthEmailGetSignupSettingsResponseProfilefieldsInner.md)
 - [AuthEmailGetSignupSettingsResponseWarningsInner](docs/AuthEmailGetSignupSettingsResponseWarningsInner.md)
 - [AuthEmailSignupUserParameters](docs/AuthEmailSignupUserParameters.md)
 - [AuthEmailSignupUserParametersCustomprofilefieldsInner](docs/AuthEmailSignupUserParametersCustomprofilefieldsInner.md)
 - [AuthEmailSignupUserResponse](docs/AuthEmailSignupUserResponse.md)
 - [BlockAccessreviewGetModuleDataResponseInner](docs/BlockAccessreviewGetModuleDataResponseInner.md)
 - [BlockAccessreviewGetSectionDataResponseInner](docs/BlockAccessreviewGetSectionDataResponseInner.md)
 - [BlockRecentlyaccesseditemsGetRecentItemsResponseInner](docs/BlockRecentlyaccesseditemsGetRecentItemsResponseInner.md)
 - [BlockStarredcoursesGetStarredCoursesResponseInner](docs/BlockStarredcoursesGetStarredCoursesResponseInner.md)
 - [CoreAiDeleteProviderInstanceResponse](docs/CoreAiDeleteProviderInstanceResponse.md)
 - [CoreAiGetPolicyStatusResponse](docs/CoreAiGetPolicyStatusResponse.md)
 - [CoreAiSetPolicyStatusResponse](docs/CoreAiSetPolicyStatusResponse.md)
 - [CoreAiSetProviderStatusResponse](docs/CoreAiSetProviderStatusResponse.md)
 - [CoreAuthConfirmUserParameters](docs/CoreAuthConfirmUserParameters.md)
 - [CoreAuthConfirmUserResponse](docs/CoreAuthConfirmUserResponse.md)
 - [CoreAuthIsAgeDigitalConsentVerificationEnabledResponse](docs/CoreAuthIsAgeDigitalConsentVerificationEnabledResponse.md)
 - [CoreAuthIsMinorParameters](docs/CoreAuthIsMinorParameters.md)
 - [CoreAuthIsMinorResponse](docs/CoreAuthIsMinorResponse.md)
 - [CoreAuthRequestPasswordResetParameters](docs/CoreAuthRequestPasswordResetParameters.md)
 - [CoreAuthRequestPasswordResetResponse](docs/CoreAuthRequestPasswordResetResponse.md)
 - [CoreAuthResendConfirmationEmailParameters](docs/CoreAuthResendConfirmationEmailParameters.md)
 - [CoreAuthResendConfirmationEmailResponse](docs/CoreAuthResendConfirmationEmailResponse.md)
 - [CoreBackupGetAsyncBackupLinksBackupResponse](docs/CoreBackupGetAsyncBackupLinksBackupResponse.md)
 - [CoreBackupGetAsyncBackupLinksRestoreResponse](docs/CoreBackupGetAsyncBackupLinksRestoreResponse.md)
 - [CoreBackupGetAsyncBackupProgressResponseInner](docs/CoreBackupGetAsyncBackupProgressResponseInner.md)
 - [CoreBackupGetCopyProgressParametersCopiesInner](docs/CoreBackupGetCopyProgressParametersCopiesInner.md)
 - [CoreBackupGetCopyProgressResponseInner](docs/CoreBackupGetCopyProgressResponseInner.md)
 - [CoreBadgesDisableBadgesResponse](docs/CoreBadgesDisableBadgesResponse.md)
 - [CoreBadgesEnableBadgesResponse](docs/CoreBadgesEnableBadgesResponse.md)
 - [CoreBadgesEnableBadgesResponseResultInner](docs/CoreBadgesEnableBadgesResponseResultInner.md)
 - [CoreBadgesGetBadgeResponse](docs/CoreBadgesGetBadgeResponse.md)
 - [CoreBadgesGetBadgeResponseBadge](docs/CoreBadgesGetBadgeResponseBadge.md)
 - [CoreBadgesGetBadgeResponseBadgeAlignmentInner](docs/CoreBadgesGetBadgeResponseBadgeAlignmentInner.md)
 - [CoreBadgesGetUserBadgeByHashResponse](docs/CoreBadgesGetUserBadgeByHashResponse.md)
 - [CoreBadgesGetUserBadgeByHashResponseBadgeInner](docs/CoreBadgesGetUserBadgeByHashResponseBadgeInner.md)
 - [CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement](docs/CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement.md)
 - [CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner](docs/CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner.md)
 - [CoreBadgesGetUserBadgesResponse](docs/CoreBadgesGetUserBadgesResponse.md)
 - [CoreBlockFetchAddableBlocksResponseInner](docs/CoreBlockFetchAddableBlocksResponseInner.md)
 - [CoreBlockGetCourseBlocksResponse](docs/CoreBlockGetCourseBlocksResponse.md)
 - [CoreBlockGetCourseBlocksResponseBlocksInner](docs/CoreBlockGetCourseBlocksResponseBlocksInner.md)
 - [CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner](docs/CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner.md)
 - [CoreBlockGetCourseBlocksResponseBlocksInnerContents](docs/CoreBlockGetCourseBlocksResponseBlocksInnerContents.md)
 - [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner](docs/CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.md)
 - [CoreBlockGetDashboardBlocksResponse](docs/CoreBlockGetDashboardBlocksResponse.md)
 - [CoreBlogAddEntryParametersOptionsInner](docs/CoreBlogAddEntryParametersOptionsInner.md)
 - [CoreBlogAddEntryResponse](docs/CoreBlogAddEntryResponse.md)
 - [CoreBlogDeleteEntryResponse](docs/CoreBlogDeleteEntryResponse.md)
 - [CoreBlogGetAccessInformationResponse](docs/CoreBlogGetAccessInformationResponse.md)
 - [CoreBlogGetEntriesParameters](docs/CoreBlogGetEntriesParameters.md)
 - [CoreBlogGetEntriesParametersFiltersInner](docs/CoreBlogGetEntriesParametersFiltersInner.md)
 - [CoreBlogGetEntriesResponse](docs/CoreBlogGetEntriesResponse.md)
 - [CoreBlogGetEntriesResponseEntriesInner](docs/CoreBlogGetEntriesResponseEntriesInner.md)
 - [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner](docs/CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.md)
 - [CoreBlogGetEntriesResponseEntriesInnerTagsInner](docs/CoreBlogGetEntriesResponseEntriesInnerTagsInner.md)
 - [CoreBlogPrepareEntryForEditionResponse](docs/CoreBlogPrepareEntryForEditionResponse.md)
 - [CoreBlogPrepareEntryForEditionResponseAreasInner](docs/CoreBlogPrepareEntryForEditionResponseAreasInner.md)
 - [CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner](docs/CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner.md)
 - [CoreBlogUpdateEntryResponse](docs/CoreBlogUpdateEntryResponse.md)
 - [CoreBlogViewEntriesParameters](docs/CoreBlogViewEntriesParameters.md)
 - [CoreBlogViewEntriesParametersFiltersInner](docs/CoreBlogViewEntriesParametersFiltersInner.md)
 - [CoreBlogViewEntriesResponse](docs/CoreBlogViewEntriesResponse.md)
 - [CoreCalendarCreateCalendarEventsParametersEventsInner](docs/CoreCalendarCreateCalendarEventsParametersEventsInner.md)
 - [CoreCalendarCreateCalendarEventsResponse](docs/CoreCalendarCreateCalendarEventsResponse.md)
 - [CoreCalendarCreateCalendarEventsResponseEventsInner](docs/CoreCalendarCreateCalendarEventsResponseEventsInner.md)
 - [CoreCalendarDeleteCalendarEventsParametersEventsInner](docs/CoreCalendarDeleteCalendarEventsParametersEventsInner.md)
 - [CoreCalendarDeleteSubscriptionResponse](docs/CoreCalendarDeleteSubscriptionResponse.md)
 - [CoreCalendarGetActionEventsByCourseResponse](docs/CoreCalendarGetActionEventsByCourseResponse.md)
 - [CoreCalendarGetActionEventsByCourseResponseEventsInner](docs/CoreCalendarGetActionEventsByCourseResponseEventsInner.md)
 - [CoreCalendarGetActionEventsByCourseResponseEventsInnerAction](docs/CoreCalendarGetActionEventsByCourseResponseEventsInnerAction.md)
 - [CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory](docs/CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory.md)
 - [CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon](docs/CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon.md)
 - [CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription](docs/CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription.md)
 - [CoreCalendarGetActionEventsByCoursesResponse](docs/CoreCalendarGetActionEventsByCoursesResponse.md)
 - [CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner](docs/CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner.md)
 - [CoreCalendarGetActionEventsByTimesortResponse](docs/CoreCalendarGetActionEventsByTimesortResponse.md)
 - [CoreCalendarGetAllowedEventTypesResponse](docs/CoreCalendarGetAllowedEventTypesResponse.md)
 - [CoreCalendarGetCalendarAccessInformationResponse](docs/CoreCalendarGetCalendarAccessInformationResponse.md)
 - [CoreCalendarGetCalendarDayViewResponse](docs/CoreCalendarGetCalendarDayViewResponse.md)
 - [CoreCalendarGetCalendarDayViewResponseDate](docs/CoreCalendarGetCalendarDayViewResponseDate.md)
 - [CoreCalendarGetCalendarDayViewResponseEventsInner](docs/CoreCalendarGetCalendarDayViewResponseEventsInner.md)
 - [CoreCalendarGetCalendarEventByIdResponse](docs/CoreCalendarGetCalendarEventByIdResponse.md)
 - [CoreCalendarGetCalendarEventsParametersEvents](docs/CoreCalendarGetCalendarEventsParametersEvents.md)
 - [CoreCalendarGetCalendarEventsParametersOptions](docs/CoreCalendarGetCalendarEventsParametersOptions.md)
 - [CoreCalendarGetCalendarEventsResponse](docs/CoreCalendarGetCalendarEventsResponse.md)
 - [CoreCalendarGetCalendarEventsResponseEventsInner](docs/CoreCalendarGetCalendarEventsResponseEventsInner.md)
 - [CoreCalendarGetCalendarExportTokenResponse](docs/CoreCalendarGetCalendarExportTokenResponse.md)
 - [CoreCalendarGetCalendarMonthlyViewResponse](docs/CoreCalendarGetCalendarMonthlyViewResponse.md)
 - [CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner](docs/CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner.md)
 - [CoreCalendarGetCalendarMonthlyViewResponseWeeksInner](docs/CoreCalendarGetCalendarMonthlyViewResponseWeeksInner.md)
 - [CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner](docs/CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner.md)
 - [CoreCalendarGetCalendarUpcomingViewResponse](docs/CoreCalendarGetCalendarUpcomingViewResponse.md)
 - [CoreCalendarGetTimestampsParametersDataInner](docs/CoreCalendarGetTimestampsParametersDataInner.md)
 - [CoreCalendarGetTimestampsResponse](docs/CoreCalendarGetTimestampsResponse.md)
 - [CoreCalendarGetTimestampsResponseTimestampsInner](docs/CoreCalendarGetTimestampsResponseTimestampsInner.md)
 - [CoreCalendarSubmitCreateUpdateFormResponse](docs/CoreCalendarSubmitCreateUpdateFormResponse.md)
 - [CoreCalendarUpdateEventStartDayResponse](docs/CoreCalendarUpdateEventStartDayResponse.md)
 - [CoreChangeEditmodeResponse](docs/CoreChangeEditmodeResponse.md)
 - [CoreCheckGetResultAdmintreeResponse](docs/CoreCheckGetResultAdmintreeResponse.md)
 - [CoreCohortAddCohortMembersParametersMembersInner](docs/CoreCohortAddCohortMembersParametersMembersInner.md)
 - [CoreCohortAddCohortMembersParametersMembersInnerCohorttype](docs/CoreCohortAddCohortMembersParametersMembersInnerCohorttype.md)
 - [CoreCohortAddCohortMembersParametersMembersInnerUsertype](docs/CoreCohortAddCohortMembersParametersMembersInnerUsertype.md)
 - [CoreCohortAddCohortMembersResponse](docs/CoreCohortAddCohortMembersResponse.md)
 - [CoreCohortCreateCohortsParametersCohortsInner](docs/CoreCohortCreateCohortsParametersCohortsInner.md)
 - [CoreCohortCreateCohortsParametersCohortsInnerCategorytype](docs/CoreCohortCreateCohortsParametersCohortsInnerCategorytype.md)
 - [CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner](docs/CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner.md)
 - [CoreCohortCreateCohortsResponseInner](docs/CoreCohortCreateCohortsResponseInner.md)
 - [CoreCohortDeleteCohortMembersParametersMembersInner](docs/CoreCohortDeleteCohortMembersParametersMembersInner.md)
 - [CoreCohortGetCohortMembersResponseInner](docs/CoreCohortGetCohortMembersResponseInner.md)
 - [CoreCohortGetCohortsResponseInner](docs/CoreCohortGetCohortsResponseInner.md)
 - [CoreCohortGetCohortsResponseInnerCustomfieldsInner](docs/CoreCohortGetCohortsResponseInnerCustomfieldsInner.md)
 - [CoreCohortSearchCohortsParametersContext](docs/CoreCohortSearchCohortsParametersContext.md)
 - [CoreCohortSearchCohortsResponse](docs/CoreCohortSearchCohortsResponse.md)
 - [CoreCohortUpdateCohortsParametersCohortsInner](docs/CoreCohortUpdateCohortsParametersCohortsInner.md)
 - [CoreCommentAddCommentsParametersCommentsInner](docs/CoreCommentAddCommentsParametersCommentsInner.md)
 - [CoreCommentAddCommentsResponseInner](docs/CoreCommentAddCommentsResponseInner.md)
 - [CoreCommentGetCommentsResponse](docs/CoreCommentGetCommentsResponse.md)
 - [CoreCompetencyCountCompetenciesParametersFiltersInner](docs/CoreCompetencyCountCompetenciesParametersFiltersInner.md)
 - [CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework](docs/CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework.md)
 - [CoreCompetencyCreateCompetencyFrameworkResponse](docs/CoreCompetencyCreateCompetencyFrameworkResponse.md)
 - [CoreCompetencyCreateCompetencyParametersCompetency](docs/CoreCompetencyCreateCompetencyParametersCompetency.md)
 - [CoreCompetencyCreateCompetencyResponse](docs/CoreCompetencyCreateCompetencyResponse.md)
 - [CoreCompetencyCreatePlanParametersPlan](docs/CoreCompetencyCreatePlanParametersPlan.md)
 - [CoreCompetencyCreatePlanResponse](docs/CoreCompetencyCreatePlanResponse.md)
 - [CoreCompetencyCreatePlanResponseCommentarea](docs/CoreCompetencyCreatePlanResponseCommentarea.md)
 - [CoreCompetencyCreatePlanResponseReviewer](docs/CoreCompetencyCreatePlanResponseReviewer.md)
 - [CoreCompetencyCreatePlanResponseTemplate](docs/CoreCompetencyCreatePlanResponseTemplate.md)
 - [CoreCompetencyCreateTemplateParametersTemplate](docs/CoreCompetencyCreateTemplateParametersTemplate.md)
 - [CoreCompetencyCreateTemplateResponse](docs/CoreCompetencyCreateTemplateResponse.md)
 - [CoreCompetencyCreateUserEvidenceCompetencyResponse](docs/CoreCompetencyCreateUserEvidenceCompetencyResponse.md)
 - [CoreCompetencyDuplicateCompetencyFrameworkResponse](docs/CoreCompetencyDuplicateCompetencyFrameworkResponse.md)
 - [CoreCompetencyDuplicateTemplateResponse](docs/CoreCompetencyDuplicateTemplateResponse.md)
 - [CoreCompetencyGetScaleValuesResponseInner](docs/CoreCompetencyGetScaleValuesResponseInner.md)
 - [CoreCompetencyGradeCompetencyInCourseResponse](docs/CoreCompetencyGradeCompetencyInCourseResponse.md)
 - [CoreCompetencyGradeCompetencyInPlanResponse](docs/CoreCompetencyGradeCompetencyInPlanResponse.md)
 - [CoreCompetencyGradeCompetencyResponse](docs/CoreCompetencyGradeCompetencyResponse.md)
 - [CoreCompetencyListCompetenciesInTemplateResponseInner](docs/CoreCompetencyListCompetenciesInTemplateResponseInner.md)
 - [CoreCompetencyListCompetencyFrameworksResponseInner](docs/CoreCompetencyListCompetencyFrameworksResponseInner.md)
 - [CoreCompetencyListCourseCompetenciesResponseInner](docs/CoreCompetencyListCourseCompetenciesResponseInner.md)
 - [CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency](docs/CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency.md)
 - [CoreCompetencyListCourseModuleCompetenciesResponseInner](docs/CoreCompetencyListCourseModuleCompetenciesResponseInner.md)
 - [CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency](docs/CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency.md)
 - [CoreCompetencyListPlanCompetenciesResponseInner](docs/CoreCompetencyListPlanCompetenciesResponseInner.md)
 - [CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency](docs/CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency.md)
 - [CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan](docs/CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan.md)
 - [CoreCompetencyListUserPlansResponseInner](docs/CoreCompetencyListUserPlansResponseInner.md)
 - [CoreCompetencyReadCompetencyFrameworkResponse](docs/CoreCompetencyReadCompetencyFrameworkResponse.md)
 - [CoreCompetencyReadCompetencyResponse](docs/CoreCompetencyReadCompetencyResponse.md)
 - [CoreCompetencyReadPlanResponse](docs/CoreCompetencyReadPlanResponse.md)
 - [CoreCompetencyReadTemplateResponse](docs/CoreCompetencyReadTemplateResponse.md)
 - [CoreCompetencyReadUserEvidenceResponse](docs/CoreCompetencyReadUserEvidenceResponse.md)
 - [CoreCompetencyReadUserEvidenceResponseFilesInner](docs/CoreCompetencyReadUserEvidenceResponseFilesInner.md)
 - [CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework](docs/CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework.md)
 - [CoreCompetencyUpdateCompetencyParametersCompetency](docs/CoreCompetencyUpdateCompetencyParametersCompetency.md)
 - [CoreCompetencyUpdateCourseCompetencySettingsParametersSettings](docs/CoreCompetencyUpdateCourseCompetencySettingsParametersSettings.md)
 - [CoreCompetencyUpdatePlanParametersPlan](docs/CoreCompetencyUpdatePlanParametersPlan.md)
 - [CoreCompetencyUpdatePlanResponse](docs/CoreCompetencyUpdatePlanResponse.md)
 - [CoreCompetencyUpdateTemplateParametersTemplate](docs/CoreCompetencyUpdateTemplateParametersTemplate.md)
 - [CoreCompletionGetActivitiesCompletionStatusResponse](docs/CoreCompletionGetActivitiesCompletionStatusResponse.md)
 - [CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner](docs/CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner.md)
 - [CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner](docs/CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner.md)
 - [CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue](docs/CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue.md)
 - [CoreCompletionGetCourseCompletionStatusResponse](docs/CoreCompletionGetCourseCompletionStatusResponse.md)
 - [CoreCompletionGetCourseCompletionStatusResponseCompletionstatus](docs/CoreCompletionGetCourseCompletionStatusResponseCompletionstatus.md)
 - [CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner](docs/CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner.md)
 - [CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails](docs/CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails.md)
 - [CoreCompletionMarkCourseSelfCompletedResponse](docs/CoreCompletionMarkCourseSelfCompletedResponse.md)
 - [CoreCompletionOverrideActivityCompletionStatusResponse](docs/CoreCompletionOverrideActivityCompletionStatusResponse.md)
 - [CoreCompletionUpdateActivityCompletionStatusManuallyResponse](docs/CoreCompletionUpdateActivityCompletionStatusManuallyResponse.md)
 - [CoreContentbankCopyContentResponse](docs/CoreContentbankCopyContentResponse.md)
 - [CoreContentbankDeleteContentResponse](docs/CoreContentbankDeleteContentResponse.md)
 - [CoreContentbankRenameContentResponse](docs/CoreContentbankRenameContentResponse.md)
 - [CoreContentbankSetContentVisibilityResponse](docs/CoreContentbankSetContentVisibilityResponse.md)
 - [CoreCourseAddContentItemToUserFavouritesResponse](docs/CoreCourseAddContentItemToUserFavouritesResponse.md)
 - [CoreCourseCheckUpdatesParametersTocheckInner](docs/CoreCourseCheckUpdatesParametersTocheckInner.md)
 - [CoreCourseCheckUpdatesResponse](docs/CoreCourseCheckUpdatesResponse.md)
 - [CoreCourseCheckUpdatesResponseInstancesInner](docs/CoreCourseCheckUpdatesResponseInstancesInner.md)
 - [CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner](docs/CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner.md)
 - [CoreCourseCreateCategoriesParametersCategoriesInner](docs/CoreCourseCreateCategoriesParametersCategoriesInner.md)
 - [CoreCourseCreateCategoriesResponseInner](docs/CoreCourseCreateCategoriesResponseInner.md)
 - [CoreCourseCreateCoursesParametersCoursesInner](docs/CoreCourseCreateCoursesParametersCoursesInner.md)
 - [CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner](docs/CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner.md)
 - [CoreCourseCreateCoursesResponseInner](docs/CoreCourseCreateCoursesResponseInner.md)
 - [CoreCourseDeleteCategoriesParametersCategoriesInner](docs/CoreCourseDeleteCategoriesParametersCategoriesInner.md)
 - [CoreCourseDeleteCoursesResponse](docs/CoreCourseDeleteCoursesResponse.md)
 - [CoreCourseDuplicateCourseParametersOptionsInner](docs/CoreCourseDuplicateCourseParametersOptionsInner.md)
 - [CoreCourseDuplicateCourseResponse](docs/CoreCourseDuplicateCourseResponse.md)
 - [CoreCourseGetActivityChooserFooterResponse](docs/CoreCourseGetActivityChooserFooterResponse.md)
 - [CoreCourseGetCategoriesParametersCriteriaInner](docs/CoreCourseGetCategoriesParametersCriteriaInner.md)
 - [CoreCourseGetCategoriesResponseInner](docs/CoreCourseGetCategoriesResponseInner.md)
 - [CoreCourseGetContentsParametersOptionsInner](docs/CoreCourseGetContentsParametersOptionsInner.md)
 - [CoreCourseGetContentsResponseInner](docs/CoreCourseGetContentsResponseInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInner](docs/CoreCourseGetContentsResponseInnerModulesInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerActivitybadge](docs/CoreCourseGetContentsResponseInnerModulesInnerActivitybadge.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf](docs/CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner](docs/CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerCompletiondata](docs/CoreCourseGetContentsResponseInnerModulesInnerCompletiondata.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner](docs/CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue](docs/CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerContentsInner](docs/CoreCourseGetContentsResponseInnerModulesInnerContentsInner.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerContentsinfo](docs/CoreCourseGetContentsResponseInnerModulesInnerContentsinfo.md)
 - [CoreCourseGetContentsResponseInnerModulesInnerDatesInner](docs/CoreCourseGetContentsResponseInnerModulesInnerDatesInner.md)
 - [CoreCourseGetCourseContentItemsResponse](docs/CoreCourseGetCourseContentItemsResponse.md)
 - [CoreCourseGetCourseContentItemsResponseContentItemsInner](docs/CoreCourseGetCourseContentItemsResponseContentItemsInner.md)
 - [CoreCourseGetCourseModuleByInstanceResponse](docs/CoreCourseGetCourseModuleByInstanceResponse.md)
 - [CoreCourseGetCourseModuleByInstanceResponseCm](docs/CoreCourseGetCourseModuleByInstanceResponseCm.md)
 - [CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner](docs/CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner.md)
 - [CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner](docs/CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner.md)
 - [CoreCourseGetCourseModuleResponse](docs/CoreCourseGetCourseModuleResponse.md)
 - [CoreCourseGetCoursesByFieldResponse](docs/CoreCourseGetCoursesByFieldResponse.md)
 - [CoreCourseGetCoursesByFieldResponseCoursesInner](docs/CoreCourseGetCoursesByFieldResponseCoursesInner.md)
 - [CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner](docs/CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner.md)
 - [CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner](docs/CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner.md)
 - [CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner](docs/CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner.md)
 - [CoreCourseGetCoursesParametersOptions](docs/CoreCourseGetCoursesParametersOptions.md)
 - [CoreCourseGetCoursesResponseInner](docs/CoreCourseGetCoursesResponseInner.md)
 - [CoreCourseGetCoursesResponseInnerCustomfieldsInner](docs/CoreCourseGetCoursesResponseInnerCustomfieldsInner.md)
 - [CoreCourseGetEnrolledCoursesByTimelineClassificationResponse](docs/CoreCourseGetEnrolledCoursesByTimelineClassificationResponse.md)
 - [CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse](docs/CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse.md)
 - [CoreCourseGetEnrolledUsersByCmidResponse](docs/CoreCourseGetEnrolledUsersByCmidResponse.md)
 - [CoreCourseGetEnrolledUsersByCmidResponseUsersInner](docs/CoreCourseGetEnrolledUsersByCmidResponseUsersInner.md)
 - [CoreCourseGetUpdatesSinceResponse](docs/CoreCourseGetUpdatesSinceResponse.md)
 - [CoreCourseGetUserAdministrationOptionsResponse](docs/CoreCourseGetUserAdministrationOptionsResponse.md)
 - [CoreCourseGetUserAdministrationOptionsResponseCoursesInner](docs/CoreCourseGetUserAdministrationOptionsResponseCoursesInner.md)
 - [CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner](docs/CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner.md)
 - [CoreCourseGetUserNavigationOptionsResponse](docs/CoreCourseGetUserNavigationOptionsResponse.md)
 - [CoreCourseImportCourseParametersOptionsInner](docs/CoreCourseImportCourseParametersOptionsInner.md)
 - [CoreCourseRemoveContentItemFromUserFavouritesResponse](docs/CoreCourseRemoveContentItemFromUserFavouritesResponse.md)
 - [CoreCourseSearchCoursesResponse](docs/CoreCourseSearchCoursesResponse.md)
 - [CoreCourseSearchCoursesResponseCoursesInner](docs/CoreCourseSearchCoursesResponseCoursesInner.md)
 - [CoreCourseSetFavouriteCoursesParametersCoursesInner](docs/CoreCourseSetFavouriteCoursesParametersCoursesInner.md)
 - [CoreCourseSetFavouriteCoursesResponse](docs/CoreCourseSetFavouriteCoursesResponse.md)
 - [CoreCourseToggleActivityRecommendationResponse](docs/CoreCourseToggleActivityRecommendationResponse.md)
 - [CoreCourseUpdateCategoriesParametersCategoriesInner](docs/CoreCourseUpdateCategoriesParametersCategoriesInner.md)
 - [CoreCourseUpdateCoursesParametersCoursesInner](docs/CoreCourseUpdateCoursesParametersCoursesInner.md)
 - [CoreCourseUpdateCoursesResponse](docs/CoreCourseUpdateCoursesResponse.md)
 - [CoreCourseViewCourseResponse](docs/CoreCourseViewCourseResponse.md)
 - [CoreCourseformatFileHandlersResponseInner](docs/CoreCourseformatFileHandlersResponseInner.md)
 - [CoreCustomfieldReloadTemplateResponse](docs/CoreCustomfieldReloadTemplateResponse.md)
 - [CoreCustomfieldReloadTemplateResponseCategoriesInner](docs/CoreCustomfieldReloadTemplateResponseCategoriesInner.md)
 - [CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner](docs/CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner.md)
 - [CoreDynamicTabsGetContentResponse](docs/CoreDynamicTabsGetContentResponse.md)
 - [CoreEnrolGetCourseEnrolmentMethodsResponseInner](docs/CoreEnrolGetCourseEnrolmentMethodsResponseInner.md)
 - [CoreEnrolGetEnrolledUsersParametersOptionsInner](docs/CoreEnrolGetEnrolledUsersParametersOptionsInner.md)
 - [CoreEnrolGetEnrolledUsersResponseInner](docs/CoreEnrolGetEnrolledUsersResponseInner.md)
 - [CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner](docs/CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner.md)
 - [CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner](docs/CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner.md)
 - [CoreEnrolGetEnrolledUsersResponseInnerGroupsInner](docs/CoreEnrolGetEnrolledUsersResponseInnerGroupsInner.md)
 - [CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner](docs/CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner.md)
 - [CoreEnrolGetEnrolledUsersResponseInnerRolesInner](docs/CoreEnrolGetEnrolledUsersResponseInnerRolesInner.md)
 - [CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner](docs/CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner.md)
 - [CoreEnrolGetEnrolledUsersWithCapabilityResponseInner](docs/CoreEnrolGetEnrolledUsersWithCapabilityResponseInner.md)
 - [CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner](docs/CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner.md)
 - [CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner](docs/CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner.md)
 - [CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner](docs/CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner.md)
 - [CoreEnrolGetPotentialUsersResponseInner](docs/CoreEnrolGetPotentialUsersResponseInner.md)
 - [CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner](docs/CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner.md)
 - [CoreEnrolGetPotentialUsersResponseInnerPreferencesInner](docs/CoreEnrolGetPotentialUsersResponseInnerPreferencesInner.md)
 - [CoreEnrolGetUsersCoursesResponseInner](docs/CoreEnrolGetUsersCoursesResponseInner.md)
 - [CoreEnrolSubmitUserEnrolmentFormResponse](docs/CoreEnrolSubmitUserEnrolmentFormResponse.md)
 - [CoreEnrolUnenrolUserEnrolmentResponse](docs/CoreEnrolUnenrolUserEnrolmentResponse.md)
 - [CoreEnrolUnenrolUserEnrolmentResponseErrorsInner](docs/CoreEnrolUnenrolUserEnrolmentResponseErrorsInner.md)
 - [CoreFetchNotificationsParameters](docs/CoreFetchNotificationsParameters.md)
 - [CoreFetchNotificationsResponseInner](docs/CoreFetchNotificationsResponseInner.md)
 - [CoreFetchNotificationsResponseInnerVariables](docs/CoreFetchNotificationsResponseInnerVariables.md)
 - [CoreFilesDeleteDraftFilesParametersFilesInner](docs/CoreFilesDeleteDraftFilesParametersFilesInner.md)
 - [CoreFilesDeleteDraftFilesResponse](docs/CoreFilesDeleteDraftFilesResponse.md)
 - [CoreFilesGetFilesResponse](docs/CoreFilesGetFilesResponse.md)
 - [CoreFilesGetFilesResponseFilesInner](docs/CoreFilesGetFilesResponseFilesInner.md)
 - [CoreFilesGetFilesResponseParentsInner](docs/CoreFilesGetFilesResponseParentsInner.md)
 - [CoreFilesGetUnusedDraftItemidResponse](docs/CoreFilesGetUnusedDraftItemidResponse.md)
 - [CoreFilesUploadResponse](docs/CoreFilesUploadResponse.md)
 - [CoreFiltersGetAllStatesResponse](docs/CoreFiltersGetAllStatesResponse.md)
 - [CoreFiltersGetAllStatesResponseFiltersInner](docs/CoreFiltersGetAllStatesResponseFiltersInner.md)
 - [CoreFiltersGetAvailableInContextParametersContextsInner](docs/CoreFiltersGetAvailableInContextParametersContextsInner.md)
 - [CoreFiltersGetAvailableInContextResponse](docs/CoreFiltersGetAvailableInContextResponse.md)
 - [CoreFiltersGetAvailableInContextResponseFiltersInner](docs/CoreFiltersGetAvailableInContextResponseFiltersInner.md)
 - [CoreFormDynamicFormResponse](docs/CoreFormDynamicFormResponse.md)
 - [CoreFormGetFiletypesBrowserDataParameters](docs/CoreFormGetFiletypesBrowserDataParameters.md)
 - [CoreFormGetFiletypesBrowserDataResponse](docs/CoreFormGetFiletypesBrowserDataResponse.md)
 - [CoreFormGetFiletypesBrowserDataResponseGroupsInner](docs/CoreFormGetFiletypesBrowserDataResponseGroupsInner.md)
 - [CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner](docs/CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner.md)
 - [CoreGetComponentStringsParameters](docs/CoreGetComponentStringsParameters.md)
 - [CoreGetComponentStringsResponseInner](docs/CoreGetComponentStringsResponseInner.md)
 - [CoreGetFragmentParametersArgsInner](docs/CoreGetFragmentParametersArgsInner.md)
 - [CoreGetFragmentResponse](docs/CoreGetFragmentResponse.md)
 - [CoreGetStringParameters](docs/CoreGetStringParameters.md)
 - [CoreGetStringParametersStringparamsInner](docs/CoreGetStringParametersStringparamsInner.md)
 - [CoreGetStringsParameters](docs/CoreGetStringsParameters.md)
 - [CoreGetStringsParametersStringsInner](docs/CoreGetStringsParametersStringsInner.md)
 - [CoreGetStringsParametersStringsInnerStringparamsInner](docs/CoreGetStringsParametersStringsInnerStringparamsInner.md)
 - [CoreGetStringsResponseInner](docs/CoreGetStringsResponseInner.md)
 - [CoreGetUserDatesParametersTimestampsInner](docs/CoreGetUserDatesParametersTimestampsInner.md)
 - [CoreGetUserDatesResponse](docs/CoreGetUserDatesResponse.md)
 - [CoreGradesCreateGradecategoriesParametersCategoriesInner](docs/CoreGradesCreateGradecategoriesParametersCategoriesInner.md)
 - [CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions](docs/CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions.md)
 - [CoreGradesCreateGradecategoriesResponse](docs/CoreGradesCreateGradecategoriesResponse.md)
 - [CoreGradesGetEnrolledUsersForSelectorResponse](docs/CoreGradesGetEnrolledUsersForSelectorResponse.md)
 - [CoreGradesGetFeedbackResponse](docs/CoreGradesGetFeedbackResponse.md)
 - [CoreGradesGetGradableUsersResponse](docs/CoreGradesGetGradableUsersResponse.md)
 - [CoreGradesGetGradeitemsResponse](docs/CoreGradesGetGradeitemsResponse.md)
 - [CoreGradesGetGradeitemsResponseGradeItemsInner](docs/CoreGradesGetGradeitemsResponseGradeItemsInner.md)
 - [CoreGradesGetGroupsForSelectorResponse](docs/CoreGradesGetGroupsForSelectorResponse.md)
 - [CoreGradesGetGroupsForSelectorResponseGroupsInner](docs/CoreGradesGetGroupsForSelectorResponseGroupsInner.md)
 - [CoreGradesGraderGradingpanelPointFetchResponse](docs/CoreGradesGraderGradingpanelPointFetchResponse.md)
 - [CoreGradesGraderGradingpanelPointFetchResponseGrade](docs/CoreGradesGraderGradingpanelPointFetchResponseGrade.md)
 - [CoreGradesGraderGradingpanelPointStoreResponse](docs/CoreGradesGraderGradingpanelPointStoreResponse.md)
 - [CoreGradesGraderGradingpanelScaleFetchResponse](docs/CoreGradesGraderGradingpanelScaleFetchResponse.md)
 - [CoreGradesGraderGradingpanelScaleFetchResponseGrade](docs/CoreGradesGraderGradingpanelScaleFetchResponseGrade.md)
 - [CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner](docs/CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner.md)
 - [CoreGradesGraderGradingpanelScaleStoreResponse](docs/CoreGradesGraderGradingpanelScaleStoreResponse.md)
 - [CoreGradesUpdateGradesParametersGradesInner](docs/CoreGradesUpdateGradesParametersGradesInner.md)
 - [CoreGradesUpdateGradesParametersItemdetails](docs/CoreGradesUpdateGradesParametersItemdetails.md)
 - [CoreGradingGetDefinitionsResponse](docs/CoreGradingGetDefinitionsResponse.md)
 - [CoreGradingGetDefinitionsResponseAreasInner](docs/CoreGradingGetDefinitionsResponseAreasInner.md)
 - [CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner](docs/CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner.md)
 - [CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide](docs/CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide.md)
 - [CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner](docs/CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner.md)
 - [CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner](docs/CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner.md)
 - [CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric](docs/CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric.md)
 - [CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner](docs/CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner.md)
 - [CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner](docs/CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner.md)
 - [CoreGradingGetGradingformInstancesResponse](docs/CoreGradingGetGradingformInstancesResponse.md)
 - [CoreGradingGetGradingformInstancesResponseInstancesInner](docs/CoreGradingGetGradingformInstancesResponseInstancesInner.md)
 - [CoreGradingGetGradingformInstancesResponseInstancesInnerGuide](docs/CoreGradingGetGradingformInstancesResponseInstancesInnerGuide.md)
 - [CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner](docs/CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner.md)
 - [CoreGradingGetGradingformInstancesResponseInstancesInnerRubric](docs/CoreGradingGetGradingformInstancesResponseInstancesInnerRubric.md)
 - [CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner](docs/CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner.md)
 - [CoreGroupAddGroupMembersParametersMembersInner](docs/CoreGroupAddGroupMembersParametersMembersInner.md)
 - [CoreGroupAssignGroupingParametersAssignmentsInner](docs/CoreGroupAssignGroupingParametersAssignmentsInner.md)
 - [CoreGroupCreateGroupingsParametersGroupingsInner](docs/CoreGroupCreateGroupingsParametersGroupingsInner.md)
 - [CoreGroupCreateGroupingsResponseInner](docs/CoreGroupCreateGroupingsResponseInner.md)
 - [CoreGroupCreateGroupsParametersGroupsInner](docs/CoreGroupCreateGroupsParametersGroupsInner.md)
 - [CoreGroupCreateGroupsResponseInner](docs/CoreGroupCreateGroupsResponseInner.md)
 - [CoreGroupGetActivityAllowedGroupsResponse](docs/CoreGroupGetActivityAllowedGroupsResponse.md)
 - [CoreGroupGetActivityAllowedGroupsResponseGroupsInner](docs/CoreGroupGetActivityAllowedGroupsResponseGroupsInner.md)
 - [CoreGroupGetActivityGroupmodeResponse](docs/CoreGroupGetActivityGroupmodeResponse.md)
 - [CoreGroupGetCourseGroupingsResponseInner](docs/CoreGroupGetCourseGroupingsResponseInner.md)
 - [CoreGroupGetCourseGroupsResponseInner](docs/CoreGroupGetCourseGroupsResponseInner.md)
 - [CoreGroupGetCourseUserGroupsResponse](docs/CoreGroupGetCourseUserGroupsResponse.md)
 - [CoreGroupGetGroupMembersResponseInner](docs/CoreGroupGetGroupMembersResponseInner.md)
 - [CoreGroupGetGroupingsResponseInner](docs/CoreGroupGetGroupingsResponseInner.md)
 - [CoreGroupGetGroupingsResponseInnerGroupsInner](docs/CoreGroupGetGroupingsResponseInnerGroupsInner.md)
 - [CoreGroupGetGroupsForSelectorResponse](docs/CoreGroupGetGroupsForSelectorResponse.md)
 - [CoreGroupGetGroupsResponseInner](docs/CoreGroupGetGroupsResponseInner.md)
 - [CoreGroupUpdateGroupingsParametersGroupingsInner](docs/CoreGroupUpdateGroupingsParametersGroupingsInner.md)
 - [CoreGroupUpdateGroupsParametersGroupsInner](docs/CoreGroupUpdateGroupsParametersGroupsInner.md)
 - [CoreH5pGetTrustedH5pFileResponse](docs/CoreH5pGetTrustedH5pFileResponse.md)
 - [CoreMessageCreateContactRequestResponse](docs/CoreMessageCreateContactRequestResponse.md)
 - [CoreMessageCreateContactRequestResponseRequest](docs/CoreMessageCreateContactRequestResponseRequest.md)
 - [CoreMessageDataForMessageareaSearchMessagesResponse](docs/CoreMessageDataForMessageareaSearchMessagesResponse.md)
 - [CoreMessageDataForMessageareaSearchMessagesResponseContactsInner](docs/CoreMessageDataForMessageareaSearchMessagesResponseContactsInner.md)
 - [CoreMessageDeleteMessageResponse](docs/CoreMessageDeleteMessageResponse.md)
 - [CoreMessageGetBlockedUsersResponse](docs/CoreMessageGetBlockedUsersResponse.md)
 - [CoreMessageGetBlockedUsersResponseUsersInner](docs/CoreMessageGetBlockedUsersResponseUsersInner.md)
 - [CoreMessageGetContactRequestsResponseInner](docs/CoreMessageGetContactRequestsResponseInner.md)
 - [CoreMessageGetContactRequestsResponseInnerContactrequestsInner](docs/CoreMessageGetContactRequestsResponseInnerContactrequestsInner.md)
 - [CoreMessageGetContactRequestsResponseInnerConversationsInner](docs/CoreMessageGetContactRequestsResponseInnerConversationsInner.md)
 - [CoreMessageGetConversationBetweenUsersResponse](docs/CoreMessageGetConversationBetweenUsersResponse.md)
 - [CoreMessageGetConversationBetweenUsersResponseMessagesInner](docs/CoreMessageGetConversationBetweenUsersResponseMessagesInner.md)
 - [CoreMessageGetConversationCountsResponse](docs/CoreMessageGetConversationCountsResponse.md)
 - [CoreMessageGetConversationCountsResponseTypes](docs/CoreMessageGetConversationCountsResponseTypes.md)
 - [CoreMessageGetConversationMessagesResponse](docs/CoreMessageGetConversationMessagesResponse.md)
 - [CoreMessageGetConversationResponse](docs/CoreMessageGetConversationResponse.md)
 - [CoreMessageGetConversationsResponse](docs/CoreMessageGetConversationsResponse.md)
 - [CoreMessageGetConversationsResponseConversationsInner](docs/CoreMessageGetConversationsResponseConversationsInner.md)
 - [CoreMessageGetMessageProcessorResponse](docs/CoreMessageGetMessageProcessorResponse.md)
 - [CoreMessageGetMessagesResponse](docs/CoreMessageGetMessagesResponse.md)
 - [CoreMessageGetMessagesResponseMessagesInner](docs/CoreMessageGetMessagesResponseMessagesInner.md)
 - [CoreMessageGetSelfConversationResponse](docs/CoreMessageGetSelfConversationResponse.md)
 - [CoreMessageGetUnreadConversationCountsResponse](docs/CoreMessageGetUnreadConversationCountsResponse.md)
 - [CoreMessageGetUnreadConversationCountsResponseTypes](docs/CoreMessageGetUnreadConversationCountsResponseTypes.md)
 - [CoreMessageGetUnsentMessageResponse](docs/CoreMessageGetUnsentMessageResponse.md)
 - [CoreMessageGetUserMessagePreferencesResponse](docs/CoreMessageGetUserMessagePreferencesResponse.md)
 - [CoreMessageGetUserMessagePreferencesResponsePreferences](docs/CoreMessageGetUserMessagePreferencesResponsePreferences.md)
 - [CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner](docs/CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner.md)
 - [CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner](docs/CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner.md)
 - [CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner](docs/CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner.md)
 - [CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner](docs/CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner.md)
 - [CoreMessageGetUserNotificationPreferencesResponse](docs/CoreMessageGetUserNotificationPreferencesResponse.md)
 - [CoreMessageMarkMessageReadResponse](docs/CoreMessageMarkMessageReadResponse.md)
 - [CoreMessageMarkNotificationReadResponse](docs/CoreMessageMarkNotificationReadResponse.md)
 - [CoreMessageMessageProcessorConfigFormParametersFormvaluesInner](docs/CoreMessageMessageProcessorConfigFormParametersFormvaluesInner.md)
 - [CoreMessageMessageSearchUsersResponse](docs/CoreMessageMessageSearchUsersResponse.md)
 - [CoreMessageSearchContactsResponseInner](docs/CoreMessageSearchContactsResponseInner.md)
 - [CoreMessageSendInstantMessagesParametersMessagesInner](docs/CoreMessageSendInstantMessagesParametersMessagesInner.md)
 - [CoreMessageSendInstantMessagesResponseInner](docs/CoreMessageSendInstantMessagesResponseInner.md)
 - [CoreMessageSendMessagesToConversationParametersMessagesInner](docs/CoreMessageSendMessagesToConversationParametersMessagesInner.md)
 - [CoreMessageSetDefaultNotificationResponse](docs/CoreMessageSetDefaultNotificationResponse.md)
 - [CoreMoodlenetAuthCheckResponse](docs/CoreMoodlenetAuthCheckResponse.md)
 - [CoreMoodlenetGetShareInfoActivityResponse](docs/CoreMoodlenetGetShareInfoActivityResponse.md)
 - [CoreMoodlenetGetSharedCourseInfoResponse](docs/CoreMoodlenetGetSharedCourseInfoResponse.md)
 - [CoreMoodlenetSendActivityResponse](docs/CoreMoodlenetSendActivityResponse.md)
 - [CoreMoodlenetSendCourseResponse](docs/CoreMoodlenetSendCourseResponse.md)
 - [CoreMyViewPageResponse](docs/CoreMyViewPageResponse.md)
 - [CoreNotesCreateNotesParametersNotesInner](docs/CoreNotesCreateNotesParametersNotesInner.md)
 - [CoreNotesCreateNotesResponseInner](docs/CoreNotesCreateNotesResponseInner.md)
 - [CoreNotesDeleteNotesResponseInner](docs/CoreNotesDeleteNotesResponseInner.md)
 - [CoreNotesGetCourseNotesResponse](docs/CoreNotesGetCourseNotesResponse.md)
 - [CoreNotesGetCourseNotesResponseCoursenotesInner](docs/CoreNotesGetCourseNotesResponseCoursenotesInner.md)
 - [CoreNotesGetNotesResponse](docs/CoreNotesGetNotesResponse.md)
 - [CoreNotesGetNotesResponseNotesInner](docs/CoreNotesGetNotesResponseNotesInner.md)
 - [CoreNotesUpdateNotesParametersNotesInner](docs/CoreNotesUpdateNotesParametersNotesInner.md)
 - [CoreNotesViewNotesResponse](docs/CoreNotesViewNotesResponse.md)
 - [CoreOutputLoadFontawesomeIconSystemMapParameters](docs/CoreOutputLoadFontawesomeIconSystemMapParameters.md)
 - [CoreOutputLoadFontawesomeIconSystemMapResponseInner](docs/CoreOutputLoadFontawesomeIconSystemMapResponseInner.md)
 - [CoreOutputLoadTemplateParameters](docs/CoreOutputLoadTemplateParameters.md)
 - [CoreOutputLoadTemplateWithDependenciesParameters](docs/CoreOutputLoadTemplateWithDependenciesParameters.md)
 - [CoreOutputLoadTemplateWithDependenciesResponse](docs/CoreOutputLoadTemplateWithDependenciesResponse.md)
 - [CoreOutputLoadTemplateWithDependenciesResponseStringsInner](docs/CoreOutputLoadTemplateWithDependenciesResponseStringsInner.md)
 - [CoreOutputPollStoredProgressResponseInner](docs/CoreOutputPollStoredProgressResponseInner.md)
 - [CorePaymentGetAvailableGatewaysResponseInner](docs/CorePaymentGetAvailableGatewaysResponseInner.md)
 - [CoreQuestionGetRandomQuestionSummariesResponse](docs/CoreQuestionGetRandomQuestionSummariesResponse.md)
 - [CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner](docs/CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner.md)
 - [CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon](docs/CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon.md)
 - [CoreQuestionSearchSharedBanksResponse](docs/CoreQuestionSearchSharedBanksResponse.md)
 - [CoreQuestionSearchSharedBanksResponseSharedbanksInner](docs/CoreQuestionSearchSharedBanksResponseSharedbanksInner.md)
 - [CoreQuestionUpdateFlagResponse](docs/CoreQuestionUpdateFlagResponse.md)
 - [CoreRatingAddRatingResponse](docs/CoreRatingAddRatingResponse.md)
 - [CoreRatingGetItemRatingsResponse](docs/CoreRatingGetItemRatingsResponse.md)
 - [CoreRatingGetItemRatingsResponseRatingsInner](docs/CoreRatingGetItemRatingsResponseRatingsInner.md)
 - [CoreReportbuilderCanViewSystemReportParametersParametersInner](docs/CoreReportbuilderCanViewSystemReportParametersParametersInner.md)
 - [CoreReportbuilderColumnsAddResponse](docs/CoreReportbuilderColumnsAddResponse.md)
 - [CoreReportbuilderColumnsAddResponseSortablecolumnsInner](docs/CoreReportbuilderColumnsAddResponseSortablecolumnsInner.md)
 - [CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon](docs/CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon.md)
 - [CoreReportbuilderColumnsDeleteResponse](docs/CoreReportbuilderColumnsDeleteResponse.md)
 - [CoreReportbuilderColumnsSortGetResponse](docs/CoreReportbuilderColumnsSortGetResponse.md)
 - [CoreReportbuilderColumnsSortReorderResponse](docs/CoreReportbuilderColumnsSortReorderResponse.md)
 - [CoreReportbuilderColumnsSortToggleResponse](docs/CoreReportbuilderColumnsSortToggleResponse.md)
 - [CoreReportbuilderConditionsAddResponse](docs/CoreReportbuilderConditionsAddResponse.md)
 - [CoreReportbuilderConditionsAddResponseAvailableconditionsInner](docs/CoreReportbuilderConditionsAddResponseAvailableconditionsInner.md)
 - [CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup](docs/CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup.md)
 - [CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner](docs/CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner.md)
 - [CoreReportbuilderConditionsDeleteResponse](docs/CoreReportbuilderConditionsDeleteResponse.md)
 - [CoreReportbuilderConditionsReorderResponse](docs/CoreReportbuilderConditionsReorderResponse.md)
 - [CoreReportbuilderConditionsResetResponse](docs/CoreReportbuilderConditionsResetResponse.md)
 - [CoreReportbuilderFiltersAddResponse](docs/CoreReportbuilderFiltersAddResponse.md)
 - [CoreReportbuilderFiltersAddResponseActivefiltersInner](docs/CoreReportbuilderFiltersAddResponseActivefiltersInner.md)
 - [CoreReportbuilderFiltersDeleteResponse](docs/CoreReportbuilderFiltersDeleteResponse.md)
 - [CoreReportbuilderFiltersReorderResponse](docs/CoreReportbuilderFiltersReorderResponse.md)
 - [CoreReportbuilderListReportsResponse](docs/CoreReportbuilderListReportsResponse.md)
 - [CoreReportbuilderListReportsResponseReportsInner](docs/CoreReportbuilderListReportsResponseReportsInner.md)
 - [CoreReportbuilderListReportsResponseReportsInnerCustomfields](docs/CoreReportbuilderListReportsResponseReportsInnerCustomfields.md)
 - [CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner](docs/CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner.md)
 - [CoreReportbuilderReportsGetResponse](docs/CoreReportbuilderReportsGetResponse.md)
 - [CoreReportbuilderReportsGetResponseAttributesInner](docs/CoreReportbuilderReportsGetResponseAttributesInner.md)
 - [CoreReportbuilderReportsGetResponseButton](docs/CoreReportbuilderReportsGetResponseButton.md)
 - [CoreReportbuilderReportsGetResponseButtonAttributesInner](docs/CoreReportbuilderReportsGetResponseButtonAttributesInner.md)
 - [CoreReportbuilderReportsGetResponseCardview](docs/CoreReportbuilderReportsGetResponseCardview.md)
 - [CoreReportbuilderReportsGetResponseConditions](docs/CoreReportbuilderReportsGetResponseConditions.md)
 - [CoreReportbuilderReportsGetResponseFilters](docs/CoreReportbuilderReportsGetResponseFilters.md)
 - [CoreReportbuilderReportsGetResponseSidebarmenucards](docs/CoreReportbuilderReportsGetResponseSidebarmenucards.md)
 - [CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner](docs/CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner.md)
 - [CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner](docs/CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner.md)
 - [CoreReportbuilderReportsGetResponseSorting](docs/CoreReportbuilderReportsGetResponseSorting.md)
 - [CoreReportbuilderRetrieveReportResponse](docs/CoreReportbuilderRetrieveReportResponse.md)
 - [CoreReportbuilderRetrieveReportResponseData](docs/CoreReportbuilderRetrieveReportResponseData.md)
 - [CoreReportbuilderRetrieveReportResponseDataRowsInner](docs/CoreReportbuilderRetrieveReportResponseDataRowsInner.md)
 - [CoreReportbuilderRetrieveSystemReportResponse](docs/CoreReportbuilderRetrieveSystemReportResponse.md)
 - [CoreReportbuilderViewReportResponse](docs/CoreReportbuilderViewReportResponse.md)
 - [CoreRoleAssignRolesParametersAssignmentsInner](docs/CoreRoleAssignRolesParametersAssignmentsInner.md)
 - [CoreRoleUnassignRolesParametersUnassignmentsInner](docs/CoreRoleUnassignRolesParametersUnassignmentsInner.md)
 - [CoreSearchGetRelevantUsersResponseInner](docs/CoreSearchGetRelevantUsersResponseInner.md)
 - [CoreSearchGetResultsParametersFilters](docs/CoreSearchGetResultsParametersFilters.md)
 - [CoreSearchGetResultsResponse](docs/CoreSearchGetResultsResponse.md)
 - [CoreSearchGetResultsResponseResultsInner](docs/CoreSearchGetResultsResponseResultsInner.md)
 - [CoreSearchGetSearchAreasListResponse](docs/CoreSearchGetSearchAreasListResponse.md)
 - [CoreSearchGetSearchAreasListResponseAreasInner](docs/CoreSearchGetSearchAreasListResponseAreasInner.md)
 - [CoreSearchGetTopResultsResponse](docs/CoreSearchGetTopResultsResponse.md)
 - [CoreSearchViewResultsParametersFilters](docs/CoreSearchViewResultsParametersFilters.md)
 - [CoreSearchViewResultsResponse](docs/CoreSearchViewResultsResponse.md)
 - [CoreSessionTimeRemainingResponse](docs/CoreSessionTimeRemainingResponse.md)
 - [CoreSmsSetGatewayStatusResponse](docs/CoreSmsSetGatewayStatusResponse.md)
 - [CoreTableGetDynamicTableContentParametersFiltersInner](docs/CoreTableGetDynamicTableContentParametersFiltersInner.md)
 - [CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner](docs/CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner.md)
 - [CoreTableGetDynamicTableContentParametersSortdataInner](docs/CoreTableGetDynamicTableContentParametersSortdataInner.md)
 - [CoreTableGetDynamicTableContentResponse](docs/CoreTableGetDynamicTableContentResponse.md)
 - [CoreTagGetTagAreasResponse](docs/CoreTagGetTagAreasResponse.md)
 - [CoreTagGetTagAreasResponseAreasInner](docs/CoreTagGetTagAreasResponseAreasInner.md)
 - [CoreTagGetTagCloudResponse](docs/CoreTagGetTagCloudResponse.md)
 - [CoreTagGetTagCloudResponseTagsInner](docs/CoreTagGetTagCloudResponseTagsInner.md)
 - [CoreTagGetTagCollectionsResponse](docs/CoreTagGetTagCollectionsResponse.md)
 - [CoreTagGetTagCollectionsResponseCollectionsInner](docs/CoreTagGetTagCollectionsResponseCollectionsInner.md)
 - [CoreTagGetTagindexParametersTagindex](docs/CoreTagGetTagindexParametersTagindex.md)
 - [CoreTagGetTagindexPerAreaParametersTagindex](docs/CoreTagGetTagindexPerAreaParametersTagindex.md)
 - [CoreTagGetTagindexPerAreaResponseInner](docs/CoreTagGetTagindexPerAreaResponseInner.md)
 - [CoreTagGetTagindexResponse](docs/CoreTagGetTagindexResponse.md)
 - [CoreTagGetTagsParametersTagsInner](docs/CoreTagGetTagsParametersTagsInner.md)
 - [CoreTagGetTagsResponse](docs/CoreTagGetTagsResponse.md)
 - [CoreTagGetTagsResponseTagsInner](docs/CoreTagGetTagsResponseTagsInner.md)
 - [CoreTagUpdateTagsParametersTagsInner](docs/CoreTagUpdateTagsParametersTagsInner.md)
 - [CoreTagUpdateTagsResponse](docs/CoreTagUpdateTagsResponse.md)
 - [CoreUpdateInplaceEditableResponse](docs/CoreUpdateInplaceEditableResponse.md)
 - [CoreUpdateInplaceEditableResponseEditicon](docs/CoreUpdateInplaceEditableResponseEditicon.md)
 - [CoreUserAgreeSitePolicyResponse](docs/CoreUserAgreeSitePolicyResponse.md)
 - [CoreUserCreateUsersParametersUsersInner](docs/CoreUserCreateUsersParametersUsersInner.md)
 - [CoreUserCreateUsersParametersUsersInnerCustomfieldsInner](docs/CoreUserCreateUsersParametersUsersInnerCustomfieldsInner.md)
 - [CoreUserCreateUsersParametersUsersInnerPreferencesInner](docs/CoreUserCreateUsersParametersUsersInnerPreferencesInner.md)
 - [CoreUserCreateUsersResponseInner](docs/CoreUserCreateUsersResponseInner.md)
 - [CoreUserGetCourseUserProfilesParametersUserlistInner](docs/CoreUserGetCourseUserProfilesParametersUserlistInner.md)
 - [CoreUserGetCourseUserProfilesResponseInner](docs/CoreUserGetCourseUserProfilesResponseInner.md)
 - [CoreUserGetPrivateFilesInfoResponse](docs/CoreUserGetPrivateFilesInfoResponse.md)
 - [CoreUserGetUserPreferencesResponse](docs/CoreUserGetUserPreferencesResponse.md)
 - [CoreUserGetUserPreferencesResponsePreferencesInner](docs/CoreUserGetUserPreferencesResponsePreferencesInner.md)
 - [CoreUserGetUsersParametersCriteriaInner](docs/CoreUserGetUsersParametersCriteriaInner.md)
 - [CoreUserGetUsersResponse](docs/CoreUserGetUsersResponse.md)
 - [CoreUserGetUsersResponseWarningsInner](docs/CoreUserGetUsersResponseWarningsInner.md)
 - [CoreUserPreparePrivateFilesForEditionResponse](docs/CoreUserPreparePrivateFilesForEditionResponse.md)
 - [CoreUserRemoveUserDeviceResponse](docs/CoreUserRemoveUserDeviceResponse.md)
 - [CoreUserSearchIdentityResponse](docs/CoreUserSearchIdentityResponse.md)
 - [CoreUserSearchIdentityResponseListInner](docs/CoreUserSearchIdentityResponseListInner.md)
 - [CoreUserSearchIdentityResponseListInnerExtrafieldsInner](docs/CoreUserSearchIdentityResponseListInnerExtrafieldsInner.md)
 - [CoreUserSetUserPreferencesParameters](docs/CoreUserSetUserPreferencesParameters.md)
 - [CoreUserSetUserPreferencesParametersPreferencesInner](docs/CoreUserSetUserPreferencesParametersPreferencesInner.md)
 - [CoreUserSetUserPreferencesResponse](docs/CoreUserSetUserPreferencesResponse.md)
 - [CoreUserSetUserPreferencesResponseSavedInner](docs/CoreUserSetUserPreferencesResponseSavedInner.md)
 - [CoreUserUpdatePictureResponse](docs/CoreUserUpdatePictureResponse.md)
 - [CoreUserUpdatePrivateFilesResponse](docs/CoreUserUpdatePrivateFilesResponse.md)
 - [CoreUserUpdateUserDevicePublicKeyResponse](docs/CoreUserUpdateUserDevicePublicKeyResponse.md)
 - [CoreUserUpdateUserPreferencesParametersPreferencesInner](docs/CoreUserUpdateUserPreferencesParametersPreferencesInner.md)
 - [CoreUserUpdateUsersParametersUsersInner](docs/CoreUserUpdateUsersParametersUsersInner.md)
 - [CoreUserUpdateUsersResponse](docs/CoreUserUpdateUsersResponse.md)
 - [CoreUserViewUserListResponse](docs/CoreUserViewUserListResponse.md)
 - [CoreUserViewUserProfileResponse](docs/CoreUserViewUserProfileResponse.md)
 - [CoreWebserviceGetSiteInfoResponse](docs/CoreWebserviceGetSiteInfoResponse.md)
 - [CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner](docs/CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner.md)
 - [CoreWebserviceGetSiteInfoResponseFunctionsInner](docs/CoreWebserviceGetSiteInfoResponseFunctionsInner.md)
 - [CustomfieldNumberRecalculateValueResponse](docs/CustomfieldNumberRecalculateValueResponse.md)
 - [EditorTinyGetConfigurationResponse](docs/EditorTinyGetConfigurationResponse.md)
 - [EditorTinyGetConfigurationResponseInstalledlanguagesInner](docs/EditorTinyGetConfigurationResponseInstalledlanguagesInner.md)
 - [EditorTinyGetConfigurationResponsePluginsInner](docs/EditorTinyGetConfigurationResponsePluginsInner.md)
 - [EditorTinyGetConfigurationResponsePluginsInnerSettingsInner](docs/EditorTinyGetConfigurationResponsePluginsInnerSettingsInner.md)
 - [EnrolGuestGetInstanceInfoResponse](docs/EnrolGuestGetInstanceInfoResponse.md)
 - [EnrolGuestGetInstanceInfoResponseInstanceinfo](docs/EnrolGuestGetInstanceInfoResponseInstanceinfo.md)
 - [EnrolGuestValidatePasswordResponse](docs/EnrolGuestValidatePasswordResponse.md)
 - [EnrolManualEnrolUsersParametersEnrolmentsInner](docs/EnrolManualEnrolUsersParametersEnrolmentsInner.md)
 - [EnrolManualUnenrolUsersParametersEnrolmentsInner](docs/EnrolManualUnenrolUsersParametersEnrolmentsInner.md)
 - [EnrolMetaAddInstancesParametersInstancesInner](docs/EnrolMetaAddInstancesParametersInstancesInner.md)
 - [EnrolMetaAddInstancesResponseInner](docs/EnrolMetaAddInstancesResponseInner.md)
 - [EnrolMetaDeleteInstancesParametersInstancesInner](docs/EnrolMetaDeleteInstancesParametersInstancesInner.md)
 - [EnrolMetaDeleteInstancesResponseInner](docs/EnrolMetaDeleteInstancesResponseInner.md)
 - [EnrolSelfEnrolUserResponse](docs/EnrolSelfEnrolUserResponse.md)
 - [EnrolSelfGetInstanceInfoResponse](docs/EnrolSelfGetInstanceInfoResponse.md)
 - [GradereportGraderGetUsersInReportResponse](docs/GradereportGraderGetUsersInReportResponse.md)
 - [GradereportOverviewGetCourseGradesResponse](docs/GradereportOverviewGetCourseGradesResponse.md)
 - [GradereportOverviewGetCourseGradesResponseGradesInner](docs/GradereportOverviewGetCourseGradesResponseGradesInner.md)
 - [GradereportOverviewViewGradeReportResponse](docs/GradereportOverviewViewGradeReportResponse.md)
 - [GradereportSingleviewGetGradeItemsForSearchWidgetResponse](docs/GradereportSingleviewGetGradeItemsForSearchWidgetResponse.md)
 - [GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner](docs/GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner.md)
 - [GradereportUserGetAccessInformationResponse](docs/GradereportUserGetAccessInformationResponse.md)
 - [GradereportUserGetGradeItemsResponse](docs/GradereportUserGetGradeItemsResponse.md)
 - [GradereportUserGetGradeItemsResponseUsergradesInner](docs/GradereportUserGetGradeItemsResponseUsergradesInner.md)
 - [GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner](docs/GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner.md)
 - [GradereportUserGetGradesTableResponse](docs/GradereportUserGetGradesTableResponse.md)
 - [GradereportUserGetGradesTableResponseTablesInner](docs/GradereportUserGetGradesTableResponseTablesInner.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInner](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInner.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank.md)
 - [GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight](docs/GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight.md)
 - [GradereportUserViewGradeReportResponse](docs/GradereportUserViewGradeReportResponse.md)
 - [GradingformGuideGraderGradingpanelFetchResponse](docs/GradingformGuideGraderGradingpanelFetchResponse.md)
 - [GradingformGuideGraderGradingpanelFetchResponseGrade](docs/GradingformGuideGraderGradingpanelFetchResponseGrade.md)
 - [GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner](docs/GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner.md)
 - [GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner](docs/GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner.md)
 - [GradingformGuideGraderGradingpanelStoreResponse](docs/GradingformGuideGraderGradingpanelStoreResponse.md)
 - [GradingformRubricGraderGradingpanelFetchResponse](docs/GradingformRubricGraderGradingpanelFetchResponse.md)
 - [GradingformRubricGraderGradingpanelFetchResponseGrade](docs/GradingformRubricGraderGradingpanelFetchResponseGrade.md)
 - [GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner](docs/GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner.md)
 - [GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner](docs/GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner.md)
 - [GradingformRubricGraderGradingpanelStoreResponse](docs/GradingformRubricGraderGradingpanelStoreResponse.md)
 - [LoginToken200Response](docs/LoginToken200Response.md)
 - [MediaVideojsGetLanguageParameters](docs/MediaVideojsGetLanguageParameters.md)
 - [MessageAirnotifierAreNotificationPreferencesConfiguredResponse](docs/MessageAirnotifierAreNotificationPreferencesConfiguredResponse.md)
 - [MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner](docs/MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner.md)
 - [MessageAirnotifierEnableDeviceResponse](docs/MessageAirnotifierEnableDeviceResponse.md)
 - [MessageAirnotifierGetUserDevicesResponse](docs/MessageAirnotifierGetUserDevicesResponse.md)
 - [MessageAirnotifierGetUserDevicesResponseDevicesInner](docs/MessageAirnotifierGetUserDevicesResponseDevicesInner.md)
 - [MessagePopupGetPopupNotificationsResponse](docs/MessagePopupGetPopupNotificationsResponse.md)
 - [MessagePopupGetPopupNotificationsResponseNotificationsInner](docs/MessagePopupGetPopupNotificationsResponseNotificationsInner.md)
 - [ModAssignGetAssignmentsResponse](docs/ModAssignGetAssignmentsResponse.md)
 - [ModAssignGetAssignmentsResponseCoursesInner](docs/ModAssignGetAssignmentsResponseCoursesInner.md)
 - [ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner](docs/ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner.md)
 - [ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner](docs/ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner.md)
 - [ModAssignGetAssignmentsResponseWarningsInner](docs/ModAssignGetAssignmentsResponseWarningsInner.md)
 - [ModAssignGetGradesResponse](docs/ModAssignGetGradesResponse.md)
 - [ModAssignGetGradesResponseAssignmentsInner](docs/ModAssignGetGradesResponseAssignmentsInner.md)
 - [ModAssignGetGradesResponseAssignmentsInnerGradesInner](docs/ModAssignGetGradesResponseAssignmentsInnerGradesInner.md)
 - [ModAssignGetGradesResponseWarningsInner](docs/ModAssignGetGradesResponseWarningsInner.md)
 - [ModAssignGetParticipantResponse](docs/ModAssignGetParticipantResponse.md)
 - [ModAssignGetSubmissionStatusResponse](docs/ModAssignGetSubmissionStatusResponse.md)
 - [ModAssignGetSubmissionStatusResponseAssignmentdata](docs/ModAssignGetSubmissionStatusResponseAssignmentdata.md)
 - [ModAssignGetSubmissionStatusResponseAssignmentdataAttachments](docs/ModAssignGetSubmissionStatusResponseAssignmentdataAttachments.md)
 - [ModAssignGetSubmissionStatusResponseFeedback](docs/ModAssignGetSubmissionStatusResponseFeedback.md)
 - [ModAssignGetSubmissionStatusResponseFeedbackPluginsInner](docs/ModAssignGetSubmissionStatusResponseFeedbackPluginsInner.md)
 - [ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner](docs/ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner.md)
 - [ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner](docs/ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner.md)
 - [ModAssignGetSubmissionStatusResponseGradingsummary](docs/ModAssignGetSubmissionStatusResponseGradingsummary.md)
 - [ModAssignGetSubmissionStatusResponseLastattempt](docs/ModAssignGetSubmissionStatusResponseLastattempt.md)
 - [ModAssignGetSubmissionStatusResponseLastattemptSubmission](docs/ModAssignGetSubmissionStatusResponseLastattemptSubmission.md)
 - [ModAssignGetSubmissionStatusResponsePreviousattemptsInner](docs/ModAssignGetSubmissionStatusResponsePreviousattemptsInner.md)
 - [ModAssignGetSubmissionsResponse](docs/ModAssignGetSubmissionsResponse.md)
 - [ModAssignGetSubmissionsResponseAssignmentsInner](docs/ModAssignGetSubmissionsResponseAssignmentsInner.md)
 - [ModAssignGetUserFlagsResponse](docs/ModAssignGetUserFlagsResponse.md)
 - [ModAssignGetUserFlagsResponseAssignmentsInner](docs/ModAssignGetUserFlagsResponseAssignmentsInner.md)
 - [ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner](docs/ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner.md)
 - [ModAssignGetUserFlagsResponseWarningsInner](docs/ModAssignGetUserFlagsResponseWarningsInner.md)
 - [ModAssignGetUserMappingsResponse](docs/ModAssignGetUserMappingsResponse.md)
 - [ModAssignGetUserMappingsResponseAssignmentsInner](docs/ModAssignGetUserMappingsResponseAssignmentsInner.md)
 - [ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner](docs/ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner.md)
 - [ModAssignGetUserMappingsResponseWarningsInner](docs/ModAssignGetUserMappingsResponseWarningsInner.md)
 - [ModAssignListParticipantsResponseInner](docs/ModAssignListParticipantsResponseInner.md)
 - [ModAssignRemoveSubmissionResponse](docs/ModAssignRemoveSubmissionResponse.md)
 - [ModAssignSaveGradeParametersAdvancedgradingdata](docs/ModAssignSaveGradeParametersAdvancedgradingdata.md)
 - [ModAssignSaveGradeParametersAdvancedgradingdataGuide](docs/ModAssignSaveGradeParametersAdvancedgradingdataGuide.md)
 - [ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner](docs/ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner.md)
 - [ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner](docs/ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner.md)
 - [ModAssignSaveGradeParametersAdvancedgradingdataRubric](docs/ModAssignSaveGradeParametersAdvancedgradingdataRubric.md)
 - [ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner](docs/ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner.md)
 - [ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner](docs/ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner.md)
 - [ModAssignSaveGradeParametersPlugindata](docs/ModAssignSaveGradeParametersPlugindata.md)
 - [ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor](docs/ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor.md)
 - [ModAssignSaveGradesParametersGradesInner](docs/ModAssignSaveGradesParametersGradesInner.md)
 - [ModAssignSaveSubmissionParametersPlugindata](docs/ModAssignSaveSubmissionParametersPlugindata.md)
 - [ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor](docs/ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor.md)
 - [ModAssignSetUserFlagsParametersUserflagsInner](docs/ModAssignSetUserFlagsParametersUserflagsInner.md)
 - [ModAssignSetUserFlagsResponseInner](docs/ModAssignSetUserFlagsResponseInner.md)
 - [ModAssignStartSubmissionResponse](docs/ModAssignStartSubmissionResponse.md)
 - [ModAssignViewAssignResponse](docs/ModAssignViewAssignResponse.md)
 - [ModAssignViewGradingTableResponse](docs/ModAssignViewGradingTableResponse.md)
 - [ModAssignViewSubmissionStatusResponse](docs/ModAssignViewSubmissionStatusResponse.md)
 - [ModBigbluebuttonbnCanJoinResponse](docs/ModBigbluebuttonbnCanJoinResponse.md)
 - [ModBigbluebuttonbnCompletionValidateResponse](docs/ModBigbluebuttonbnCompletionValidateResponse.md)
 - [ModBigbluebuttonbnEndMeetingResponse](docs/ModBigbluebuttonbnEndMeetingResponse.md)
 - [ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse](docs/ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse.md)
 - [ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner](docs/ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner.md)
 - [ModBigbluebuttonbnGetJoinUrlResponse](docs/ModBigbluebuttonbnGetJoinUrlResponse.md)
 - [ModBigbluebuttonbnGetRecordingsResponse](docs/ModBigbluebuttonbnGetRecordingsResponse.md)
 - [ModBigbluebuttonbnGetRecordingsResponseTabledata](docs/ModBigbluebuttonbnGetRecordingsResponseTabledata.md)
 - [ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner](docs/ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner.md)
 - [ModBigbluebuttonbnGetRecordingsToImportResponse](docs/ModBigbluebuttonbnGetRecordingsToImportResponse.md)
 - [ModBigbluebuttonbnMeetingInfoResponse](docs/ModBigbluebuttonbnMeetingInfoResponse.md)
 - [ModBigbluebuttonbnMeetingInfoResponseFeaturesInner](docs/ModBigbluebuttonbnMeetingInfoResponseFeaturesInner.md)
 - [ModBigbluebuttonbnMeetingInfoResponsePresentationsInner](docs/ModBigbluebuttonbnMeetingInfoResponsePresentationsInner.md)
 - [ModBigbluebuttonbnViewBigbluebuttonbnResponse](docs/ModBigbluebuttonbnViewBigbluebuttonbnResponse.md)
 - [ModBookGetBooksByCoursesResponse](docs/ModBookGetBooksByCoursesResponse.md)
 - [ModBookGetBooksByCoursesResponseBooksInner](docs/ModBookGetBooksByCoursesResponseBooksInner.md)
 - [ModBookViewBookResponse](docs/ModBookViewBookResponse.md)
 - [ModChoiceDeleteChoiceResponsesResponse](docs/ModChoiceDeleteChoiceResponsesResponse.md)
 - [ModChoiceGetChoiceOptionsResponse](docs/ModChoiceGetChoiceOptionsResponse.md)
 - [ModChoiceGetChoiceOptionsResponseOptionsInner](docs/ModChoiceGetChoiceOptionsResponseOptionsInner.md)
 - [ModChoiceGetChoiceResultsResponse](docs/ModChoiceGetChoiceResultsResponse.md)
 - [ModChoiceGetChoiceResultsResponseOptionsInner](docs/ModChoiceGetChoiceResultsResponseOptionsInner.md)
 - [ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner](docs/ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner.md)
 - [ModChoiceGetChoicesByCoursesResponse](docs/ModChoiceGetChoicesByCoursesResponse.md)
 - [ModChoiceGetChoicesByCoursesResponseChoicesInner](docs/ModChoiceGetChoicesByCoursesResponseChoicesInner.md)
 - [ModChoiceSubmitChoiceResponseResponse](docs/ModChoiceSubmitChoiceResponseResponse.md)
 - [ModChoiceSubmitChoiceResponseResponseAnswersInner](docs/ModChoiceSubmitChoiceResponseResponseAnswersInner.md)
 - [ModChoiceViewChoiceResponse](docs/ModChoiceViewChoiceResponse.md)
 - [ModDataAddEntryParametersDataInner](docs/ModDataAddEntryParametersDataInner.md)
 - [ModDataAddEntryResponse](docs/ModDataAddEntryResponse.md)
 - [ModDataAddEntryResponseFieldnotificationsInner](docs/ModDataAddEntryResponseFieldnotificationsInner.md)
 - [ModDataApproveEntryResponse](docs/ModDataApproveEntryResponse.md)
 - [ModDataDeleteEntryResponse](docs/ModDataDeleteEntryResponse.md)
 - [ModDataDeleteSavedPresetResponse](docs/ModDataDeleteSavedPresetResponse.md)
 - [ModDataGetDataAccessInformationResponse](docs/ModDataGetDataAccessInformationResponse.md)
 - [ModDataGetDatabasesByCoursesResponse](docs/ModDataGetDatabasesByCoursesResponse.md)
 - [ModDataGetDatabasesByCoursesResponseDatabasesInner](docs/ModDataGetDatabasesByCoursesResponseDatabasesInner.md)
 - [ModDataGetEntriesResponse](docs/ModDataGetEntriesResponse.md)
 - [ModDataGetEntriesResponseEntriesInner](docs/ModDataGetEntriesResponseEntriesInner.md)
 - [ModDataGetEntriesResponseEntriesInnerContentsInner](docs/ModDataGetEntriesResponseEntriesInnerContentsInner.md)
 - [ModDataGetEntryResponse](docs/ModDataGetEntryResponse.md)
 - [ModDataGetEntryResponseRatinginfo](docs/ModDataGetEntryResponseRatinginfo.md)
 - [ModDataGetEntryResponseRatinginfoRatingsInner](docs/ModDataGetEntryResponseRatinginfoRatingsInner.md)
 - [ModDataGetEntryResponseRatinginfoScalesInner](docs/ModDataGetEntryResponseRatinginfoScalesInner.md)
 - [ModDataGetEntryResponseRatinginfoScalesInnerItemsInner](docs/ModDataGetEntryResponseRatinginfoScalesInnerItemsInner.md)
 - [ModDataGetFieldsResponse](docs/ModDataGetFieldsResponse.md)
 - [ModDataGetFieldsResponseFieldsInner](docs/ModDataGetFieldsResponseFieldsInner.md)
 - [ModDataGetMappingInformationResponse](docs/ModDataGetMappingInformationResponse.md)
 - [ModDataGetMappingInformationResponseData](docs/ModDataGetMappingInformationResponseData.md)
 - [ModDataSearchEntriesParametersAdvsearchInner](docs/ModDataSearchEntriesParametersAdvsearchInner.md)
 - [ModDataSearchEntriesResponse](docs/ModDataSearchEntriesResponse.md)
 - [ModDataUpdateEntryParametersDataInner](docs/ModDataUpdateEntryParametersDataInner.md)
 - [ModDataUpdateEntryResponse](docs/ModDataUpdateEntryResponse.md)
 - [ModDataViewDatabaseResponse](docs/ModDataViewDatabaseResponse.md)
 - [ModFeedbackGetAnalysisResponse](docs/ModFeedbackGetAnalysisResponse.md)
 - [ModFeedbackGetAnalysisResponseItemsdataInner](docs/ModFeedbackGetAnalysisResponseItemsdataInner.md)
 - [ModFeedbackGetAnalysisResponseItemsdataInnerItem](docs/ModFeedbackGetAnalysisResponseItemsdataInnerItem.md)
 - [ModFeedbackGetCurrentCompletedTmpResponse](docs/ModFeedbackGetCurrentCompletedTmpResponse.md)
 - [ModFeedbackGetCurrentCompletedTmpResponseFeedback](docs/ModFeedbackGetCurrentCompletedTmpResponseFeedback.md)
 - [ModFeedbackGetFeedbackAccessInformationResponse](docs/ModFeedbackGetFeedbackAccessInformationResponse.md)
 - [ModFeedbackGetFeedbacksByCoursesResponse](docs/ModFeedbackGetFeedbacksByCoursesResponse.md)
 - [ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner](docs/ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner.md)
 - [ModFeedbackGetFinishedResponsesResponse](docs/ModFeedbackGetFinishedResponsesResponse.md)
 - [ModFeedbackGetFinishedResponsesResponseResponsesInner](docs/ModFeedbackGetFinishedResponsesResponseResponsesInner.md)
 - [ModFeedbackGetItemsResponse](docs/ModFeedbackGetItemsResponse.md)
 - [ModFeedbackGetLastCompletedResponse](docs/ModFeedbackGetLastCompletedResponse.md)
 - [ModFeedbackGetLastCompletedResponseCompleted](docs/ModFeedbackGetLastCompletedResponseCompleted.md)
 - [ModFeedbackGetNonRespondentsResponse](docs/ModFeedbackGetNonRespondentsResponse.md)
 - [ModFeedbackGetNonRespondentsResponseUsersInner](docs/ModFeedbackGetNonRespondentsResponseUsersInner.md)
 - [ModFeedbackGetPageItemsResponse](docs/ModFeedbackGetPageItemsResponse.md)
 - [ModFeedbackGetResponsesAnalysisResponse](docs/ModFeedbackGetResponsesAnalysisResponse.md)
 - [ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner](docs/ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner.md)
 - [ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner](docs/ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner.md)
 - [ModFeedbackGetResponsesAnalysisResponseAttemptsInner](docs/ModFeedbackGetResponsesAnalysisResponseAttemptsInner.md)
 - [ModFeedbackGetUnfinishedResponsesResponse](docs/ModFeedbackGetUnfinishedResponsesResponse.md)
 - [ModFeedbackGetUnfinishedResponsesResponseResponsesInner](docs/ModFeedbackGetUnfinishedResponsesResponseResponsesInner.md)
 - [ModFeedbackLaunchFeedbackResponse](docs/ModFeedbackLaunchFeedbackResponse.md)
 - [ModFeedbackProcessPageParametersResponsesInner](docs/ModFeedbackProcessPageParametersResponsesInner.md)
 - [ModFeedbackProcessPageResponse](docs/ModFeedbackProcessPageResponse.md)
 - [ModFeedbackViewFeedbackResponse](docs/ModFeedbackViewFeedbackResponse.md)
 - [ModFolderGetFoldersByCoursesResponse](docs/ModFolderGetFoldersByCoursesResponse.md)
 - [ModFolderGetFoldersByCoursesResponseFoldersInner](docs/ModFolderGetFoldersByCoursesResponseFoldersInner.md)
 - [ModFolderViewFolderResponse](docs/ModFolderViewFolderResponse.md)
 - [ModForumAddDiscussionParametersOptionsInner](docs/ModForumAddDiscussionParametersOptionsInner.md)
 - [ModForumAddDiscussionPostParametersOptionsInner](docs/ModForumAddDiscussionPostParametersOptionsInner.md)
 - [ModForumAddDiscussionPostResponse](docs/ModForumAddDiscussionPostResponse.md)
 - [ModForumAddDiscussionPostResponseMessagesInner](docs/ModForumAddDiscussionPostResponseMessagesInner.md)
 - [ModForumAddDiscussionPostResponsePost](docs/ModForumAddDiscussionPostResponsePost.md)
 - [ModForumAddDiscussionPostResponsePostAttachmentsInner](docs/ModForumAddDiscussionPostResponsePostAttachmentsInner.md)
 - [ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml](docs/ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml.md)
 - [ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls](docs/ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls.md)
 - [ModForumAddDiscussionPostResponsePostAuthor](docs/ModForumAddDiscussionPostResponsePostAuthor.md)
 - [ModForumAddDiscussionPostResponsePostAuthorGroupsInner](docs/ModForumAddDiscussionPostResponsePostAuthorGroupsInner.md)
 - [ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls](docs/ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls.md)
 - [ModForumAddDiscussionPostResponsePostAuthorUrls](docs/ModForumAddDiscussionPostResponsePostAuthorUrls.md)
 - [ModForumAddDiscussionPostResponsePostCapabilities](docs/ModForumAddDiscussionPostResponsePostCapabilities.md)
 - [ModForumAddDiscussionPostResponsePostHtml](docs/ModForumAddDiscussionPostResponsePostHtml.md)
 - [ModForumAddDiscussionPostResponsePostTagsInner](docs/ModForumAddDiscussionPostResponsePostTagsInner.md)
 - [ModForumAddDiscussionPostResponsePostTagsInnerUrls](docs/ModForumAddDiscussionPostResponsePostTagsInnerUrls.md)
 - [ModForumAddDiscussionPostResponsePostUrls](docs/ModForumAddDiscussionPostResponsePostUrls.md)
 - [ModForumAddDiscussionResponse](docs/ModForumAddDiscussionResponse.md)
 - [ModForumCanAddDiscussionResponse](docs/ModForumCanAddDiscussionResponse.md)
 - [ModForumDeletePostResponse](docs/ModForumDeletePostResponse.md)
 - [ModForumGetDiscussionPostResponse](docs/ModForumGetDiscussionPostResponse.md)
 - [ModForumGetDiscussionPostsByUseridResponse](docs/ModForumGetDiscussionPostsByUseridResponse.md)
 - [ModForumGetDiscussionPostsByUseridResponseDiscussionsInner](docs/ModForumGetDiscussionPostsByUseridResponseDiscussionsInner.md)
 - [ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts](docs/ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts.md)
 - [ModForumGetDiscussionPostsResponse](docs/ModForumGetDiscussionPostsResponse.md)
 - [ModForumGetForumAccessInformationResponse](docs/ModForumGetForumAccessInformationResponse.md)
 - [ModForumGetForumDiscussionsResponse](docs/ModForumGetForumDiscussionsResponse.md)
 - [ModForumGetForumDiscussionsResponseDiscussionsInner](docs/ModForumGetForumDiscussionsResponseDiscussionsInner.md)
 - [ModForumGetForumsByCoursesResponseInner](docs/ModForumGetForumsByCoursesResponseInner.md)
 - [ModForumPrepareDraftAreaForPostParametersFilestokeepInner](docs/ModForumPrepareDraftAreaForPostParametersFilestokeepInner.md)
 - [ModForumPrepareDraftAreaForPostResponse](docs/ModForumPrepareDraftAreaForPostResponse.md)
 - [ModForumSetLockStateResponse](docs/ModForumSetLockStateResponse.md)
 - [ModForumSetLockStateResponseTimes](docs/ModForumSetLockStateResponseTimes.md)
 - [ModForumSetPinStateResponse](docs/ModForumSetPinStateResponse.md)
 - [ModForumSetPinStateResponseCapabilities](docs/ModForumSetPinStateResponseCapabilities.md)
 - [ModForumSetPinStateResponseGroup](docs/ModForumSetPinStateResponseGroup.md)
 - [ModForumSetPinStateResponseGroupUrls](docs/ModForumSetPinStateResponseGroupUrls.md)
 - [ModForumSetPinStateResponseTimed](docs/ModForumSetPinStateResponseTimed.md)
 - [ModForumSetPinStateResponseTimes](docs/ModForumSetPinStateResponseTimes.md)
 - [ModForumSetPinStateResponseUrls](docs/ModForumSetPinStateResponseUrls.md)
 - [ModForumSetPinStateResponseUserstate](docs/ModForumSetPinStateResponseUserstate.md)
 - [ModForumSetSubscriptionStateResponse](docs/ModForumSetSubscriptionStateResponse.md)
 - [ModForumToggleFavouriteStateResponse](docs/ModForumToggleFavouriteStateResponse.md)
 - [ModForumUpdateDiscussionPostParametersOptionsInner](docs/ModForumUpdateDiscussionPostParametersOptionsInner.md)
 - [ModForumUpdateDiscussionPostResponse](docs/ModForumUpdateDiscussionPostResponse.md)
 - [ModForumViewForumDiscussionResponse](docs/ModForumViewForumDiscussionResponse.md)
 - [ModForumViewForumResponse](docs/ModForumViewForumResponse.md)
 - [ModGlossaryAddEntryParametersOptionsInner](docs/ModGlossaryAddEntryParametersOptionsInner.md)
 - [ModGlossaryAddEntryResponse](docs/ModGlossaryAddEntryResponse.md)
 - [ModGlossaryDeleteEntryResponse](docs/ModGlossaryDeleteEntryResponse.md)
 - [ModGlossaryGetAuthorsParametersOptions](docs/ModGlossaryGetAuthorsParametersOptions.md)
 - [ModGlossaryGetAuthorsResponse](docs/ModGlossaryGetAuthorsResponse.md)
 - [ModGlossaryGetAuthorsResponseAuthorsInner](docs/ModGlossaryGetAuthorsResponseAuthorsInner.md)
 - [ModGlossaryGetCategoriesResponse](docs/ModGlossaryGetCategoriesResponse.md)
 - [ModGlossaryGetCategoriesResponseCategoriesInner](docs/ModGlossaryGetCategoriesResponseCategoriesInner.md)
 - [ModGlossaryGetEntriesByAuthorIdParametersOptions](docs/ModGlossaryGetEntriesByAuthorIdParametersOptions.md)
 - [ModGlossaryGetEntriesByAuthorIdResponse](docs/ModGlossaryGetEntriesByAuthorIdResponse.md)
 - [ModGlossaryGetEntriesByAuthorIdResponseEntriesInner](docs/ModGlossaryGetEntriesByAuthorIdResponseEntriesInner.md)
 - [ModGlossaryGetEntriesByAuthorResponse](docs/ModGlossaryGetEntriesByAuthorResponse.md)
 - [ModGlossaryGetEntriesByCategoryResponse](docs/ModGlossaryGetEntriesByCategoryResponse.md)
 - [ModGlossaryGetEntriesByCategoryResponseEntriesInner](docs/ModGlossaryGetEntriesByCategoryResponseEntriesInner.md)
 - [ModGlossaryGetEntriesByDateResponse](docs/ModGlossaryGetEntriesByDateResponse.md)
 - [ModGlossaryGetEntriesByLetterResponse](docs/ModGlossaryGetEntriesByLetterResponse.md)
 - [ModGlossaryGetEntriesBySearchResponse](docs/ModGlossaryGetEntriesBySearchResponse.md)
 - [ModGlossaryGetEntriesByTermResponse](docs/ModGlossaryGetEntriesByTermResponse.md)
 - [ModGlossaryGetEntriesToApproveResponse](docs/ModGlossaryGetEntriesToApproveResponse.md)
 - [ModGlossaryGetEntryByIdResponse](docs/ModGlossaryGetEntryByIdResponse.md)
 - [ModGlossaryGetEntryByIdResponsePermissions](docs/ModGlossaryGetEntryByIdResponsePermissions.md)
 - [ModGlossaryGetGlossariesByCoursesResponse](docs/ModGlossaryGetGlossariesByCoursesResponse.md)
 - [ModGlossaryGetGlossariesByCoursesResponseGlossariesInner](docs/ModGlossaryGetGlossariesByCoursesResponseGlossariesInner.md)
 - [ModGlossaryPrepareEntryForEditionResponse](docs/ModGlossaryPrepareEntryForEditionResponse.md)
 - [ModGlossaryUpdateEntryResponse](docs/ModGlossaryUpdateEntryResponse.md)
 - [ModGlossaryViewEntryResponse](docs/ModGlossaryViewEntryResponse.md)
 - [ModGlossaryViewGlossaryResponse](docs/ModGlossaryViewGlossaryResponse.md)
 - [ModH5pactivityGetAttemptsResponse](docs/ModH5pactivityGetAttemptsResponse.md)
 - [ModH5pactivityGetAttemptsResponseUsersattemptsInner](docs/ModH5pactivityGetAttemptsResponseUsersattemptsInner.md)
 - [ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner](docs/ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner.md)
 - [ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored](docs/ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored.md)
 - [ModH5pactivityGetH5pactivitiesByCoursesResponse](docs/ModH5pactivityGetH5pactivitiesByCoursesResponse.md)
 - [ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner](docs/ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner.md)
 - [ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile](docs/ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile.md)
 - [ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings](docs/ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings.md)
 - [ModH5pactivityGetH5pactivityAccessInformationResponse](docs/ModH5pactivityGetH5pactivityAccessInformationResponse.md)
 - [ModH5pactivityGetResultsResponse](docs/ModH5pactivityGetResultsResponse.md)
 - [ModH5pactivityGetResultsResponseAttemptsInner](docs/ModH5pactivityGetResultsResponseAttemptsInner.md)
 - [ModH5pactivityGetResultsResponseAttemptsInnerResultsInner](docs/ModH5pactivityGetResultsResponseAttemptsInnerResultsInner.md)
 - [ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner](docs/ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner.md)
 - [ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer](docs/ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer.md)
 - [ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer](docs/ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer.md)
 - [ModH5pactivityGetUserAttemptsResponse](docs/ModH5pactivityGetUserAttemptsResponse.md)
 - [ModH5pactivityGetUserAttemptsResponseUsersattemptsInner](docs/ModH5pactivityGetUserAttemptsResponseUsersattemptsInner.md)
 - [ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored](docs/ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored.md)
 - [ModH5pactivityLogReportViewedResponse](docs/ModH5pactivityLogReportViewedResponse.md)
 - [ModH5pactivityViewH5pactivityResponse](docs/ModH5pactivityViewH5pactivityResponse.md)
 - [ModImscpGetImscpsByCoursesResponse](docs/ModImscpGetImscpsByCoursesResponse.md)
 - [ModImscpGetImscpsByCoursesResponseImscpsInner](docs/ModImscpGetImscpsByCoursesResponseImscpsInner.md)
 - [ModImscpViewImscpResponse](docs/ModImscpViewImscpResponse.md)
 - [ModLabelGetLabelsByCoursesResponse](docs/ModLabelGetLabelsByCoursesResponse.md)
 - [ModLabelGetLabelsByCoursesResponseLabelsInner](docs/ModLabelGetLabelsByCoursesResponseLabelsInner.md)
 - [ModLessonFinishAttemptResponse](docs/ModLessonFinishAttemptResponse.md)
 - [ModLessonFinishAttemptResponseDataInner](docs/ModLessonFinishAttemptResponseDataInner.md)
 - [ModLessonFinishAttemptResponseMessagesInner](docs/ModLessonFinishAttemptResponseMessagesInner.md)
 - [ModLessonGetAttemptsOverviewResponse](docs/ModLessonGetAttemptsOverviewResponse.md)
 - [ModLessonGetAttemptsOverviewResponseData](docs/ModLessonGetAttemptsOverviewResponseData.md)
 - [ModLessonGetAttemptsOverviewResponseDataStudentsInner](docs/ModLessonGetAttemptsOverviewResponseDataStudentsInner.md)
 - [ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner](docs/ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner.md)
 - [ModLessonGetContentPagesViewedResponse](docs/ModLessonGetContentPagesViewedResponse.md)
 - [ModLessonGetContentPagesViewedResponsePagesInner](docs/ModLessonGetContentPagesViewedResponsePagesInner.md)
 - [ModLessonGetLessonAccessInformationResponse](docs/ModLessonGetLessonAccessInformationResponse.md)
 - [ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner](docs/ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner.md)
 - [ModLessonGetLessonResponse](docs/ModLessonGetLessonResponse.md)
 - [ModLessonGetLessonResponseLesson](docs/ModLessonGetLessonResponseLesson.md)
 - [ModLessonGetLessonsByCoursesResponse](docs/ModLessonGetLessonsByCoursesResponse.md)
 - [ModLessonGetPageDataResponse](docs/ModLessonGetPageDataResponse.md)
 - [ModLessonGetPageDataResponseAnswersInner](docs/ModLessonGetPageDataResponseAnswersInner.md)
 - [ModLessonGetPageDataResponsePage](docs/ModLessonGetPageDataResponsePage.md)
 - [ModLessonGetPagesPossibleJumpsResponse](docs/ModLessonGetPagesPossibleJumpsResponse.md)
 - [ModLessonGetPagesPossibleJumpsResponseJumpsInner](docs/ModLessonGetPagesPossibleJumpsResponseJumpsInner.md)
 - [ModLessonGetPagesResponse](docs/ModLessonGetPagesResponse.md)
 - [ModLessonGetPagesResponsePagesInner](docs/ModLessonGetPagesResponsePagesInner.md)
 - [ModLessonGetQuestionsAttemptsResponse](docs/ModLessonGetQuestionsAttemptsResponse.md)
 - [ModLessonGetQuestionsAttemptsResponseAttemptsInner](docs/ModLessonGetQuestionsAttemptsResponseAttemptsInner.md)
 - [ModLessonGetUserAttemptGradeResponse](docs/ModLessonGetUserAttemptGradeResponse.md)
 - [ModLessonGetUserAttemptGradeResponseGrade](docs/ModLessonGetUserAttemptGradeResponseGrade.md)
 - [ModLessonGetUserAttemptResponse](docs/ModLessonGetUserAttemptResponse.md)
 - [ModLessonGetUserAttemptResponseAnswerpagesInner](docs/ModLessonGetUserAttemptResponseAnswerpagesInner.md)
 - [ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata](docs/ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata.md)
 - [ModLessonGetUserAttemptResponseUserstats](docs/ModLessonGetUserAttemptResponseUserstats.md)
 - [ModLessonGetUserGradeResponse](docs/ModLessonGetUserGradeResponse.md)
 - [ModLessonGetUserTimersResponse](docs/ModLessonGetUserTimersResponse.md)
 - [ModLessonGetUserTimersResponseTimersInner](docs/ModLessonGetUserTimersResponseTimersInner.md)
 - [ModLessonLaunchAttemptResponse](docs/ModLessonLaunchAttemptResponse.md)
 - [ModLessonProcessPageParametersDataInner](docs/ModLessonProcessPageParametersDataInner.md)
 - [ModLessonProcessPageResponse](docs/ModLessonProcessPageResponse.md)
 - [ModLessonViewLessonResponse](docs/ModLessonViewLessonResponse.md)
 - [ModLtiCreateToolProxyResponse](docs/ModLtiCreateToolProxyResponse.md)
 - [ModLtiCreateToolTypeResponse](docs/ModLtiCreateToolTypeResponse.md)
 - [ModLtiCreateToolTypeResponseState](docs/ModLtiCreateToolTypeResponseState.md)
 - [ModLtiCreateToolTypeResponseUrls](docs/ModLtiCreateToolTypeResponseUrls.md)
 - [ModLtiDeleteToolProxyResponse](docs/ModLtiDeleteToolProxyResponse.md)
 - [ModLtiDeleteToolTypeResponse](docs/ModLtiDeleteToolTypeResponse.md)
 - [ModLtiGetLtisByCoursesResponse](docs/ModLtiGetLtisByCoursesResponse.md)
 - [ModLtiGetLtisByCoursesResponseLtisInner](docs/ModLtiGetLtisByCoursesResponseLtisInner.md)
 - [ModLtiGetToolLaunchDataResponse](docs/ModLtiGetToolLaunchDataResponse.md)
 - [ModLtiGetToolLaunchDataResponseParametersInner](docs/ModLtiGetToolLaunchDataResponseParametersInner.md)
 - [ModLtiGetToolProxiesResponseInner](docs/ModLtiGetToolProxiesResponseInner.md)
 - [ModLtiGetToolProxyRegistrationRequestResponse](docs/ModLtiGetToolProxyRegistrationRequestResponse.md)
 - [ModLtiGetToolTypesAndProxiesCountResponse](docs/ModLtiGetToolTypesAndProxiesCountResponse.md)
 - [ModLtiGetToolTypesAndProxiesResponse](docs/ModLtiGetToolTypesAndProxiesResponse.md)
 - [ModLtiGetToolTypesAndProxiesResponseTypesInner](docs/ModLtiGetToolTypesAndProxiesResponseTypesInner.md)
 - [ModLtiIsCartridgeResponse](docs/ModLtiIsCartridgeResponse.md)
 - [ModLtiUpdateToolTypeResponse](docs/ModLtiUpdateToolTypeResponse.md)
 - [ModLtiViewLtiResponse](docs/ModLtiViewLtiResponse.md)
 - [ModPageGetPagesByCoursesResponse](docs/ModPageGetPagesByCoursesResponse.md)
 - [ModPageGetPagesByCoursesResponsePagesInner](docs/ModPageGetPagesByCoursesResponsePagesInner.md)
 - [ModPageViewPageResponse](docs/ModPageViewPageResponse.md)
 - [ModQuizAddRandomQuestionsResponse](docs/ModQuizAddRandomQuestionsResponse.md)
 - [ModQuizCreateGradeItemsParametersQuizgradeitemsInner](docs/ModQuizCreateGradeItemsParametersQuizgradeitemsInner.md)
 - [ModQuizDeleteGradeItemsParametersQuizgradeitemsInner](docs/ModQuizDeleteGradeItemsParametersQuizgradeitemsInner.md)
 - [ModQuizDeleteOverridesParametersData](docs/ModQuizDeleteOverridesParametersData.md)
 - [ModQuizDeleteOverridesResponse](docs/ModQuizDeleteOverridesResponse.md)
 - [ModQuizGetAttemptAccessInformationResponse](docs/ModQuizGetAttemptAccessInformationResponse.md)
 - [ModQuizGetAttemptDataResponse](docs/ModQuizGetAttemptDataResponse.md)
 - [ModQuizGetAttemptDataResponseAttempt](docs/ModQuizGetAttemptDataResponseAttempt.md)
 - [ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner](docs/ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner.md)
 - [ModQuizGetAttemptDataResponseQuestionsInner](docs/ModQuizGetAttemptDataResponseQuestionsInner.md)
 - [ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner](docs/ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner.md)
 - [ModQuizGetAttemptReviewResponse](docs/ModQuizGetAttemptReviewResponse.md)
 - [ModQuizGetAttemptReviewResponseAdditionaldataInner](docs/ModQuizGetAttemptReviewResponseAdditionaldataInner.md)
 - [ModQuizGetAttemptSummaryResponse](docs/ModQuizGetAttemptSummaryResponse.md)
 - [ModQuizGetCombinedReviewOptionsResponse](docs/ModQuizGetCombinedReviewOptionsResponse.md)
 - [ModQuizGetCombinedReviewOptionsResponseAlloptionsInner](docs/ModQuizGetCombinedReviewOptionsResponseAlloptionsInner.md)
 - [ModQuizGetOverridesResponse](docs/ModQuizGetOverridesResponse.md)
 - [ModQuizGetOverridesResponseOverridesInner](docs/ModQuizGetOverridesResponseOverridesInner.md)
 - [ModQuizGetQuizAccessInformationResponse](docs/ModQuizGetQuizAccessInformationResponse.md)
 - [ModQuizGetQuizFeedbackForGradeResponse](docs/ModQuizGetQuizFeedbackForGradeResponse.md)
 - [ModQuizGetQuizRequiredQtypesResponse](docs/ModQuizGetQuizRequiredQtypesResponse.md)
 - [ModQuizGetQuizzesByCoursesResponse](docs/ModQuizGetQuizzesByCoursesResponse.md)
 - [ModQuizGetQuizzesByCoursesResponseQuizzesInner](docs/ModQuizGetQuizzesByCoursesResponseQuizzesInner.md)
 - [ModQuizGetUserAttemptsResponse](docs/ModQuizGetUserAttemptsResponse.md)
 - [ModQuizGetUserAttemptsResponseAttemptsInner](docs/ModQuizGetUserAttemptsResponseAttemptsInner.md)
 - [ModQuizGetUserBestGradeResponse](docs/ModQuizGetUserBestGradeResponse.md)
 - [ModQuizGetUserQuizAttemptsResponse](docs/ModQuizGetUserQuizAttemptsResponse.md)
 - [ModQuizProcessAttemptResponse](docs/ModQuizProcessAttemptResponse.md)
 - [ModQuizSaveAttemptResponse](docs/ModQuizSaveAttemptResponse.md)
 - [ModQuizSaveOverridesParametersData](docs/ModQuizSaveOverridesParametersData.md)
 - [ModQuizSaveOverridesParametersDataOverridesInner](docs/ModQuizSaveOverridesParametersDataOverridesInner.md)
 - [ModQuizSaveOverridesResponse](docs/ModQuizSaveOverridesResponse.md)
 - [ModQuizSetQuestionVersionResponse](docs/ModQuizSetQuestionVersionResponse.md)
 - [ModQuizStartAttemptResponse](docs/ModQuizStartAttemptResponse.md)
 - [ModQuizUpdateFilterConditionResponse](docs/ModQuizUpdateFilterConditionResponse.md)
 - [ModQuizUpdateGradeItemsParametersQuizgradeitemsInner](docs/ModQuizUpdateGradeItemsParametersQuizgradeitemsInner.md)
 - [ModQuizUpdateSlotsParametersSlotsInner](docs/ModQuizUpdateSlotsParametersSlotsInner.md)
 - [ModQuizViewAttemptResponse](docs/ModQuizViewAttemptResponse.md)
 - [ModQuizViewAttemptReviewResponse](docs/ModQuizViewAttemptReviewResponse.md)
 - [ModQuizViewAttemptSummaryResponse](docs/ModQuizViewAttemptSummaryResponse.md)
 - [ModQuizViewQuizResponse](docs/ModQuizViewQuizResponse.md)
 - [ModResourceGetResourcesByCoursesResponse](docs/ModResourceGetResourcesByCoursesResponse.md)
 - [ModResourceGetResourcesByCoursesResponseResourcesInner](docs/ModResourceGetResourcesByCoursesResponseResourcesInner.md)
 - [ModResourceViewResourceResponse](docs/ModResourceViewResourceResponse.md)
 - [ModScormGetScormAccessInformationResponse](docs/ModScormGetScormAccessInformationResponse.md)
 - [ModScormGetScormAttemptCountResponse](docs/ModScormGetScormAttemptCountResponse.md)
 - [ModScormGetScormScoTracksResponse](docs/ModScormGetScormScoTracksResponse.md)
 - [ModScormGetScormScoTracksResponseData](docs/ModScormGetScormScoTracksResponseData.md)
 - [ModScormGetScormScoTracksResponseDataTracksInner](docs/ModScormGetScormScoTracksResponseDataTracksInner.md)
 - [ModScormGetScormScoesResponse](docs/ModScormGetScormScoesResponse.md)
 - [ModScormGetScormScoesResponseScoesInner](docs/ModScormGetScormScoesResponseScoesInner.md)
 - [ModScormGetScormScoesResponseScoesInnerExtradataInner](docs/ModScormGetScormScoesResponseScoesInnerExtradataInner.md)
 - [ModScormGetScormUserDataResponse](docs/ModScormGetScormUserDataResponse.md)
 - [ModScormGetScormUserDataResponseDataInner](docs/ModScormGetScormUserDataResponseDataInner.md)
 - [ModScormGetScormsByCoursesResponse](docs/ModScormGetScormsByCoursesResponse.md)
 - [ModScormGetScormsByCoursesResponseOptionsInner](docs/ModScormGetScormsByCoursesResponseOptionsInner.md)
 - [ModScormGetScormsByCoursesResponseScormsInner](docs/ModScormGetScormsByCoursesResponseScormsInner.md)
 - [ModScormInsertScormTracksResponse](docs/ModScormInsertScormTracksResponse.md)
 - [ModScormLaunchScoResponse](docs/ModScormLaunchScoResponse.md)
 - [ModScormViewScormResponse](docs/ModScormViewScormResponse.md)
 - [ModUrlGetUrlsByCoursesResponse](docs/ModUrlGetUrlsByCoursesResponse.md)
 - [ModUrlGetUrlsByCoursesResponseUrlsInner](docs/ModUrlGetUrlsByCoursesResponseUrlsInner.md)
 - [ModUrlViewUrlResponse](docs/ModUrlViewUrlResponse.md)
 - [ModWikiEditPageResponse](docs/ModWikiEditPageResponse.md)
 - [ModWikiGetPageContentsResponse](docs/ModWikiGetPageContentsResponse.md)
 - [ModWikiGetPageContentsResponsePage](docs/ModWikiGetPageContentsResponsePage.md)
 - [ModWikiGetPageForEditingResponse](docs/ModWikiGetPageForEditingResponse.md)
 - [ModWikiGetPageForEditingResponsePagesection](docs/ModWikiGetPageForEditingResponsePagesection.md)
 - [ModWikiGetSubwikiFilesResponse](docs/ModWikiGetSubwikiFilesResponse.md)
 - [ModWikiGetSubwikiPagesParametersOptions](docs/ModWikiGetSubwikiPagesParametersOptions.md)
 - [ModWikiGetSubwikiPagesResponse](docs/ModWikiGetSubwikiPagesResponse.md)
 - [ModWikiGetSubwikiPagesResponsePagesInner](docs/ModWikiGetSubwikiPagesResponsePagesInner.md)
 - [ModWikiGetSubwikisResponse](docs/ModWikiGetSubwikisResponse.md)
 - [ModWikiGetSubwikisResponseSubwikisInner](docs/ModWikiGetSubwikisResponseSubwikisInner.md)
 - [ModWikiGetWikisByCoursesResponse](docs/ModWikiGetWikisByCoursesResponse.md)
 - [ModWikiGetWikisByCoursesResponseWikisInner](docs/ModWikiGetWikisByCoursesResponseWikisInner.md)
 - [ModWikiNewPageResponse](docs/ModWikiNewPageResponse.md)
 - [ModWikiViewPageResponse](docs/ModWikiViewPageResponse.md)
 - [ModWikiViewWikiResponse](docs/ModWikiViewWikiResponse.md)
 - [ModWorkshopAddSubmissionResponse](docs/ModWorkshopAddSubmissionResponse.md)
 - [ModWorkshopDeleteSubmissionResponse](docs/ModWorkshopDeleteSubmissionResponse.md)
 - [ModWorkshopEvaluateAssessmentResponse](docs/ModWorkshopEvaluateAssessmentResponse.md)
 - [ModWorkshopEvaluateSubmissionResponse](docs/ModWorkshopEvaluateSubmissionResponse.md)
 - [ModWorkshopGetAssessmentFormDefinitionResponse](docs/ModWorkshopGetAssessmentFormDefinitionResponse.md)
 - [ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner](docs/ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner.md)
 - [ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner](docs/ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner.md)
 - [ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner](docs/ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner.md)
 - [ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner](docs/ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner.md)
 - [ModWorkshopGetAssessmentResponse](docs/ModWorkshopGetAssessmentResponse.md)
 - [ModWorkshopGetAssessmentResponseAssessment](docs/ModWorkshopGetAssessmentResponseAssessment.md)
 - [ModWorkshopGetGradesReportResponse](docs/ModWorkshopGetGradesReportResponse.md)
 - [ModWorkshopGetGradesReportResponseReport](docs/ModWorkshopGetGradesReportResponseReport.md)
 - [ModWorkshopGetGradesReportResponseReportGradesInner](docs/ModWorkshopGetGradesReportResponseReportGradesInner.md)
 - [ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner](docs/ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner.md)
 - [ModWorkshopGetGradesResponse](docs/ModWorkshopGetGradesResponse.md)
 - [ModWorkshopGetReviewerAssessmentsResponse](docs/ModWorkshopGetReviewerAssessmentsResponse.md)
 - [ModWorkshopGetSubmissionAssessmentsResponse](docs/ModWorkshopGetSubmissionAssessmentsResponse.md)
 - [ModWorkshopGetSubmissionResponse](docs/ModWorkshopGetSubmissionResponse.md)
 - [ModWorkshopGetSubmissionResponseSubmission](docs/ModWorkshopGetSubmissionResponseSubmission.md)
 - [ModWorkshopGetSubmissionsResponse](docs/ModWorkshopGetSubmissionsResponse.md)
 - [ModWorkshopGetUserPlanResponse](docs/ModWorkshopGetUserPlanResponse.md)
 - [ModWorkshopGetUserPlanResponseUserplan](docs/ModWorkshopGetUserPlanResponseUserplan.md)
 - [ModWorkshopGetUserPlanResponseUserplanExamplesInner](docs/ModWorkshopGetUserPlanResponseUserplanExamplesInner.md)
 - [ModWorkshopGetUserPlanResponseUserplanPhasesInner](docs/ModWorkshopGetUserPlanResponseUserplanPhasesInner.md)
 - [ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner](docs/ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner.md)
 - [ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner](docs/ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner.md)
 - [ModWorkshopGetWorkshopAccessInformationResponse](docs/ModWorkshopGetWorkshopAccessInformationResponse.md)
 - [ModWorkshopGetWorkshopsByCoursesResponse](docs/ModWorkshopGetWorkshopsByCoursesResponse.md)
 - [ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner](docs/ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner.md)
 - [ModWorkshopUpdateAssessmentParametersDataInner](docs/ModWorkshopUpdateAssessmentParametersDataInner.md)
 - [ModWorkshopUpdateAssessmentResponse](docs/ModWorkshopUpdateAssessmentResponse.md)
 - [ModWorkshopUpdateSubmissionResponse](docs/ModWorkshopUpdateSubmissionResponse.md)
 - [ModWorkshopViewSubmissionResponse](docs/ModWorkshopViewSubmissionResponse.md)
 - [ModWorkshopViewWorkshopResponse](docs/ModWorkshopViewWorkshopResponse.md)
 - [PaygwPaypalCreateTransactionCompleteParameters](docs/PaygwPaypalCreateTransactionCompleteParameters.md)
 - [PaygwPaypalCreateTransactionCompleteResponse](docs/PaygwPaypalCreateTransactionCompleteResponse.md)
 - [PaygwPaypalGetConfigForJsResponse](docs/PaygwPaypalGetConfigForJsResponse.md)
 - [QbankEditquestionSetStatusResponse](docs/QbankEditquestionSetStatusResponse.md)
 - [QbankManagecategoriesMoveCategoryResponseInner](docs/QbankManagecategoriesMoveCategoryResponseInner.md)
 - [QbankManagecategoriesMoveCategoryResponseInnerFields](docs/QbankManagecategoriesMoveCategoryResponseInnerFields.md)
 - [QbankTagquestionSubmitTagsFormResponse](docs/QbankTagquestionSubmitTagsFormResponse.md)
 - [QuizaccessSebValidateQuizKeysResponse](docs/QuizaccessSebValidateQuizKeysResponse.md)
 - [ReportCompetencyDataForReportResponse](docs/ReportCompetencyDataForReportResponse.md)
 - [ReportCompetencyDataForReportResponseUsercompetenciesInner](docs/ReportCompetencyDataForReportResponseUsercompetenciesInner.md)
 - [ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency](docs/ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency.md)
 - [ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath](docs/ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath.md)
 - [ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner](docs/ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner.md)
 - [ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse](docs/ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse.md)
 - [ReportInsightsActionExecutedResponse](docs/ReportInsightsActionExecutedResponse.md)
 - [TinyAutosaveResetSessionParameters](docs/TinyAutosaveResetSessionParameters.md)
 - [TinyAutosaveResumeSessionParameters](docs/TinyAutosaveResumeSessionParameters.md)
 - [TinyAutosaveResumeSessionResponse](docs/TinyAutosaveResumeSessionResponse.md)
 - [TinyAutosaveUpdateSessionParameters](docs/TinyAutosaveUpdateSessionParameters.md)
 - [TinyEquationFilterResponse](docs/TinyEquationFilterResponse.md)
 - [TinyMediaPreviewResponse](docs/TinyMediaPreviewResponse.md)
 - [TinyPremiumGetApiKeyResponse](docs/TinyPremiumGetApiKeyResponse.md)
 - [ToolAnalyticsPotentialContextsResponseInner](docs/ToolAnalyticsPotentialContextsResponseInner.md)
 - [ToolBehatGetEntityGeneratorResponse](docs/ToolBehatGetEntityGeneratorResponse.md)
 - [ToolDataprivacyApproveDataRequestResponse](docs/ToolDataprivacyApproveDataRequestResponse.md)
 - [ToolDataprivacyBulkApproveDataRequestsResponse](docs/ToolDataprivacyBulkApproveDataRequestsResponse.md)
 - [ToolDataprivacyBulkDenyDataRequestsResponse](docs/ToolDataprivacyBulkDenyDataRequestsResponse.md)
 - [ToolDataprivacyCancelDataRequestResponse](docs/ToolDataprivacyCancelDataRequestResponse.md)
 - [ToolDataprivacyConfirmContextsForDeletionResponse](docs/ToolDataprivacyConfirmContextsForDeletionResponse.md)
 - [ToolDataprivacyContactDpoResponse](docs/ToolDataprivacyContactDpoResponse.md)
 - [ToolDataprivacyCreateCategoryFormResponse](docs/ToolDataprivacyCreateCategoryFormResponse.md)
 - [ToolDataprivacyCreateCategoryFormResponseCategory](docs/ToolDataprivacyCreateCategoryFormResponseCategory.md)
 - [ToolDataprivacyCreateDataRequestResponse](docs/ToolDataprivacyCreateDataRequestResponse.md)
 - [ToolDataprivacyCreatePurposeFormResponse](docs/ToolDataprivacyCreatePurposeFormResponse.md)
 - [ToolDataprivacyCreatePurposeFormResponsePurpose](docs/ToolDataprivacyCreatePurposeFormResponsePurpose.md)
 - [ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner](docs/ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner.md)
 - [ToolDataprivacyDeleteCategoryResponse](docs/ToolDataprivacyDeleteCategoryResponse.md)
 - [ToolDataprivacyDeletePurposeResponse](docs/ToolDataprivacyDeletePurposeResponse.md)
 - [ToolDataprivacyDenyDataRequestResponse](docs/ToolDataprivacyDenyDataRequestResponse.md)
 - [ToolDataprivacyGetAccessInformationResponse](docs/ToolDataprivacyGetAccessInformationResponse.md)
 - [ToolDataprivacyGetActivityOptionsResponse](docs/ToolDataprivacyGetActivityOptionsResponse.md)
 - [ToolDataprivacyGetActivityOptionsResponseOptionsInner](docs/ToolDataprivacyGetActivityOptionsResponseOptionsInner.md)
 - [ToolDataprivacyGetCategoryOptionsResponse](docs/ToolDataprivacyGetCategoryOptionsResponse.md)
 - [ToolDataprivacyGetCategoryOptionsResponseOptionsInner](docs/ToolDataprivacyGetCategoryOptionsResponseOptionsInner.md)
 - [ToolDataprivacyGetDataRequestResponse](docs/ToolDataprivacyGetDataRequestResponse.md)
 - [ToolDataprivacyGetDataRequestResponseResult](docs/ToolDataprivacyGetDataRequestResponseResult.md)
 - [ToolDataprivacyGetDataRequestsResponse](docs/ToolDataprivacyGetDataRequestsResponse.md)
 - [ToolDataprivacyGetPurposeOptionsResponse](docs/ToolDataprivacyGetPurposeOptionsResponse.md)
 - [ToolDataprivacyGetPurposeOptionsResponseOptionsInner](docs/ToolDataprivacyGetPurposeOptionsResponseOptionsInner.md)
 - [ToolDataprivacyMarkCompleteResponse](docs/ToolDataprivacyMarkCompleteResponse.md)
 - [ToolDataprivacySetContextDefaultsResponse](docs/ToolDataprivacySetContextDefaultsResponse.md)
 - [ToolDataprivacySetContextFormResponse](docs/ToolDataprivacySetContextFormResponse.md)
 - [ToolDataprivacySetContextlevelFormResponse](docs/ToolDataprivacySetContextlevelFormResponse.md)
 - [ToolDataprivacySubmitSelectedCoursesFormResponse](docs/ToolDataprivacySubmitSelectedCoursesFormResponse.md)
 - [ToolDataprivacyTreeExtraBranchesResponse](docs/ToolDataprivacyTreeExtraBranchesResponse.md)
 - [ToolDataprivacyTreeExtraBranchesResponseBranchesInner](docs/ToolDataprivacyTreeExtraBranchesResponseBranchesInner.md)
 - [ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner](docs/ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner.md)
 - [ToolLpDataForCompetenciesManagePageResponse](docs/ToolLpDataForCompetenciesManagePageResponse.md)
 - [ToolLpDataForCompetencyFrameworksManagePageResponse](docs/ToolLpDataForCompetencyFrameworksManagePageResponse.md)
 - [ToolLpDataForCompetencySummaryResponse](docs/ToolLpDataForCompetencySummaryResponse.md)
 - [ToolLpDataForCourseCompetenciesPageResponse](docs/ToolLpDataForCourseCompetenciesPageResponse.md)
 - [ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner](docs/ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner.md)
 - [ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner](docs/ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner.md)
 - [ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner](docs/ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner.md)
 - [ToolLpDataForCourseCompetenciesPageResponseSettings](docs/ToolLpDataForCourseCompetenciesPageResponseSettings.md)
 - [ToolLpDataForCourseCompetenciesPageResponseStatistics](docs/ToolLpDataForCourseCompetenciesPageResponseStatistics.md)
 - [ToolLpDataForPlanPageResponse](docs/ToolLpDataForPlanPageResponse.md)
 - [ToolLpDataForPlanPageResponseCompetenciesInner](docs/ToolLpDataForPlanPageResponseCompetenciesInner.md)
 - [ToolLpDataForPlansPageResponse](docs/ToolLpDataForPlansPageResponse.md)
 - [ToolLpDataForRelatedCompetenciesSectionResponse](docs/ToolLpDataForRelatedCompetenciesSectionResponse.md)
 - [ToolLpDataForTemplateCompetenciesPageResponse](docs/ToolLpDataForTemplateCompetenciesPageResponse.md)
 - [ToolLpDataForTemplateCompetenciesPageResponseStatistics](docs/ToolLpDataForTemplateCompetenciesPageResponseStatistics.md)
 - [ToolLpDataForTemplatesManagePageResponse](docs/ToolLpDataForTemplatesManagePageResponse.md)
 - [ToolLpDataForUserCompetencySummaryInCourseResponse](docs/ToolLpDataForUserCompetencySummaryInCourseResponse.md)
 - [ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary](docs/ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary.md)
 - [ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner](docs/ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner.md)
 - [ToolLpDataForUserCompetencySummaryInPlanResponse](docs/ToolLpDataForUserCompetencySummaryInPlanResponse.md)
 - [ToolLpDataForUserCompetencySummaryResponse](docs/ToolLpDataForUserCompetencySummaryResponse.md)
 - [ToolLpDataForUserEvidenceListPageResponse](docs/ToolLpDataForUserEvidenceListPageResponse.md)
 - [ToolLpDataForUserEvidenceListPageResponseEvidenceInner](docs/ToolLpDataForUserEvidenceListPageResponseEvidenceInner.md)
 - [ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner](docs/ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner.md)
 - [ToolLpDataForUserEvidencePageResponse](docs/ToolLpDataForUserEvidencePageResponse.md)
 - [ToolLpSearchCohortsResponse](docs/ToolLpSearchCohortsResponse.md)
 - [ToolLpSearchUsersResponse](docs/ToolLpSearchUsersResponse.md)
 - [ToolMobileCallExternalFunctionsParametersRequestsInner](docs/ToolMobileCallExternalFunctionsParametersRequestsInner.md)
 - [ToolMobileCallExternalFunctionsResponse](docs/ToolMobileCallExternalFunctionsResponse.md)
 - [ToolMobileCallExternalFunctionsResponseResponsesInner](docs/ToolMobileCallExternalFunctionsResponseResponsesInner.md)
 - [ToolMobileGetAutologinKeyResponse](docs/ToolMobileGetAutologinKeyResponse.md)
 - [ToolMobileGetConfigResponse](docs/ToolMobileGetConfigResponse.md)
 - [ToolMobileGetConfigResponseSettingsInner](docs/ToolMobileGetConfigResponseSettingsInner.md)
 - [ToolMobileGetContentParametersArgsInner](docs/ToolMobileGetContentParametersArgsInner.md)
 - [ToolMobileGetContentResponse](docs/ToolMobileGetContentResponse.md)
 - [ToolMobileGetContentResponseOtherdataInner](docs/ToolMobileGetContentResponseOtherdataInner.md)
 - [ToolMobileGetContentResponseRestrict](docs/ToolMobileGetContentResponseRestrict.md)
 - [ToolMobileGetContentResponseTemplatesInner](docs/ToolMobileGetContentResponseTemplatesInner.md)
 - [ToolMobileGetPluginsSupportingMobileResponse](docs/ToolMobileGetPluginsSupportingMobileResponse.md)
 - [ToolMobileGetPluginsSupportingMobileResponsePluginsInner](docs/ToolMobileGetPluginsSupportingMobileResponsePluginsInner.md)
 - [ToolMobileGetPublicConfigResponse](docs/ToolMobileGetPublicConfigResponse.md)
 - [ToolMobileGetPublicConfigResponseIdentityprovidersInner](docs/ToolMobileGetPublicConfigResponseIdentityprovidersInner.md)
 - [ToolMobileGetTokensForQrLoginParameters](docs/ToolMobileGetTokensForQrLoginParameters.md)
 - [ToolMobileGetTokensForQrLoginResponse](docs/ToolMobileGetTokensForQrLoginResponse.md)
 - [ToolMobileValidateSubscriptionKeyParameters](docs/ToolMobileValidateSubscriptionKeyParameters.md)
 - [ToolMobileValidateSubscriptionKeyResponse](docs/ToolMobileValidateSubscriptionKeyResponse.md)
 - [ToolMoodlenetSearchCoursesResponse](docs/ToolMoodlenetSearchCoursesResponse.md)
 - [ToolMoodlenetSearchCoursesResponseCoursesInner](docs/ToolMoodlenetSearchCoursesResponseCoursesInner.md)
 - [ToolMoodlenetVerifyWebfingerResponse](docs/ToolMoodlenetVerifyWebfingerResponse.md)
 - [ToolPolicyGetPolicyVersionParameters](docs/ToolPolicyGetPolicyVersionParameters.md)
 - [ToolPolicyGetPolicyVersionResponse](docs/ToolPolicyGetPolicyVersionResponse.md)
 - [ToolPolicyGetPolicyVersionResponseResult](docs/ToolPolicyGetPolicyVersionResponseResult.md)
 - [ToolPolicyGetPolicyVersionResponseResultPolicy](docs/ToolPolicyGetPolicyVersionResponseResultPolicy.md)
 - [ToolPolicyGetUserAcceptancesResponse](docs/ToolPolicyGetUserAcceptancesResponse.md)
 - [ToolPolicyGetUserAcceptancesResponsePoliciesInner](docs/ToolPolicyGetUserAcceptancesResponsePoliciesInner.md)
 - [ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance](docs/ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance.md)
 - [ToolPolicySetAcceptancesStatusParametersPoliciesInner](docs/ToolPolicySetAcceptancesStatusParametersPoliciesInner.md)
 - [ToolPolicySetAcceptancesStatusResponse](docs/ToolPolicySetAcceptancesStatusResponse.md)
 - [ToolTemplatelibraryListTemplatesParameters](docs/ToolTemplatelibraryListTemplatesParameters.md)
 - [ToolTemplatelibraryLoadCanonicalTemplateParameters](docs/ToolTemplatelibraryLoadCanonicalTemplateParameters.md)
 - [ToolUsertoursFetchAndStartTourResponse](docs/ToolUsertoursFetchAndStartTourResponse.md)
 - [ToolUsertoursFetchAndStartTourResponseTourconfig](docs/ToolUsertoursFetchAndStartTourResponseTourconfig.md)
 - [ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner](docs/ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner.md)
 - [ToolUsertoursResetTourResponse](docs/ToolUsertoursResetTourResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="wstoken"></a>
### wstoken

- **Type**: API key
- **API key parameter name**: wstoken
- **Location**: URL query string


## Author




